# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/dynamic/v2/dynamic.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2
from bilireq.grpc.protos.bilibili.dagw.component.avatar.v1 import avatar_pb2 as bilibili_dot_dagw_dot_component_dot_avatar_dot_v1_dot_avatar__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%bilibili/app/dynamic/v2/dynamic.proto\x12\x17\x62ilibili.app.dynamic.v2\x1a\x19google/protobuf/any.proto\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\x1a.bilibili/dagw/component/avatar/v1/avatar.proto\"I\n\x11\x41\x64\x64itionalActSkin\x12\x0c\n\x04svga\x18\x01 \x01(\t\x12\x12\n\nlast_image\x18\x02 \x01(\t\x12\x12\n\nplay_times\x18\x03 \x01(\x03\"\xa7\x03\n\x10\x41\x64\x64itionalButton\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.bilibili.app.dynamic.v2.AddButtonType\x12\x42\n\njump_style\x18\x02 \x01(\x0b\x32..bilibili.app.dynamic.v2.AdditionalButtonStyle\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12?\n\x07uncheck\x18\x04 \x01(\x0b\x32..bilibili.app.dynamic.v2.AdditionalButtonStyle\x12=\n\x05\x63heck\x18\x05 \x01(\x0b\x32..bilibili.app.dynamic.v2.AdditionalButtonStyle\x12?\n\x06status\x18\x06 \x01(\x0e\x32/.bilibili.app.dynamic.v2.AdditionalButtonStatus\x12\x46\n\nclick_type\x18\x07 \x01(\x0e\x32\x32.bilibili.app.dynamic.v2.AdditionalButtonClickType\"\\\n\x1b\x41\x64\x64itionalButtonInteractive\x12\x0e\n\x06popups\x18\x01 \x01(\t\x12\x0f\n\x07\x63onfirm\x18\x02 \x01(\t\x12\x0e\n\x06\x63\x61ncel\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\"A\n\x15\x41\x64\x64itionalButtonShare\x12\x0c\n\x04show\x18\x01 \x01(\x05\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\"\xc1\x02\n\x15\x41\x64\x64itionalButtonStyle\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12I\n\x0binteractive\x18\x03 \x01(\x0b\x32\x34.bilibili.app.dynamic.v2.AdditionalButtonInteractive\x12;\n\x08\x62g_style\x18\x04 \x01(\x0e\x32).bilibili.app.dynamic.v2.AddButtonBgStyle\x12\r\n\x05toast\x18\x05 \x01(\t\x12\x36\n\x07\x64isable\x18\x06 \x01(\x0e\x32%.bilibili.app.dynamic.v2.DisableState\x12=\n\x05share\x18\x07 \x01(\x0b\x32..bilibili.app.dynamic.v2.AdditionalButtonShare\"\x8b\x02\n\rAdditionalPGC\x12\x11\n\thead_text\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x11\n\timage_url\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_1\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_2\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12\x39\n\x06\x62utton\x18\x07 \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionalButton\x12\x11\n\thead_icon\x18\x08 \x01(\t\x12\x32\n\x05style\x18\t \x01(\x0e\x32#.bilibili.app.dynamic.v2.ImageStyle\x12\x0c\n\x04type\x18\n \x01(\t\"\xa9\x01\n\x0f\x41\x64\x64itionArticle\x12\r\n\x05title\x18\x01 \x01(\t\x12\x36\n\x05\x63over\x18\x02 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.MdlDynDrawItem\x12\x16\n\x0e\x64\x65sc_text_left\x18\x03 \x01(\t\x12\x17\n\x0f\x64\x65sc_text_right\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x11\n\tcard_type\x18\x06 \x01(\t\"\x9f\x02\n\x0e\x41\x64\x64itionCommon\x12\x11\n\thead_text\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x11\n\timage_url\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_1\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_2\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12\x39\n\x06\x62utton\x18\x07 \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionalButton\x12\x11\n\thead_icon\x18\x08 \x01(\t\x12\x32\n\x05style\x18\t \x01(\x0e\x32#.bilibili.app.dynamic.v2.ImageStyle\x12\x0c\n\x04type\x18\n \x01(\t\x12\x11\n\tcard_type\x18\x0b \x01(\t\"\xbb\x01\n\x0e\x41\x64\x64itionEsport\x12\x33\n\x05style\x18\x01 \x01(\x0e\x32$.bilibili.app.dynamic.v2.EspaceStyle\x12K\n\x14\x61\x64\x64ition_esport_moba\x18\x02 \x01(\x0b\x32+.bilibili.app.dynamic.v2.AdditionEsportMobaH\x00\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x11\n\tcard_type\x18\x04 \x01(\tB\x06\n\x04item\"\xd5\x02\n\x12\x41\x64\x64itionEsportMoba\x12\x11\n\thead_text\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x36\n\nmatch_team\x18\x03 \x03(\x0b\x32\".bilibili.app.dynamic.v2.MatchTeam\x12V\n\x1b\x61\x64\x64ition_esport_moba_status\x18\x04 \x01(\x0b\x32\x31.bilibili.app.dynamic.v2.AdditionEsportMobaStatus\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x39\n\x06\x62utton\x18\x06 \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionalButton\x12\x11\n\tsub_title\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\n \x01(\t\x12\x11\n\tcard_type\x18\x0b \x01(\t\x12\x11\n\thead_icon\x18\x0c \x01(\t\"\xbe\x01\n\x18\x41\x64\x64itionEsportMobaStatus\x12_\n addition_esport_moba_status_desc\x18\x01 \x03(\x0b\x32\x35.bilibili.app.dynamic.v2.AdditionEsportMobaStatusDesc\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\x05\x12\r\n\x05\x63olor\x18\x04 \x01(\t\x12\x13\n\x0bnight_color\x18\x05 \x01(\t\"Q\n\x1c\x41\x64\x64itionEsportMobaStatusDesc\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63olor\x18\x02 \x01(\t\x12\x13\n\x0bnight_color\x18\x03 \x01(\t\"\xd9\x01\n\rAdditionGoods\x12\x11\n\trcmd_desc\x18\x01 \x01(\t\x12\x37\n\x0bgoods_items\x18\x02 \x03(\x0b\x32\".bilibili.app.dynamic.v2.GoodsItem\x12\x11\n\tcard_type\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x13\n\x0bsource_type\x18\x06 \x01(\x05\x12\x11\n\tjump_type\x18\x07 \x01(\x05\x12\x10\n\x08\x61pp_name\x18\x08 \x01(\t\x12\x14\n\x0c\x61\x64_mark_icon\x18\t \x01(\t\"\xe2\x01\n\x10\x41\x64\x64itionLiveRoom\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x32\n\x05\x62\x61\x64ge\x18\x03 \x01(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x43\n\x0f\x64\x65sc_text_upper\x18\x04 \x01(\x0b\x32*.bilibili.app.dynamic.v2.CoverIconWithText\x12\x17\n\x0f\x64\x65sc_text_lower\x18\x05 \x01(\t\x12\x0b\n\x03uri\x18\x06 \x01(\t\x12\x11\n\tcard_type\x18\x07 \x01(\t\"\xad\x01\n\x0b\x41\x64\x64itionUgc\x12\x11\n\thead_text\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_1\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_2\x18\x05 \x01(\t\x12\x0b\n\x03uri\x18\x06 \x01(\t\x12\x10\n\x08\x64uration\x18\x07 \x01(\t\x12\x11\n\tline_feed\x18\x08 \x01(\x08\x12\x11\n\tcard_type\x18\t \x01(\t\"\xc2\x04\n\nAdditionUP\x12\r\n\x05title\x18\x01 \x01(\t\x12;\n\x0b\x64\x65sc_text_1\x18\x02 \x01(\x0b\x32&.bilibili.app.dynamic.v2.HighlightText\x12\x13\n\x0b\x64\x65sc_text_2\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x39\n\x06\x62utton\x18\x05 \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionalButton\x12\x11\n\tcard_type\x18\x06 \x01(\t\x12\x15\n\rreserve_total\x18\x07 \x01(\x03\x12<\n\x08\x61\x63t_skin\x18\x08 \x01(\x0b\x32*.bilibili.app.dynamic.v2.AdditionalActSkin\x12\x0b\n\x03rid\x18\t \x01(\x03\x12\x14\n\x0clottery_type\x18\n \x01(\x05\x12:\n\ndesc_text3\x18\x0b \x01(\x0b\x32&.bilibili.app.dynamic.v2.HighlightText\x12\x0e\n\x06up_mid\x18\x0c \x01(\x03\x12<\n\tuser_info\x18\r \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionUserInfo\x12\x12\n\ndynamic_id\x18\x0e \x01(\t\x12\x12\n\nshow_text2\x18\x0f \x01(\x08\x12\x10\n\x08\x64yn_type\x18\x10 \x01(\x03\x12\x13\n\x0b\x62usiness_id\x18\x11 \x01(\t\x12\x12\n\nbadge_text\x18\x12 \x01(\t\x12\x13\n\x0bis_premiere\x18\x13 \x01(\x08\".\n\x10\x41\x64\x64itionUserInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\"b\n\x0c\x41\x64\x64itionVote\x12\x11\n\timage_url\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0e\n\x06text_1\x18\x03 \x01(\t\x12\x13\n\x0b\x62utton_text\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\"\x87\x05\n\rAdditionVote2\x12\x45\n\x12\x61\x64\x64ition_vote_type\x18\x01 \x01(\x0e\x32).bilibili.app.dynamic.v2.AdditionVoteType\x12\x0f\n\x07vote_id\x18\x02 \x01(\x03\x12\r\n\x05title\x18\x03 \x01(\t\x12\r\n\x05label\x18\x04 \x01(\t\x12\x10\n\x08\x64\x65\x61\x64line\x18\x05 \x01(\x03\x12\x11\n\topen_text\x18\x06 \x01(\t\x12\x12\n\nclose_text\x18\x07 \x01(\t\x12\x12\n\nvoted_text\x18\x08 \x01(\t\x12\x39\n\x05state\x18\t \x01(\x0e\x32*.bilibili.app.dynamic.v2.AdditionVoteState\x12G\n\x12\x61\x64\x64ition_vote_word\x18\n \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionVoteWordH\x00\x12\x45\n\x11\x61\x64\x64ition_vote_pic\x18\x0b \x01(\x0b\x32(.bilibili.app.dynamic.v2.AdditionVotePicH\x00\x12M\n\x15\x61\x64\x64ition_vote_defaule\x18\x0c \x01(\x0b\x32,.bilibili.app.dynamic.v2.AdditionVoteDefauleH\x00\x12\x10\n\x08\x62iz_type\x18\r \x01(\x05\x12\r\n\x05total\x18\x0e \x01(\x03\x12\x11\n\tcard_type\x18\x0f \x01(\t\x12\x0c\n\x04tips\x18\x10 \x01(\t\x12\x0b\n\x03uri\x18\x11 \x01(\t\x12\x10\n\x08is_voted\x18\x12 \x01(\x08\x12\x12\n\nchoice_cnt\x18\x13 \x01(\x05\x12\x1c\n\x14\x64\x65\x66\x61ule_select_share\x18\x14 \x01(\x08\x42\x06\n\x04item\"$\n\x13\x41\x64\x64itionVoteDefaule\x12\r\n\x05\x63over\x18\x01 \x03(\t\"M\n\x0f\x41\x64\x64itionVotePic\x12:\n\x04item\x18\x01 \x03(\x0b\x32,.bilibili.app.dynamic.v2.AdditionVotePicItem\"\x8c\x01\n\x13\x41\x64\x64itionVotePicItem\x12\x0f\n\x07opt_idx\x18\x01 \x01(\x05\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0f\n\x07is_vote\x18\x03 \x01(\x08\x12\r\n\x05total\x18\x04 \x01(\x05\x12\x0f\n\x07persent\x18\x05 \x01(\x01\x12\r\n\x05title\x18\x06 \x01(\t\x12\x15\n\ris_max_option\x18\x07 \x01(\x08\"O\n\x10\x41\x64\x64itionVoteWord\x12;\n\x04item\x18\x01 \x03(\x0b\x32-.bilibili.app.dynamic.v2.AdditionVoteWordItem\"~\n\x14\x41\x64\x64itionVoteWordItem\x12\x0f\n\x07opt_idx\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07is_vote\x18\x03 \x01(\x08\x12\r\n\x05total\x18\x04 \x01(\x05\x12\x0f\n\x07persent\x18\x05 \x01(\x01\x12\x15\n\ris_max_option\x18\x06 \x01(\x08\"/\n\x07\x41\x64Param\x12\x10\n\x08\x61\x64_extra\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\t\"X\n\x13\x41lumniDynamicsReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\r\n\x05toast\x18\x02 \x01(\t\"\xb4\x01\n\x11\x41lumniDynamicsReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x12\n\nfirst_time\x18\x02 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x04 \x01(\x05\x12\x0c\n\x04page\x18\x05 \x01(\x05\x12\x11\n\tfrom_type\x18\x06 \x01(\x05\"3\n\x10\x43\x61mpusBannerInfo\x12\r\n\x05image\x18\x01 \x01(\t\x12\x10\n\x08jump_url\x18\x02 \x01(\t\"R\n\x1a\x43\x61mpusBillboardInternalReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x11\n\tcampus_id\x18\x02 \x01(\x03\x12\x14\n\x0cversion_code\x18\x03 \x01(\t\"\xc3\x02\n\x14\x43\x61mpusBillBoardReply\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08help_uri\x18\x02 \x01(\t\x12\x13\n\x0b\x63\x61mpus_name\x18\x03 \x01(\t\x12\x12\n\nbuild_time\x18\x04 \x01(\x03\x12\x14\n\x0cversion_code\x18\x05 \x01(\t\x12\x33\n\x04list\x18\x06 \x03(\x0b\x32%.bilibili.app.dynamic.v2.OfficialItem\x12\x11\n\tshare_uri\x18\x07 \x01(\t\x12\x13\n\x0b\x62ind_notice\x18\x08 \x01(\x05\x12\x14\n\x0cupdate_toast\x18\t \x01(\t\x12\x11\n\tcampus_id\x18\n \x01(\x03\x12\x45\n\ropen_progress\x18\x0b \x01(\x0b\x32..bilibili.app.dynamic.v2.CampusFeatureProgress\"\xc1\x01\n\x12\x43\x61mpusBillBoardReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x14\n\x0cversion_code\x18\x02 \x01(\t\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12=\n\tfrom_type\x18\x04 \x01(\x0e\x32*.bilibili.app.dynamic.v2.CampusReqFromType\"&\n\x11\x43\x61mpusEntryTabReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\"R\n\x12\x43\x61mpusEntryTabResp\x12<\n\nentry_type\x18\x01 \x01(\x0e\x32(.bilibili.app.dynamic.v2.CampusEntryType\"\xa0\x01\n\x15\x43\x61mpusFeatureProgress\x12\x15\n\rprogress_full\x18\x01 \x01(\x03\x12\x19\n\x11progress_achieved\x18\x02 \x01(\x03\x12\x12\n\ndesc_title\x18\x03 \x01(\t\x12\x0e\n\x06\x64\x65sc_1\x18\x04 \x01(\t\x12\x31\n\x03\x62tn\x18\x05 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\"Y\n\x12\x43\x61mpusFeedbackInfo\x12\x10\n\x08\x62iz_type\x18\x01 \x01(\x05\x12\x0e\n\x06\x62iz_id\x18\x02 \x01(\x03\x12\x11\n\tcampus_id\x18\x03 \x01(\x03\x12\x0e\n\x06reason\x18\x04 \x01(\t\"&\n\x13\x43\x61mpusFeedbackReply\x12\x0f\n\x07message\x18\x01 \x01(\t\"]\n\x11\x43\x61mpusFeedbackReq\x12:\n\x05infos\x18\x01 \x03(\x0b\x32+.bilibili.app.dynamic.v2.CampusFeedbackInfo\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x05\"\x96\x01\n\x14\x43\x61mpusHomePagesReply\x12\x33\n\x03top\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v2.CampusRcmdTop\x12\x36\n\ncampus_top\x18\x02 \x01(\x0b\x32\".bilibili.app.dynamic.v2.CampusTop\x12\x11\n\tpage_type\x18\x03 \x01(\x05\"\xae\x01\n\x12\x43\x61mpusHomePagesReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12\x0b\n\x03lat\x18\x03 \x01(\x01\x12\x0b\n\x03lng\x18\x04 \x01(\x01\x12\x43\n\x0bplayer_args\x18\x05 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x11\n\tpage_type\x18\x06 \x01(\x05\"}\n\x13\x43\x61mpusHomeRcmdTopic\x12\x33\n\x05title\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.ModuleTitle\x12\x31\n\x05topic\x18\x02 \x03(\x0b\x32\".bilibili.app.dynamic.v2.TopicItem\"_\n\nCampusInfo\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x0e\n\x06online\x18\x04 \x01(\x03\x12\x0b\n\x03url\x18\x05 \x01(\t\"6\n\x0b\x43\x61mpusLabel\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\"N\n\x17\x43\x61mpusMateLikeListReply\x12\x33\n\x04list\x18\x01 \x03(\x0b\x32%.bilibili.app.dynamic.v2.ModuleAuthor\"j\n\x15\x43\x61mpusMateLikeListReq\x12\x12\n\ndynamic_id\x18\x01 \x01(\x03\x12=\n\tfrom_type\x18\x02 \x01(\x0e\x32*.bilibili.app.dynamic.v2.CampusReqFromType\"K\n\x0e\x43\x61mpusMngBadge\x12\r\n\x05title\x18\x01 \x01(\t\x12\x11\n\tbadge_url\x18\x02 \x01(\t\x12\x17\n\x0fupload_hint_msg\x18\x03 \x01(\t\"N\n\x12\x43\x61mpusMngBasicInfo\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12\x10\n\x08hint_msg\x18\x03 \x01(\t\"\xaf\x01\n\x14\x43\x61mpusMngDetailReply\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32&.bilibili.app.dynamic.v2.CampusMngItem\x12\x18\n\x10top_hint_bar_msg\x18\x02 \x01(\t\x12\x1e\n\x16\x62ottom_submit_hint_msg\x18\x03 \x01(\t\x12\x11\n\tcampus_id\x18\x04 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x05 \x01(\t\"\'\n\x12\x43\x61mpusMngDetailReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\"\xc3\x02\n\rCampusMngItem\x12\x14\n\x0c\x61udit_status\x18\x01 \x01(\x05\x12\x15\n\raudit_message\x18\x02 \x01(\t\x12\x11\n\titem_type\x18\x03 \x01(\x05\x12\x13\n\x0bmng_item_id\x18\x04 \x01(\t\x12\x0e\n\x06is_del\x18\x05 \x01(\x08\x12\x41\n\nbasic_info\x18\x06 \x01(\x0b\x32+.bilibili.app.dynamic.v2.CampusMngBasicInfoH\x00\x12\x38\n\x05\x62\x61\x64ge\x18\x07 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.CampusMngBadgeH\x00\x12\x10\n\x06slogan\x18\x08 \x01(\tH\x00\x12\x36\n\x04quiz\x18\t \x01(\x0b\x32&.bilibili.app.dynamic.v2.CampusMngQuizH\x00\x42\x06\n\x04item\"\x95\x01\n\rCampusMngQuiz\x12\r\n\x05title\x18\x01 \x01(\t\x12\x38\n\nmore_label\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12\x11\n\tadd_label\x18\x03 \x01(\t\x12\x14\n\x0csubmit_label\x18\x04 \x01(\t\x12\x12\n\nquiz_count\x18\x05 \x01(\x03\"\x98\x01\n\x13\x43\x61mpusMngQuizDetail\x12\x0f\n\x07quiz_id\x18\x01 \x01(\x03\x12\x10\n\x08question\x18\x02 \x01(\t\x12\x16\n\x0e\x63orrect_answer\x18\x03 \x01(\t\x12\x19\n\x11wrong_answer_list\x18\x04 \x03(\t\x12\x14\n\x0c\x61udit_status\x18\x05 \x01(\x05\x12\x15\n\raudit_message\x18\x06 \x01(\t\"z\n\x19\x43\x61mpusMngQuizOperateReply\x12\r\n\x05toast\x18\x01 \x01(\t\x12:\n\x04quiz\x18\x02 \x03(\x0b\x32,.bilibili.app.dynamic.v2.CampusMngQuizDetail\x12\x12\n\nquiz_total\x18\x03 \x01(\x03\"x\n\x17\x43\x61mpusMngQuizOperateReq\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\x05\x12\x11\n\tcampus_id\x18\x02 \x01(\x03\x12:\n\x04quiz\x18\x03 \x03(\x0b\x32,.bilibili.app.dynamic.v2.CampusMngQuizDetail\"H\n\x0f\x43\x61mpusMngSlogan\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0e\n\x06slogan\x18\x02 \x01(\t\x12\x16\n\x0einput_hint_msg\x18\x03 \x01(\t\"%\n\x14\x43\x61mpusMngSubmitReply\x12\r\n\x05toast\x18\x01 \x01(\t\"g\n\x12\x43\x61mpusMngSubmitReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12>\n\x0emodified_items\x18\x02 \x03(\x0b\x32&.bilibili.app.dynamic.v2.CampusMngItem\"e\n\x10\x43\x61mpusNoticeInfo\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x34\n\x06\x62utton\x18\x03 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\"\xb4\x01\n\x13\x43\x61mpusRcmdFeedReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\r\n\x05toast\x18\x02 \x01(\t\x12\x38\n\tguide_bar\x18\x03 \x01(\x0b\x32%.bilibili.app.dynamic.v2.GuideBarInfo\x12\x10\n\x08has_more\x18\x04 \x01(\x08\x12\x0e\n\x06update\x18\x05 \x01(\x08\"\x85\x02\n\x11\x43\x61mpusRcmdFeedReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x12\n\nfirst_time\x18\x02 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x04 \x01(\x05\x12\x0c\n\x04page\x18\x05 \x01(\x05\x12\x0e\n\x06scroll\x18\x06 \x01(\x05\x12\x13\n\x0bview_dyn_id\x18\x07 \x01(\t\x12=\n\tfrom_type\x18\x08 \x01(\x0e\x32*.bilibili.app.dynamic.v2.CampusReqFromType\"W\n\x0e\x43\x61mpusRcmdInfo\x12\r\n\x05title\x18\x01 \x01(\t\x12\x36\n\x05items\x18\x02 \x03(\x0b\x32\'.bilibili.app.dynamic.v2.CampusRcmdItem\"\x9f\x01\n\x0e\x43\x61mpusRcmdItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\x30\n\x05items\x18\x02 \x03(\x0b\x32!.bilibili.app.dynamic.v2.RcmdItem\x12\x11\n\tcampus_id\x18\x03 \x01(\x03\x12\x39\n\x0b\x65ntry_label\x18\x04 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\"\xdf\x01\n\x0f\x43\x61mpusRcmdReply\x12\x33\n\x03top\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v2.CampusRcmdTop\x12\x35\n\x04rcmd\x18\x02 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.CampusRcmdInfo\x12\x36\n\ncampus_top\x18\x03 \x01(\x0b\x32\".bilibili.app.dynamic.v2.CampusTop\x12\x11\n\tpage_type\x18\x04 \x01(\x05\x12\x15\n\rjump_home_pop\x18\x05 \x01(\x05\"\x95\x02\n\rCampusRcmdReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12\x0b\n\x03lat\x18\x03 \x01(\x01\x12\x0b\n\x03lng\x18\x04 \x01(\x01\x12\x43\n\x0bplayer_args\x18\x05 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12=\n\tfrom_type\x18\x06 \x01(\x0e\x32*.bilibili.app.dynamic.v2.CampusReqFromType\x12>\n\tpage_type\x18\x07 \x01(\x0e\x32+.bilibili.app.dynamic.v2.CampusHomePageType\"\xbf\x05\n\rCampusRcmdTop\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\x05\x12\x36\n\x06\x62utton\x18\x06 \x01(\x0b\x32&.bilibili.app.dynamic.v2.RcmdTopButton\x12:\n\x0cswitch_label\x18\x07 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12:\n\x0cnotice_label\x18\x08 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12\r\n\x05\x64\x65sc2\x18\t \x01(\t\x12\r\n\x05\x64\x65sc3\x18\n \x01(\t\x12:\n\x0cinvite_label\x18\x0b \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12;\n\rreserve_label\x18\x0c \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12\x16\n\x0ereserve_number\x18\r \x01(\x03\x12\x13\n\x0bmax_reserve\x18\x0e \x01(\x03\x12:\n\x0cschool_label\x18\x0f \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12\x37\n\tmng_label\x18\x10 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12@\n\nrcmd_topic\x18\x11 \x01(\x0b\x32,.bilibili.app.dynamic.v2.CampusHomeRcmdTopic\x12\x19\n\x11\x61udit_before_open\x18\x12 \x01(\x08\x12\x15\n\raudit_message\x18\x13 \x01(\t\"Z\n\x14\x43\x61mpusRecommendReply\x12\x30\n\x05items\x18\x01 \x03(\x0b\x32!.bilibili.app.dynamic.v2.RcmdItem\x12\x10\n\x08has_more\x18\x02 \x01(\x08\"\xb7\x01\n\x12\x43\x61mpusRecommendReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x0f\n\x07page_no\x18\x02 \x01(\x03\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x38\n\x04\x66rom\x18\x04 \x01(\x0e\x32*.bilibili.app.dynamic.v2.CampusRcmdReqFrom\"$\n\x11\x43\x61mpusRedDotReply\x12\x0f\n\x07red_dot\x18\x01 \x01(\x05\"c\n\x0f\x43\x61mpusRedDotReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12=\n\tfrom_type\x18\x02 \x01(\x0e\x32*.bilibili.app.dynamic.v2.CampusReqFromType\"_\n\x11\x43\x61mpusShowTabInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x0f\n\x07red_dot\x18\x04 \x01(\x05\x12\x10\n\x08icon_url\x18\x05 \x01(\t\"\x90\x01\n\x11\x43\x61mpusSquareReply\x12\r\n\x05title\x18\x01 \x01(\t\x12\x36\n\x04list\x18\x02 \x03(\x0b\x32(.bilibili.app.dynamic.v2.RcmdCampusBrief\x12\x34\n\x06\x62utton\x18\x03 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\">\n\x0f\x43\x61mpusSquareReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x0b\n\x03lat\x18\x02 \x01(\x01\x12\x0b\n\x03lng\x18\x03 \x01(\x01\"\xf4\x04\n\tCampusTop\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12\x38\n\x04tabs\x18\x03 \x03(\x0b\x32*.bilibili.app.dynamic.v2.CampusShowTabInfo\x12:\n\x0cswitch_label\x18\x04 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12\r\n\x05title\x18\x05 \x01(\t\x12\x39\n\x06\x62\x61nner\x18\x06 \x03(\x0b\x32).bilibili.app.dynamic.v2.CampusBannerInfo\x12:\n\x0cinvite_label\x18\x07 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12\x39\n\x06notice\x18\x08 \x01(\x0b\x32).bilibili.app.dynamic.v2.CampusNoticeInfo\x12>\n\x0ctopic_square\x18\t \x01(\x0b\x32(.bilibili.app.dynamic.v2.TopicSquareInfo\x12\x14\n\x0c\x63\x61mpus_badge\x18\n \x01(\t\x12\x19\n\x11\x63\x61mpus_background\x18\x0b \x01(\t\x12\x14\n\x0c\x63\x61mpus_motto\x18\x0c \x01(\t\x12\x37\n\tmng_entry\x18\r \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12\x14\n\x0c\x63\x61mpus_intro\x18\x0e \x01(\t\x12\x18\n\x10\x63\x61mpus_name_link\x18\x0f \x01(\t\x12\x18\n\x10\x62ottom_left_text\x18\x10 \x01(\t\"\xba\x01\n\x18\x43\x61mpusTopicRcmdFeedReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\r\n\x05toast\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x0e\n\x06offset\x18\x04 \x01(\t\x12\x39\n\x0cjoin_discuss\x18\x05 \x01(\x0b\x32#.bilibili.app.dynamic.v2.IconButton\"\xd3\x01\n\x16\x43\x61mpusTopicRcmdFeedReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x04 \x01(\x05\x12=\n\tfrom_type\x18\x05 \x01(\x0e\x32*.bilibili.app.dynamic.v2.CampusReqFromType\"\x9c\x01\n\rCardParagraph\x12\x42\n\x0f\x61\x64\x64itional_card\x18\x01 \x01(\x0b\x32).bilibili.app.dynamic.v2.ModuleAdditional\x12\x0e\n\x06\x62iz_id\x18\x03 \x01(\t\x12\x37\n\x08\x62iz_type\x18\x02 \x01(\x0e\x32%.bilibili.app.dynamic.v2.LinkNodeType\"\x9d\x01\n\x10\x43\x61rdVideoDynList\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x12\n\nupdate_num\x18\x02 \x01(\x03\x12\x16\n\x0ehistory_offset\x18\x03 \x01(\t\x12\x17\n\x0fupdate_baseline\x18\x04 \x01(\t\x12\x10\n\x08has_more\x18\x05 \x01(\x08\"c\n\x13\x43\x61rdVideoFollowList\x12\x15\n\rview_all_link\x18\x01 \x01(\t\x12\x35\n\x04list\x18\x02 \x03(\x0b\x32\'.bilibili.app.dynamic.v2.FollowListItem\"\xd8\x02\n\x0f\x43\x61rdVideoUpList\x12\r\n\x05title\x18\x01 \x01(\t\x12\x31\n\x04list\x18\x02 \x03(\x0b\x32#.bilibili.app.dynamic.v2.UpListItem\x12\x11\n\tfootprint\x18\x03 \x01(\t\x12\x15\n\rshow_live_num\x18\x04 \x01(\x05\x12<\n\nmore_label\x18\x05 \x01(\x0b\x32(.bilibili.app.dynamic.v2.UpListMoreLabel\x12\x14\n\x0ctitle_switch\x18\x06 \x01(\x05\x12\x17\n\x0fshow_more_label\x18\x07 \x01(\x08\x12\x18\n\x10show_in_personal\x18\x08 \x01(\x08\x12\x18\n\x10show_more_button\x18\t \x01(\x08\x12\x38\n\x0blist_second\x18\n \x03(\x0b\x32#.bilibili.app.dynamic.v2.UpListItem\"\xbc\x01\n\x0b\x43hannelInfo\x12\x12\n\nchannel_id\x18\x01 \x01(\x03\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x10\n\x08is_atten\x18\x04 \x01(\x08\x12\x11\n\ttype_icon\x18\x05 \x01(\t\x12\x30\n\x05items\x18\x06 \x03(\x0b\x32!.bilibili.app.dynamic.v2.RcmdItem\x12\x0c\n\x04icon\x18\x07 \x01(\t\x12\x10\n\x08jump_uri\x18\x08 \x01(\t\"G\n\x0b\x43mtShowItem\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\r\n\x05uname\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0f\n\x07\x63omment\x18\x04 \x01(\t\"0\n\x06\x43olors\x12\x11\n\tcolor_day\x18\x01 \x01(\t\x12\x13\n\x0b\x63olor_night\x18\x02 \x01(\t\"3\n\rCommentDetail\x12\x12\n\ncan_modify\x18\x01 \x01(\x08\x12\x0e\n\x06status\x18\x02 \x01(\x03\">\n\x06\x43onfig\x12\x1a\n\x12story_vertical_exp\x18\x01 \x01(\x08\x12\x18\n\x10\x64\x65tail_view_bits\x18\x02 \x01(\x03\"/\n\x11\x43overIconWithText\x12\x0c\n\x04icon\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\"P\n\x0b\x44\x65\x63oCardFan\x12\x0e\n\x06is_fan\x18\x01 \x01(\x05\x12\x0e\n\x06number\x18\x02 \x01(\x05\x12\x12\n\nnumber_str\x18\x03 \x01(\t\x12\r\n\x05\x63olor\x18\x04 \x01(\t\"q\n\x0c\x44\x65\x63orateCard\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x10\n\x08\x63\x61rd_url\x18\x02 \x01(\t\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x31\n\x03\x66\x61n\x18\x04 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DecoCardFan\"\xf8\x02\n\x0b\x44\x65scription\x12\x0c\n\x04text\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0e\x32!.bilibili.app.dynamic.v2.DescType\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x36\n\nemoji_type\x18\x04 \x01(\x0e\x32\".bilibili.app.dynamic.v2.EmojiType\x12\x12\n\ngoods_type\x18\x05 \x01(\t\x12\x10\n\x08icon_url\x18\x06 \x01(\t\x12\x11\n\ticon_name\x18\x07 \x01(\t\x12\x0b\n\x03rid\x18\x08 \x01(\t\x12\x37\n\x05goods\x18\t \x01(\x0b\x32(.bilibili.app.dynamic.v2.ModuleDescGoods\x12\x11\n\torig_text\x18\n \x01(\t\x12\x12\n\nemoji_size\x18\x0b \x01(\x05\x12?\n\x0f\x65moji_size_spec\x18\x0c \x01(\x0b\x32&.bilibili.app.dynamic.v2.EmojiSizeSpec\":\n\tDimension\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05width\x18\x02 \x01(\x03\x12\x0e\n\x06rotate\x18\x03 \x01(\x03\"_\n\x1c\x44ynAdditionCommonFollowReply\x12?\n\x06status\x18\x01 \x01(\x0e\x32/.bilibili.app.dynamic.v2.AdditionalButtonStatus\"\x80\x01\n\x1a\x44ynAdditionCommonFollowReq\x12?\n\x06status\x18\x01 \x01(\x0e\x32/.bilibili.app.dynamic.v2.AdditionalButtonStatus\x12\x0e\n\x06\x64yn_id\x18\x02 \x01(\t\x12\x11\n\tcard_type\x18\x03 \x01(\t\"\x94\x02\n\x13\x44ynAllPersonalReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x13\n\x0bread_offset\x18\x04 \x01(\t\x12\x33\n\x08relation\x18\x05 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\x12;\n\x0b\x61\x64\x64ition_up\x18\x06 \x01(\x0b\x32&.bilibili.app.dynamic.v2.TopAdditionUP\x12\r\n\x05title\x18\x07 \x01(\t\x12\x11\n\ttitle_sub\x18\x08 \x01(\t\"\xa7\x02\n\x11\x44ynAllPersonalReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x12\n\nis_preload\x18\x04 \x01(\x05\x12<\n\rplayurl_param\x18\x05 \x01(\x0b\x32%.bilibili.app.dynamic.v2.PlayurlParam\x12\x12\n\nlocal_time\x18\x06 \x01(\x05\x12\x11\n\tfootprint\x18\x07 \x01(\t\x12\x0c\n\x04\x66rom\x18\x08 \x01(\t\x12\x43\n\x0bplayer_args\x18\t \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x16\n\x0epersonal_extra\x18\n \x01(\t\"\xdf\x02\n\x0b\x44ynAllReply\x12:\n\x0c\x64ynamic_list\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicList\x12\x39\n\x07up_list\x18\x02 \x01(\x0b\x32(.bilibili.app.dynamic.v2.CardVideoUpList\x12\x36\n\ntopic_list\x18\x03 \x01(\x0b\x32\".bilibili.app.dynamic.v2.TopicList\x12\x33\n\x08unfollow\x18\x04 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Unfollow\x12;\n\x0bregion_rcmd\x18\x05 \x01(\x0b\x32&.bilibili.app.dynamic.v2.DynRegionRcmd\x12/\n\x06\x63onfig\x18\x06 \x01(\x0b\x32\x1f.bilibili.app.dynamic.v2.Config\"\xf0\x03\n\tDynAllReq\x12\x17\n\x0fupdate_baseline\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x36\n\x0crefresh_type\x18\x04 \x01(\x0e\x32 .bilibili.app.dynamic.v2.Refresh\x12<\n\rplayurl_param\x18\x05 \x01(\x0b\x32%.bilibili.app.dynamic.v2.PlayurlParam\x12\x17\n\x0f\x61ssist_baseline\x18\x06 \x01(\t\x12\x12\n\nlocal_time\x18\x07 \x01(\x05\x12=\n\x0ercmd_ups_param\x18\x08 \x01(\x0b\x32%.bilibili.app.dynamic.v2.RcmdUPsParam\x12\x32\n\x08\x61\x64_param\x18\t \x01(\x0b\x32 .bilibili.app.dynamic.v2.AdParam\x12\x12\n\ncold_start\x18\n \x01(\x05\x12\x0c\n\x04\x66rom\x18\x0b \x01(\t\x12\x43\n\x0bplayer_args\x18\x0c \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x16\n\x0etab_recall_uid\x18\r \x01(\x03\x12\x17\n\x0ftab_recall_type\x18\x0e \x01(\x05\"f\n\x12\x44ynAllUpdOffsetReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x13\n\x0bread_offset\x18\x02 \x01(\t\x12\x11\n\tfootprint\x18\x03 \x01(\t\x12\x16\n\x0epersonal_extra\x18\x04 \x01(\t\"\x89\x02\n\x0b\x44ynamicItem\x12\x37\n\tcard_type\x18\x01 \x01(\x0e\x32$.bilibili.app.dynamic.v2.DynamicType\x12\x37\n\titem_type\x18\x02 \x01(\x0e\x32$.bilibili.app.dynamic.v2.DynamicType\x12\x30\n\x07modules\x18\x03 \x03(\x0b\x32\x1f.bilibili.app.dynamic.v2.Module\x12/\n\x06\x65xtend\x18\x04 \x01(\x0b\x32\x1f.bilibili.app.dynamic.v2.Extend\x12\x10\n\x08has_fold\x18\x05 \x01(\x05\x12\x13\n\x0bserver_info\x18\x06 \x01(\t\"\x98\x01\n\x0b\x44ynamicList\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x12\n\nupdate_num\x18\x02 \x01(\x03\x12\x16\n\x0ehistory_offset\x18\x03 \x01(\t\x12\x17\n\x0fupdate_baseline\x18\x04 \x01(\t\x12\x10\n\x08has_more\x18\x05 \x01(\x08\"D\n\x0e\x44ynDetailReply\x12\x32\n\x04item\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"\xd1\x02\n\x0c\x44ynDetailReq\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x12\n\ndynamic_id\x18\x02 \x01(\t\x12\x10\n\x08\x64yn_type\x18\x03 \x01(\x03\x12\x0b\n\x03rid\x18\x04 \x01(\x03\x12\x32\n\x08\x61\x64_param\x18\x05 \x01(\x0b\x32 .bilibili.app.dynamic.v2.AdParam\x12\x0c\n\x04\x66rom\x18\x06 \x01(\t\x12\x43\n\x0bplayer_args\x18\x07 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x10\n\x08share_id\x18\x08 \x01(\t\x12\x12\n\nshare_mode\x18\t \x01(\x05\x12\x12\n\nlocal_time\x18\n \x01(\x05\x12\x0f\n\x07pattern\x18\x0b \x01(\t\x12/\n\x06\x63onfig\x18\x0c \x01(\x0b\x32\x1f.bilibili.app.dynamic.v2.Config\"E\n\x0f\x44ynDetailsReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"\xec\x01\n\rDynDetailsReq\x12\x13\n\x0b\x64ynamic_ids\x18\x01 \x01(\t\x12<\n\rplayurl_param\x18\x02 \x01(\x0b\x32%.bilibili.app.dynamic.v2.PlayurlParam\x12\x12\n\nlocal_time\x18\x03 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12/\n\x06\x63onfig\x18\x05 \x01(\x0b\x32\x1f.bilibili.app.dynamic.v2.Config\"F\n\x10\x44ynFakeCardReply\x12\x32\n\x04item\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"!\n\x0e\x44ynFakeCardReq\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\".\n\x0e\x44ynFeatureGate\x12\x1c\n\x14\x65nhanced_interaction\x18\x01 \x01(\x08\"j\n\x0e\x44ynFriendReply\x12\x36\n\x08\x64yn_list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x10\n\x08has_more\x18\x02 \x01(\x08\x12\x0e\n\x06offset\x18\x03 \x01(\t\"w\n\x0c\x44ynFriendReq\x12\x0e\n\x06offset\x18\x01 \x01(\t\x12\x12\n\nlocal_time\x18\x02 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"K\n\rDynLightReply\x12:\n\x0c\x64ynamic_list\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicList\"\xbf\x01\n\x0b\x44ynLightReq\x12\x16\n\x0ehistory_offset\x18\x01 \x01(\t\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x05 \x01(\x05\x12\x11\n\tfrom_type\x18\x06 \x01(\x05\x12\x10\n\x08\x66\x61ke_uid\x18\x07 \x01(\x03\"\xdf\x01\n\x19\x44ynMixUpListViewMoreReply\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32&.bilibili.app.dynamic.v2.MixUpListItem\x12\x1b\n\x13search_default_text\x18\x02 \x01(\t\x12\x35\n\nsort_types\x18\x03 \x03(\x0b\x32!.bilibili.app.dynamic.v2.SortType\x12\x1c\n\x14show_more_sort_types\x18\x04 \x01(\x08\x12\x19\n\x11\x64\x65\x66\x61ult_sort_type\x18\x05 \x01(\x05\",\n\x17\x44ynMixUpListViewMoreReq\x12\x11\n\tsort_type\x18\x01 \x01(\x05\"\x87\x01\n\x0c\x44ynRcmdReply\x12;\n\x0bregion_rcmd\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v2.DynRegionRcmd\x12:\n\x0c\x64ynamic_list\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicList\"\x8b\x01\n\nDynRcmdReq\x12\x43\n\x0bplayer_args\x18\x01 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x02 \x01(\x05\x12\x10\n\x08\x66\x61ke_uid\x18\x03 \x01(\x03\x12\x12\n\nis_refresh\x18\x04 \x01(\x08\"M\n\x16\x44ynRcmdUpExchangeReply\x12\x33\n\x08unfollow\x18\x01 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Unfollow\"D\n\x14\x44ynRcmdUpExchangeReq\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x11\n\tdislikeTs\x18\x02 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\"}\n\rDynRegionRcmd\x12\x39\n\x05items\x18\x01 \x03(\x0b\x32*.bilibili.app.dynamic.v2.DynRegionRcmdItem\x12\x31\n\x04opts\x18\x02 \x01(\x0b\x32#.bilibili.app.dynamic.v2.RcmdOption\"c\n\x11\x44ynRegionRcmdItem\x12\x0b\n\x03rid\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x32\n\x05items\x18\x03 \x03(\x0b\x32#.bilibili.app.dynamic.v2.ModuleRcmd\"\xa7\x01\n\x0c\x44ynScreenTab\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65\x66\x61ult_tab\x18\x03 \x01(\x08\x12!\n\x19strategy_show_on_entrance\x18\x04 \x01(\x08\x12 \n\x18strategy_show_on_refresh\x18\x05 \x01(\x08\x12 \n\x18strategy_show_on_pull_up\x18\x06 \x01(\x08\"\xc4\x01\n\x0e\x44ynSearchReply\x12<\n\x0c\x63hannel_info\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v2.SearchChannel\x12:\n\x0csearch_topic\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.SearchTopic\x12\x38\n\x0bsearch_info\x18\x03 \x01(\x0b\x32#.bilibili.app.dynamic.v2.SearchInfo\"\x86\x01\n\x0c\x44ynSearchReq\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x12\n\nlocal_time\x18\x03 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"\xb5\x01\n\x15\x44ynServerDetailsReply\x12H\n\x05items\x18\x01 \x03(\x0b\x32\x39.bilibili.app.dynamic.v2.DynServerDetailsReply.ItemsEntry\x1aR\n\nItemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem:\x02\x38\x01\"\xf9\x01\n\x13\x44ynServerDetailsReq\x12\x12\n\nlocal_time\x18\x02 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x10\n\x08mobi_app\x18\x04 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x05 \x01(\t\x12\r\n\x05\x62uvid\x18\x06 \x01(\t\x12\r\n\x05\x62uild\x18\x07 \x01(\x03\x12\x0b\n\x03mid\x18\x08 \x01(\x03\x12\x10\n\x08platform\x18\t \x01(\t\x12\x11\n\tis_master\x18\n \x01(\x08\x12\x17\n\x0ftop_dynamic_ids\x18\x0b \x03(\x03\"\xac\x01\n\x0b\x44ynSpaceReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x16\n\x0ehistory_offset\x18\x02 \x01(\t\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x04 \x01(\x05\x12\x0c\n\x04page\x18\x05 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x06 \x01(\t\"k\n\x0b\x44ynSpaceRsp\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x16\n\x0ehistory_offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\"\xbf\x01\n\x1a\x44ynSpaceSearchDetailsReply\x12M\n\x05items\x18\x01 \x03(\x0b\x32>.bilibili.app.dynamic.v2.DynSpaceSearchDetailsReply.ItemsEntry\x1aR\n\nItemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem:\x02\x38\x01\"\x97\x02\n\x18\x44ynSpaceSearchDetailsReq\x12\x14\n\x0csearch_words\x18\x02 \x03(\t\x12\x12\n\nlocal_time\x18\x03 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x10\n\x08mobi_app\x18\x05 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x06 \x01(\t\x12\r\n\x05\x62uvid\x18\x07 \x01(\t\x12\r\n\x05\x62uild\x18\x08 \x01(\x03\x12\x0b\n\x03mid\x18\t \x01(\x03\x12\x10\n\x08platform\x18\n \x01(\t\x12\n\n\x02ip\x18\x0b \x01(\t\x12\x10\n\x08net_type\x18\x0c \x01(\x05\x12\x0f\n\x07tf_type\x18\r \x01(\x05\"\xa8\x02\n\x06\x44ynTab\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0e\n\x06\x62ubble\x18\x03 \x01(\t\x12\x11\n\tred_point\x18\x04 \x01(\x05\x12\x0f\n\x07\x63ity_id\x18\x05 \x01(\x03\x12\x10\n\x08is_popup\x18\x06 \x01(\x05\x12-\n\x05popup\x18\x07 \x01(\x0b\x32\x1e.bilibili.app.dynamic.v2.Popup\x12\x13\n\x0b\x64\x65\x66\x61ult_tab\x18\x08 \x01(\x08\x12\x11\n\tsub_title\x18\t \x01(\t\x12\x0e\n\x06\x61nchor\x18\n \x01(\t\x12\x15\n\rinternal_test\x18\x0b \x01(\t\x12\x0c\n\x04type\x18\x0c \x01(\x05\x12\x30\n\x07\x62\x61\x63k_up\x18\r \x01(\x0b\x32\x1f.bilibili.app.dynamic.v2.DynTab\"z\n\x0b\x44ynTabReply\x12\x30\n\x07\x64yn_tab\x18\x01 \x03(\x0b\x32\x1f.bilibili.app.dynamic.v2.DynTab\x12\x39\n\nscreen_tab\x18\x02 \x03(\x0b\x32%.bilibili.app.dynamic.v2.DynScreenTab\"b\n\tDynTabReq\x12\x16\n\x0eteenagers_mode\x18\x01 \x01(\x05\x12=\n\tfrom_type\x18\x02 \x01(\x0e\x32*.bilibili.app.dynamic.v2.CampusReqFromType\"{\n\x0b\x44ynThumbReq\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x0e\n\x06\x64yn_id\x18\x02 \x01(\t\x12\x10\n\x08\x64yn_type\x18\x03 \x01(\x03\x12\x0b\n\x03rid\x18\x04 \x01(\t\x12\x30\n\x04type\x18\x05 \x01(\x0e\x32\".bilibili.app.dynamic.v2.ThumbType\"\x96\x02\n\x15\x44ynVideoPersonalReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x13\n\x0bread_offset\x18\x04 \x01(\t\x12\x33\n\x08relation\x18\x05 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\x12;\n\x0b\x61\x64\x64ition_up\x18\x06 \x01(\x0b\x32&.bilibili.app.dynamic.v2.TopAdditionUP\x12\r\n\x05title\x18\x07 \x01(\t\x12\x11\n\ttitle_sub\x18\x08 \x01(\t\"\xbf\x02\n\x13\x44ynVideoPersonalReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x12\n\nis_preload\x18\x04 \x01(\x05\x12<\n\rplayurl_param\x18\x05 \x01(\x0b\x32%.bilibili.app.dynamic.v2.PlayurlParam\x12\x12\n\nlocal_time\x18\x06 \x01(\x05\x12\x11\n\tfootprint\x18\x07 \x01(\t\x12\x0c\n\x04\x66rom\x18\x08 \x01(\t\x12\x43\n\x0bplayer_args\x18\t \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x14\n\x0cpegasus_avid\x18\n \x01(\x03\x12\x16\n\x0epersonal_extra\x18\x0b \x01(\t\"\xda\x01\n\rDynVideoReply\x12?\n\x0c\x64ynamic_list\x18\x01 \x01(\x0b\x32).bilibili.app.dynamic.v2.CardVideoDynList\x12?\n\rvideo_up_list\x18\x02 \x01(\x0b\x32(.bilibili.app.dynamic.v2.CardVideoUpList\x12G\n\x11video_follow_list\x18\x03 \x01(\x0b\x32,.bilibili.app.dynamic.v2.CardVideoFollowList\"\xba\x02\n\x0b\x44ynVideoReq\x12\x17\n\x0fupdate_baseline\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x36\n\x0crefresh_type\x18\x04 \x01(\x0e\x32 .bilibili.app.dynamic.v2.Refresh\x12<\n\rplayurl_param\x18\x05 \x01(\x0b\x32%.bilibili.app.dynamic.v2.PlayurlParam\x12\x17\n\x0f\x61ssist_baseline\x18\x06 \x01(\t\x12\x12\n\nlocal_time\x18\x07 \x01(\x05\x12\x0c\n\x04\x66rom\x18\x08 \x01(\t\x12\x43\n\x0bplayer_args\x18\t \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"h\n\x14\x44ynVideoUpdOffsetReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x13\n\x0bread_offset\x18\x02 \x01(\t\x12\x11\n\tfootprint\x18\x03 \x01(\t\x12\x16\n\x0epersonal_extra\x18\x04 \x01(\t\"S\n\x0c\x44ynVoteReply\x12\x34\n\x04item\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v2.AdditionVote2\x12\r\n\x05toast\x18\x02 \x01(\t\"\x84\x01\n\nDynVoteReq\x12\x0f\n\x07vote_id\x18\x01 \x01(\x03\x12\r\n\x05votes\x18\x02 \x03(\x03\x12\x33\n\x06status\x18\x03 \x01(\x0e\x32#.bilibili.app.dynamic.v2.VoteStatus\x12\x12\n\ndynamic_id\x18\x04 \x01(\t\x12\r\n\x05share\x18\x05 \x01(\x08\"\x1e\n\rEmojiSizeSpec\x12\r\n\x05width\x18\x01 \x01(\x03\"\xe2\x01\n\tEmoteNode\x12\x11\n\temote_url\x18\x02 \x01(\t\x12\x37\n\x0b\x65mote_width\x18\x03 \x01(\x0b\x32\".bilibili.app.dynamic.v2.EmoteSize\x12=\n\x0einline_img_cfg\x18\x05 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ImgInlineCfg\x12\x15\n\ris_inline_img\x18\x04 \x01(\x08\x12\x33\n\x08raw_text\x18\x01 \x01(\x0b\x32!.bilibili.app.dynamic.v2.WordNode\".\n\tEmoteSize\x12\r\n\x05width\x18\x01 \x01(\x01\x12\x12\n\nemoji_size\x18\x02 \x01(\x05\"\x85\x07\n\x06\x45xtend\x12\x12\n\ndyn_id_str\x18\x01 \x01(\t\x12\x13\n\x0b\x62usiness_id\x18\x02 \x01(\t\x12\x17\n\x0forig_dyn_id_str\x18\x03 \x01(\t\x12\x11\n\torig_name\x18\x04 \x01(\t\x12\x14\n\x0corig_img_url\x18\x05 \x01(\t\x12\x37\n\torig_desc\x18\x06 \x03(\x0b\x32$.bilibili.app.dynamic.v2.Description\x12\x32\n\x04\x64\x65sc\x18\x07 \x03(\x0b\x32$.bilibili.app.dynamic.v2.Description\x12;\n\rorig_dyn_type\x18\x08 \x01(\x0e\x32$.bilibili.app.dynamic.v2.DynamicType\x12\x12\n\nshare_type\x18\t \x01(\t\x12\x13\n\x0bshare_scene\x18\n \x01(\t\x12\x15\n\ris_fast_share\x18\x0b \x01(\x08\x12\x0e\n\x06r_type\x18\x0c \x01(\x05\x12\x10\n\x08\x64yn_type\x18\r \x01(\x03\x12\x0b\n\x03uid\x18\x0e \x01(\x03\x12\x10\n\x08\x63\x61rd_url\x18\x0f \x01(\t\x12,\n\x0esource_content\x18\x10 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x11\n\torig_face\x18\x11 \x01(\t\x12\x33\n\x05reply\x18\x12 \x01(\x0b\x32$.bilibili.app.dynamic.v2.ExtendReply\x12\x10\n\x08track_id\x18\x13 \x01(\t\x12@\n\x0copus_summary\x18\x14 \x01(\x0b\x32*.bilibili.app.dynamic.v2.ModuleOpusSummary\x12\x45\n\x12only_fans_property\x18\x15 \x01(\x0b\x32).bilibili.app.dynamic.v2.OnlyFansProperty\x12=\n\x0c\x66\x65\x61ture_gate\x18\x16 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.DynFeatureGate\x12\x13\n\x0bis_in_audit\x18\x17 \x01(\x08\x12J\n\x0ehistory_report\x18\x18 \x03(\x0b\x32\x32.bilibili.app.dynamic.v2.Extend.HistoryReportEntry\x1a\x34\n\x12HistoryReportEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n\x0b\x45xtendReply\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x39\n\x06params\x18\x02 \x03(\x0b\x32).bilibili.app.dynamic.v2.ExtendReplyParam\".\n\x10\x45xtendReplyParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xe2\x01\n\rExtInfoCommon\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x10\n\x08poi_type\x18\x04 \x01(\x05\x12\x34\n\x04type\x18\x05 \x01(\x0e\x32&.bilibili.app.dynamic.v2.DynExtendType\x12\x12\n\nsub_module\x18\x06 \x01(\t\x12\x13\n\x0b\x61\x63tion_text\x18\x07 \x01(\t\x12\x12\n\naction_url\x18\x08 \x01(\t\x12\x0b\n\x03rid\x18\t \x01(\x03\x12\x15\n\ris_show_light\x18\n \x01(\x08\"7\n\x0b\x45xtInfoGame\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"6\n\nExtInfoHot\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"H\n\nExtInfoLBS\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x10\n\x08poi_type\x18\x04 \x01(\x05\"@\n\nExtInfoOGV\x12\x32\n\x08info_ogv\x18\x01 \x03(\x0b\x32 .bilibili.app.dynamic.v2.InfoOGV\"8\n\x0c\x45xtInfoTopic\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"g\n\x0f\x46\x65\x65\x64\x46ilterReply\x12\x0e\n\x06offset\x18\x01 \x01(\t\x12\x10\n\x08has_more\x18\x02 \x01(\x08\x12\x32\n\x04list\x18\x03 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"\xdb\x01\n\rFeedFilterReq\x12\x0e\n\x06offset\x18\x01 \x01(\t\x12\x0b\n\x03tab\x18\x02 \x01(\t\x12\x12\n\nlocal_time\x18\x03 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x32\n\x08\x61\x64_param\x18\x05 \x01(\x0b\x32 .bilibili.app.dynamic.v2.AdParam\x12\x12\n\ncold_start\x18\x06 \x01(\x05\x12\x0c\n\x04page\x18\x07 \x01(\x03\"&\n\x14\x46\x65tchTabSettingReply\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x9e\x01\n\x0e\x46ollowListItem\x12\x11\n\tseason_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12.\n\x06new_ep\x18\x05 \x01(\x0b\x32\x1e.bilibili.app.dynamic.v2.NewEP\x12\x11\n\tsub_title\x18\x06 \x01(\t\x12\x0b\n\x03pos\x18\x07 \x01(\x03\"\xcf\x02\n\tGoodsItem\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x1b\n\x13schema_package_name\x18\x02 \x01(\t\x12\x13\n\x0bsource_type\x18\x03 \x01(\x05\x12\x10\n\x08jump_url\x18\x04 \x01(\t\x12\x11\n\tjump_desc\x18\x05 \x01(\t\x12\r\n\x05title\x18\x06 \x01(\t\x12\r\n\x05\x62rief\x18\x07 \x01(\t\x12\r\n\x05price\x18\x08 \x01(\t\x12\x0f\n\x07item_id\x18\t \x01(\x03\x12\x12\n\nschema_url\x18\n \x01(\t\x12\x17\n\x0fopen_white_list\x18\x0b \x03(\t\x12\x13\n\x0buser_web_v2\x18\x0c \x01(\x08\x12\x0f\n\x07\x61\x64_mark\x18\r \x01(\t\x12\x10\n\x08\x61pp_name\x18\x0e \x01(\t\x12\x39\n\tjump_type\x18\x0f \x01(\x0e\x32&.bilibili.app.dynamic.v2.GoodsJumpType\"t\n\x0cGuideBarInfo\x12\x0c\n\x04show\x18\x01 \x01(\x05\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x10\n\x08position\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\x11\n\tjump_page\x18\x05 \x01(\x05\x12\x15\n\rjump_position\x18\x06 \x01(\x05\"~\n\rHighlightText\x12\x0c\n\x04text\x18\x01 \x01(\t\x12?\n\ntext_style\x18\x02 \x01(\x0e\x32+.bilibili.app.dynamic.v2.HighlightTextStyle\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\t\"$\n\x12HomeSubscribeReply\x12\x0e\n\x06online\x18\x01 \x01(\x05\":\n\x10HomeSubscribeReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\".\n\tIconBadge\x12\x13\n\x0bicon_bg_url\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"R\n\nIconButton\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x11\n\ticon_head\x18\x02 \x01(\t\x12\x11\n\ticon_tail\x18\x03 \x01(\t\x12\x10\n\x08jump_uri\x18\x04 \x01(\t\"-\n\x08ImageSet\x12\x0f\n\x07img_day\x18\x01 \x01(\t\x12\x10\n\x08img_dark\x18\x02 \x01(\t\"]\n\x0cImgInlineCfg\x12\r\n\x05width\x18\x01 \x01(\x01\x12\x0e\n\x06height\x18\x02 \x01(\x01\x12.\n\x05\x63olor\x18\x03 \x01(\x0b\x32\x1f.bilibili.app.dynamic.v2.Colors\"G\n\x07InfoOGV\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x12\n\nsub_module\x18\x04 \x01(\t\",\n\x0fInteractionFace\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\"\xb5\x02\n\x0fInteractionItem\x12\x39\n\ticon_type\x18\x01 \x01(\x0e\x32&.bilibili.app.dynamic.v2.LocalIconType\x12\x32\n\x04\x64\x65sc\x18\x02 \x03(\x0b\x32$.bilibili.app.dynamic.v2.Description\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x12\n\ndynamic_id\x18\x04 \x01(\t\x12\x13\n\x0b\x63omment_mid\x18\x06 \x01(\x03\x12\x37\n\x05\x66\x61\x63\x65s\x18\x07 \x03(\x0b\x32(.bilibili.app.dynamic.v2.InteractionFace\x12\x36\n\x04stat\x18\x08 \x01(\x0b\x32(.bilibili.app.dynamic.v2.InteractionStat\x12\x0c\n\x04icon\x18\t \x01(\t\"\x1f\n\x0fInteractionStat\x12\x0c\n\x04like\x18\x01 \x01(\x03\"j\n\x0cLbsPoiDetail\x12\x0b\n\x03poi\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\x03\x12\x10\n\x08\x62\x61se_pic\x18\x03 \x03(\t\x12\r\n\x05\x63over\x18\x04 \x03(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x05 \x01(\t\x12\r\n\x05title\x18\x06 \x01(\t\"\x9a\x01\n\x0bLbsPoiReply\x12\x10\n\x08has_more\x18\x01 \x01(\x08\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x35\n\x06\x64\x65tail\x18\x03 \x01(\x0b\x32%.bilibili.app.dynamic.v2.LbsPoiDetail\x12\x32\n\x04list\x18\x04 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"\xa5\x01\n\tLbsPoiReq\x12\x0b\n\x03poi\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\x03\x12\x0e\n\x06offset\x18\x03 \x01(\t\x12\x14\n\x0crefresh_type\x18\x04 \x01(\x05\x12\x12\n\nlocal_time\x18\x05 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x06 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"\xeb\x01\n\x14LegacyTopicFeedReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x10\n\x08has_more\x18\x02 \x01(\x08\x12\x0e\n\x06offset\x18\x03 \x01(\t\x12?\n\x14supported_sort_types\x18\x04 \x03(\x0b\x32!.bilibili.app.dynamic.v2.SortType\x12<\n\x11\x66\x65\x65\x64_card_filters\x18\x05 \x03(\x0b\x32!.bilibili.app.dynamic.v2.SortType\"\xb8\x01\n\x12LegacyTopicFeedReq\x12\x10\n\x08topic_id\x18\x01 \x01(\x03\x12\x12\n\ntopic_name\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\t\x12\x34\n\tsort_type\x18\x04 \x01(\x0b\x32!.bilibili.app.dynamic.v2.SortType\x12\x36\n\x0b\x63\x61rd_filter\x18\x05 \x01(\x0b\x32!.bilibili.app.dynamic.v2.SortType\"O\n\rLikeAnimation\x12\r\n\x05\x62\x65gin\x18\x01 \x01(\t\x12\x0c\n\x04proc\x18\x02 \x01(\t\x12\x0b\n\x03\x65nd\x18\x03 \x01(\t\x12\x14\n\x0clike_icon_id\x18\x04 \x01(\x03\"V\n\x08LikeInfo\x12\x39\n\tanimation\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v2.LikeAnimation\x12\x0f\n\x07is_like\x18\x02 \x01(\x08\"k\n\rLikeListReply\x12\x33\n\x04list\x18\x01 \x03(\x0b\x32%.bilibili.app.dynamic.v2.ModuleAuthor\x12\x10\n\x08has_more\x18\x02 \x01(\x08\x12\x13\n\x0btotal_count\x18\x03 \x01(\x03\"b\n\x0bLikeListReq\x12\x12\n\ndynamic_id\x18\x01 \x01(\t\x12\x10\n\x08\x64yn_type\x18\x02 \x01(\x03\x12\x0b\n\x03rid\x18\x03 \x01(\x03\x12\x12\n\nuid_offset\x18\x04 \x01(\x03\x12\x0c\n\x04page\x18\x05 \x01(\x05\"3\n\x08LikeUser\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\r\n\x05uname\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"E\n\rLineParagraph\x12\x34\n\x03pic\x18\x01 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.MdlDynDrawItem\"\xb8\x02\n\x08LinkNode\x12\x11\n\tshow_text\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x13\n\x0bicon_suffix\x18\x04 \x01(\t\x12\x11\n\tlink_type\x18\x05 \x01(\t\x12=\n\x0elink_type_enum\x18\x06 \x01(\x0e\x32%.bilibili.app.dynamic.v2.LinkNodeType\x12\x0e\n\x06\x62iz_id\x18\x07 \x01(\t\x12\x11\n\ttimestamp\x18\x08 \x01(\x03\x12\x36\n\ngoods_item\x18\t \x01(\x0b\x32\".bilibili.app.dynamic.v2.GoodsItem\x12;\n\rnote_video_ts\x18\n \x01(\x0b\x32$.bilibili.app.dynamic.v2.NoteVideoTS\"b\n\x08LiveInfo\x12\x11\n\tis_living\x18\x01 \x01(\x05\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x36\n\nlive_state\x18\x03 \x01(\x0e\x32\".bilibili.app.dynamic.v2.LiveState\"=\n\x0bLivePendant\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\x12\n\npendant_id\x18\x03 \x01(\x03\"X\n\tMatchTeam\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\r\n\x05\x63olor\x18\x04 \x01(\t\x12\x13\n\x0bnight_color\x18\x05 \x01(\t\"\x8b\x01\n\x0cMdlDynApplet\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x11\n\tsub_title\x18\x05 \x01(\t\x12\r\n\x05\x63over\x18\x06 \x01(\t\x12\x0c\n\x04icon\x18\x07 \x01(\t\x12\r\n\x05label\x18\x08 \x01(\t\x12\x14\n\x0c\x62utton_title\x18\t \x01(\t\"\xd6\x06\n\rMdlDynArchive\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\x0c\n\x04\x61vid\x18\x07 \x01(\x03\x12\x0b\n\x03\x63id\x18\x08 \x01(\x03\x12\x36\n\nmedia_type\x18\t \x01(\x0e\x32\".bilibili.app.dynamic.v2.MediaType\x12\x35\n\tdimension\x18\n \x01(\x0b\x32\".bilibili.app.dynamic.v2.Dimension\x12\x32\n\x05\x62\x61\x64ge\x18\x0b \x03(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x10\n\x08\x63\x61n_play\x18\x0c \x01(\x08\x12\x31\n\x05stype\x18\r \x01(\x0e\x32\".bilibili.app.dynamic.v2.VideoType\x12\r\n\x05isPGC\x18\x0e \x01(\x08\x12\x11\n\tinlineURL\x18\x0f \x01(\t\x12\x11\n\tEpisodeId\x18\x10 \x01(\x03\x12\x0f\n\x07SubType\x18\x11 \x01(\x05\x12\x13\n\x0bPgcSeasonId\x18\x12 \x01(\x03\x12\x11\n\tplay_icon\x18\x13 \x01(\t\x12\x10\n\x08\x64uration\x18\x14 \x01(\x03\x12\x10\n\x08jump_url\x18\x15 \x01(\t\x12\x12\n\nis_preview\x18\x16 \x01(\x08\x12;\n\x0e\x62\x61\x64ge_category\x18\x17 \x03(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x12\n\nis_feature\x18\x18 \x01(\x08\x12:\n\x0creserve_type\x18\x19 \x01(\x0e\x32$.bilibili.app.dynamic.v2.ReserveType\x12\x0c\n\x04\x62vid\x18\x1a \x01(\t\x12\x0c\n\x04view\x18\x1b \x01(\x05\x12\x1b\n\x13show_premiere_badge\x18\x1c \x01(\x08\x12\x15\n\rpremiere_card\x18\x1d \x01(\x08\x12\x15\n\rshow_progress\x18\x1e \x01(\x08\x12\x15\n\rpart_duration\x18\x1f \x01(\x03\x12\x15\n\rpart_progress\x18  \x01(\x03\"x\n\rMdlDynArticle\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\x0e\n\x06\x63overs\x18\x05 \x03(\t\x12\r\n\x05label\x18\x06 \x01(\t\x12\x12\n\ntemplateID\x18\x07 \x01(\x05\"\xaf\x02\n\x0cMdlDynCommon\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\r\n\x05label\x18\x06 \x01(\t\x12\x0f\n\x07\x62izType\x18\x07 \x01(\x05\x12\x10\n\x08sketchID\x18\x08 \x01(\x03\x12\x38\n\x05style\x18\t \x01(\x0e\x32).bilibili.app.dynamic.v2.MdlDynCommonType\x12\x32\n\x05\x62\x61\x64ge\x18\n \x03(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x39\n\x06\x62utton\x18\x0b \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionalButton\"\xe8\x02\n\x0fMdlDynCourBatch\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0e\n\x06text_1\x18\x04 \x01(\t\x12\x0e\n\x06text_2\x18\x05 \x01(\t\x12\x32\n\x05\x62\x61\x64ge\x18\x06 \x01(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x11\n\tplay_icon\x18\x07 \x01(\t\x12\x10\n\x08\x63\x61n_play\x18\x08 \x01(\x08\x12\x12\n\nis_preview\x18\t \x01(\x08\x12\x19\n\x11\x63over_left_text_1\x18\n \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x0b \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x0c \x01(\t\x12\x0c\n\x04\x61vid\x18\r \x01(\x03\x12\x0b\n\x03\x63id\x18\x0e \x01(\x03\x12\x0c\n\x04\x65pid\x18\x0f \x01(\x03\x12\x10\n\x08\x64uration\x18\x10 \x01(\x03\x12\x11\n\tseason_id\x18\x11 \x01(\x03\"\x96\x02\n\x10MdlDynCourSeason\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0e\n\x06text_1\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\t\x12\x32\n\x05\x62\x61\x64ge\x18\x06 \x01(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x11\n\tplay_icon\x18\x07 \x01(\t\x12\x10\n\x08\x63\x61n_play\x18\x08 \x01(\x08\x12\x12\n\nis_preview\x18\t \x01(\x08\x12\x0c\n\x04\x61vid\x18\n \x01(\x03\x12\x0b\n\x03\x63id\x18\x0b \x01(\x03\x12\x0c\n\x04\x65pid\x18\x0c \x01(\x03\x12\x10\n\x08\x64uration\x18\r \x01(\x03\x12\x11\n\tseason_id\x18\x0e \x01(\x03\"\x92\x02\n\x0cMdlDynCourUp\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\x12\x0e\n\x06text_1\x18\x05 \x01(\t\x12\x32\n\x05\x62\x61\x64ge\x18\x06 \x01(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x11\n\tplay_icon\x18\x07 \x01(\t\x12\x10\n\x08\x63\x61n_play\x18\x08 \x01(\x08\x12\x12\n\nis_preview\x18\t \x01(\x08\x12\x0c\n\x04\x61vid\x18\n \x01(\x03\x12\x0b\n\x03\x63id\x18\x0b \x01(\x03\x12\x0c\n\x04\x65pid\x18\x0c \x01(\x03\x12\x10\n\x08\x64uration\x18\r \x01(\x03\x12\x11\n\tseason_id\x18\x0e \x01(\x03\"\xa4\x01\n\nMdlDynDraw\x12\x36\n\x05items\x18\x01 \x03(\x0b\x32\'.bilibili.app.dynamic.v2.MdlDynDrawItem\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\x03\x12\x15\n\ris_draw_first\x18\x04 \x01(\x08\x12\x14\n\x0cis_big_cover\x18\x05 \x01(\x08\x12\x18\n\x10is_article_cover\x18\x06 \x01(\x08\"\x80\x01\n\x0eMdlDynDrawItem\x12\x0b\n\x03src\x18\x01 \x01(\t\x12\r\n\x05width\x18\x02 \x01(\x03\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x0c\n\x04size\x18\x04 \x01(\x02\x12\x34\n\x04tags\x18\x05 \x03(\x0b\x32&.bilibili.app.dynamic.v2.MdlDynDrawTag\"\x83\x01\n\rMdlDynDrawTag\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32*.bilibili.app.dynamic.v2.MdlDynDrawTagType\x12\x38\n\x04item\x18\x02 \x01(\x0b\x32*.bilibili.app.dynamic.v2.MdlDynDrawTagItem\"\xb5\x01\n\x11MdlDynDrawTagItem\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\t\n\x01x\x18\x03 \x01(\x03\x12\t\n\x01y\x18\x04 \x01(\x03\x12\x13\n\x0borientation\x18\x05 \x01(\x05\x12\x0e\n\x06source\x18\x06 \x01(\x05\x12\x0f\n\x07item_id\x18\x07 \x01(\x03\x12\x0b\n\x03mid\x18\x08 \x01(\x03\x12\x0b\n\x03tid\x18\t \x01(\x03\x12\x0b\n\x03poi\x18\n \x01(\t\x12\x12\n\nschema_url\x18\x0b \x01(\t\"R\n\rMdlDynForward\x12\x32\n\x04item\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\r\n\x05rtype\x18\x02 \x01(\x05\"\x96\x02\n\nMdlDynLive\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\x13\n\x0b\x63over_label\x18\x05 \x01(\t\x12\x14\n\x0c\x63over_label2\x18\x06 \x01(\t\x12\x36\n\nlive_state\x18\x07 \x01(\x0e\x32\".bilibili.app.dynamic.v2.LiveState\x12\x32\n\x05\x62\x61\x64ge\x18\x08 \x01(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12:\n\x0creserve_type\x18\t \x01(\x0e\x32$.bilibili.app.dynamic.v2.ReserveType\"\x94\x01\n\x0eMdlDynLiveRcmd\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12:\n\x0creserve_type\x18\x02 \x01(\x0e\x32$.bilibili.app.dynamic.v2.ReserveType\x12\x35\n\x07pendant\x18\x03 \x01(\x0b\x32$.bilibili.app.dynamic.v2.LivePendant\"\xa3\x01\n\x0fMdlDynMedialist\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x11\n\tsub_title\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x12\n\ncover_type\x18\x06 \x01(\x05\x12\x32\n\x05\x62\x61\x64ge\x18\x07 \x01(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\"r\n\x0bMdlDynMusic\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05up_id\x18\x03 \x01(\x03\x12\r\n\x05title\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x0e\n\x06label1\x18\x06 \x01(\t\x12\r\n\x05upper\x18\x07 \x01(\t\"\x80\x05\n\tMdlDynPGC\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\x0b\n\x03\x63id\x18\x07 \x01(\x03\x12\x11\n\tseason_id\x18\x08 \x01(\x03\x12\x0c\n\x04\x65pid\x18\t \x01(\x03\x12\x0b\n\x03\x61id\x18\n \x01(\x03\x12\x36\n\nmedia_type\x18\x0b \x01(\x0e\x32\".bilibili.app.dynamic.v2.MediaType\x12\x37\n\x08sub_type\x18\x0c \x01(\x0e\x32%.bilibili.app.dynamic.v2.VideoSubType\x12\x12\n\nis_preview\x18\r \x01(\x08\x12\x35\n\tdimension\x18\x0e \x01(\x0b\x32\".bilibili.app.dynamic.v2.Dimension\x12\x32\n\x05\x62\x61\x64ge\x18\x0f \x03(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x10\n\x08\x63\x61n_play\x18\x10 \x01(\x08\x12\x32\n\x06season\x18\x11 \x01(\x0b\x32\".bilibili.app.dynamic.v2.PGCSeason\x12\x11\n\tplay_icon\x18\x12 \x01(\t\x12\x10\n\x08\x64uration\x18\x13 \x01(\x03\x12\x10\n\x08jump_url\x18\x14 \x01(\t\x12;\n\x0e\x62\x61\x64ge_category\x18\x15 \x03(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x12\n\nis_feature\x18\x16 \x01(\x08\"\xae\x01\n\x12MdlDynSubscription\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05\x61\x64_id\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x10\n\x08\x61\x64_title\x18\x06 \x01(\t\x12\x32\n\x05\x62\x61\x64ge\x18\x07 \x01(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x0c\n\x04tips\x18\x08 \x01(\t\"\xee\x01\n\x15MdlDynSubscriptionNew\x12\x42\n\x05style\x18\x01 \x01(\x0e\x32\x33.bilibili.app.dynamic.v2.MdlDynSubscriptionNewStyle\x12G\n\x10\x64yn_subscription\x18\x02 \x01(\x0b\x32+.bilibili.app.dynamic.v2.MdlDynSubscriptionH\x00\x12@\n\rdyn_live_rcmd\x18\x03 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.MdlDynLiveRcmdH\x00\x42\x06\n\x04item\"\xa2\x01\n\x0eMdlDynTopicSet\x12\x32\n\x06topics\x18\x01 \x03(\x0b\x32\".bilibili.app.dynamic.v2.TopicItem\x12\x35\n\x08more_btn\x18\x02 \x01(\x0b\x32#.bilibili.app.dynamic.v2.IconButton\x12\x14\n\x0ctopic_set_id\x18\x03 \x01(\x03\x12\x0f\n\x07push_id\x18\x04 \x01(\x03\"\xc7\x02\n\x0fMdlDynUGCSeason\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\x03\x12\x11\n\tinlineURL\x18\x08 \x01(\t\x12\x10\n\x08\x63\x61n_play\x18\t \x01(\x08\x12\x11\n\tplay_icon\x18\n \x01(\t\x12\x0c\n\x04\x61vid\x18\x0b \x01(\x03\x12\x0b\n\x03\x63id\x18\x0c \x01(\x03\x12\x35\n\tdimension\x18\r \x01(\x0b\x32\".bilibili.app.dynamic.v2.Dimension\x12\x10\n\x08\x64uration\x18\x0e \x01(\x03\x12\x10\n\x08jump_url\x18\x0f \x01(\t\"\xeb\x02\n\rMixUpListItem\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x19\n\x11special_attention\x18\x02 \x01(\x05\x12\x14\n\x0creddot_state\x18\x03 \x01(\x05\x12=\n\tlive_info\x18\x04 \x01(\x0b\x32*.bilibili.app.dynamic.v2.MixUpListLiveItem\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x06 \x01(\t\x12\x39\n\x08official\x18\x07 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.OfficialVerify\x12-\n\x03vip\x18\x08 \x01(\x0b\x32 .bilibili.app.dynamic.v2.VipInfo\x12\x33\n\x08relation\x18\t \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\x12\x15\n\rpermire_state\x18\n \x01(\x05\x12\x0b\n\x03uri\x18\x0b \x01(\t\"A\n\x11MixUpListLiveItem\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x0f\n\x07room_id\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\xc6\x12\n\x06Module\x12;\n\x0bmodule_type\x18\x01 \x01(\x0e\x32&.bilibili.app.dynamic.v2.DynModuleType\x12>\n\rmodule_author\x18\x02 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ModuleAuthorH\x00\x12@\n\x0emodule_dispute\x18\x03 \x01(\x0b\x32&.bilibili.app.dynamic.v2.ModuleDisputeH\x00\x12:\n\x0bmodule_desc\x18\x04 \x01(\x0b\x32#.bilibili.app.dynamic.v2.ModuleDescH\x00\x12@\n\x0emodule_dynamic\x18\x05 \x01(\x0b\x32&.bilibili.app.dynamic.v2.ModuleDynamicH\x00\x12\x42\n\x0fmodule_likeUser\x18\x06 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.ModuleLikeUserH\x00\x12>\n\rmodule_extend\x18\x07 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ModuleExtendH\x00\x12\x46\n\x11module_additional\x18\x08 \x01(\x0b\x32).bilibili.app.dynamic.v2.ModuleAdditionalH\x00\x12:\n\x0bmodule_stat\x18\t \x01(\x0b\x32#.bilibili.app.dynamic.v2.ModuleStatH\x00\x12:\n\x0bmodule_fold\x18\n \x01(\x0b\x32#.bilibili.app.dynamic.v2.ModuleFoldH\x00\x12@\n\x0emodule_comment\x18\x0b \x01(\x0b\x32&.bilibili.app.dynamic.v2.ModuleCommentH\x00\x12H\n\x12module_interaction\x18\x0c \x01(\x0b\x32*.bilibili.app.dynamic.v2.ModuleInteractionH\x00\x12M\n\x15module_author_forward\x18\r \x01(\x0b\x32,.bilibili.app.dynamic.v2.ModuleAuthorForwardH\x00\x12\x36\n\tmodule_ad\x18\x0e \x01(\x0b\x32!.bilibili.app.dynamic.v2.ModuleAdH\x00\x12>\n\rmodule_banner\x18\x0f \x01(\x0b\x32%.bilibili.app.dynamic.v2.ModuleBannerH\x00\x12\x43\n\x10module_item_null\x18\x10 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.ModuleItemNullH\x00\x12\x45\n\x11module_share_info\x18\x11 \x01(\x0b\x32(.bilibili.app.dynamic.v2.ModuleShareInfoH\x00\x12\x44\n\x10module_recommend\x18\x12 \x01(\x0b\x32(.bilibili.app.dynamic.v2.ModuleRecommendH\x00\x12\x38\n\nmodule_top\x18\x13 \x01(\x0b\x32\".bilibili.app.dynamic.v2.ModuleTopH\x00\x12>\n\rmodule_buttom\x18\x14 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ModuleButtomH\x00\x12\x42\n\x13module_stat_forward\x18\x15 \x01(\x0b\x32#.bilibili.app.dynamic.v2.ModuleStatH\x00\x12<\n\x0cmodule_story\x18\x16 \x01(\x0b\x32$.bilibili.app.dynamic.v2.ModuleStoryH\x00\x12<\n\x0cmodule_topic\x18\x17 \x01(\x0b\x32$.bilibili.app.dynamic.v2.ModuleTopicH\x00\x12R\n\x18module_topic_details_ext\x18\x18 \x01(\x0b\x32..bilibili.app.dynamic.v2.ModuleTopicDetailsExtH\x00\x12?\n\x0emodule_top_tag\x18\x19 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ModuleTopTagH\x00\x12G\n\x12module_topic_brief\x18\x1a \x01(\x0b\x32).bilibili.app.dynamic.v2.ModuleTopicBriefH\x00\x12<\n\x0cmodule_title\x18\x1b \x01(\x0b\x32$.bilibili.app.dynamic.v2.ModuleTitleH\x00\x12>\n\rmodule_button\x18\x1c \x01(\x0b\x32%.bilibili.app.dynamic.v2.ModuleButtonH\x00\x12>\n\rmodule_notice\x18\x1d \x01(\x0b\x32%.bilibili.app.dynamic.v2.ModuleNoticeH\x00\x12I\n\x13module_opus_summary\x18\x1e \x01(\x0b\x32*.bilibili.app.dynamic.v2.ModuleOpusSummaryH\x00\x12\x44\n\x10module_copyright\x18\x1f \x01(\x0b\x32(.bilibili.app.dynamic.v2.ModuleCopyrightH\x00\x12\x44\n\x10module_paragraph\x18  \x01(\x0b\x32(.bilibili.app.dynamic.v2.ModuleParagraphH\x00\x12@\n\x0emodule_blocked\x18! \x01(\x0b\x32&.bilibili.app.dynamic.v2.ModuleBlockedH\x00\x12G\n\x12module_text_notice\x18\" \x01(\x0b\x32).bilibili.app.dynamic.v2.ModuleTextNoticeH\x00\x12O\n\x16module_opus_collection\x18# \x01(\x0b\x32-.bilibili.app.dynamic.v2.ModuleOpusCollectionH\x00\x42\r\n\x0bmodule_item\"\xdd\x01\n\x08ModuleAd\x12,\n\x0esource_content\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12<\n\rmodule_author\x18\x02 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ModuleAuthor\x12\x17\n\x0f\x61\x64_content_type\x18\x03 \x01(\x05\x12\x18\n\x10\x63over_left_text1\x18\x04 \x01(\t\x12\x18\n\x10\x63over_left_text2\x18\x05 \x01(\t\x12\x18\n\x10\x63over_left_text3\x18\x06 \x01(\t\"\xb1\x05\n\x10ModuleAdditional\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.bilibili.app.dynamic.v2.AdditionalType\x12\x35\n\x03pgc\x18\x02 \x01(\x0b\x32&.bilibili.app.dynamic.v2.AdditionalPGCH\x00\x12\x37\n\x05goods\x18\x03 \x01(\x0b\x32&.bilibili.app.dynamic.v2.AdditionGoodsH\x00\x12\x35\n\x04vote\x18\x04 \x01(\x0b\x32%.bilibili.app.dynamic.v2.AdditionVoteH\x00\x12\x39\n\x06\x63ommon\x18\x05 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.AdditionCommonH\x00\x12\x39\n\x06\x65sport\x18\x06 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.AdditionEsportH\x00\x12\x37\n\x05vote2\x18\x08 \x01(\x0b\x32&.bilibili.app.dynamic.v2.AdditionVote2H\x00\x12\x33\n\x03ugc\x18\t \x01(\x0b\x32$.bilibili.app.dynamic.v2.AdditionUgcH\x00\x12\x31\n\x02up\x18\n \x01(\x0b\x32#.bilibili.app.dynamic.v2.AdditionUPH\x00\x12;\n\x07\x61rticle\x18\x0c \x01(\x0b\x32(.bilibili.app.dynamic.v2.AdditionArticleH\x00\x12\x39\n\x04live\x18\r \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionLiveRoomH\x00\x12\x0b\n\x03rid\x18\x07 \x01(\x03\x12\x1b\n\x13need_write_calender\x18\x0b \x01(\x08\x42\x06\n\x04item\"\xfb\x04\n\x0cModuleAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x18\n\x10ptime_label_text\x18\x02 \x01(\t\x12\x31\n\x06\x61uthor\x18\x03 \x01(\x0b\x32!.bilibili.app.dynamic.v2.UserInfo\x12<\n\rdecorate_card\x18\x04 \x01(\x0b\x32%.bilibili.app.dynamic.v2.DecorateCard\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x38\n\x07tp_list\x18\x06 \x03(\x0b\x32\'.bilibili.app.dynamic.v2.ThreePointItem\x12\x42\n\nbadge_type\x18\x07 \x01(\x0e\x32..bilibili.app.dynamic.v2.ModuleAuthorBadgeType\x12\x46\n\x0c\x62\x61\x64ge_button\x18\x08 \x01(\x0b\x32\x30.bilibili.app.dynamic.v2.ModuleAuthorBadgeButton\x12\x0e\n\x06\x61ttend\x18\t \x01(\x05\x12\x33\n\x08relation\x18\n \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\x12/\n\x06weight\x18\x0b \x01(\x0b\x32\x1f.bilibili.app.dynamic.v2.Weight\x12\x13\n\x0bshow_follow\x18\x0c \x01(\x08\x12\x0e\n\x06is_top\x18\r \x01(\x08\x12\x1b\n\x13ptime_location_text\x18\x0e \x01(\t\x12\x12\n\nshow_level\x18\x0f \x01(\x08\x12\x34\n\tonly_fans\x18\x10 \x01(\x0b\x32!.bilibili.app.dynamic.v2.OnlyFans\"Q\n\x17ModuleAuthorBadgeButton\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\x05\x12\n\n\x02id\x18\x04 \x01(\x03\"\xa1\x02\n\x13ModuleAuthorForward\x12@\n\x05title\x18\x01 \x03(\x0b\x32\x31.bilibili.app.dynamic.v2.ModuleAuthorForwardTitle\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x18\n\x10ptime_label_text\x18\x04 \x01(\t\x12\x13\n\x0bshow_follow\x18\x05 \x01(\x08\x12\x10\n\x08\x66\x61\x63\x65_url\x18\x06 \x01(\t\x12\x33\n\x08relation\x18\x07 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\x12\x38\n\x07tp_list\x18\x08 \x03(\x0b\x32\'.bilibili.app.dynamic.v2.ThreePointItem\"5\n\x18ModuleAuthorForwardTitle\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"\xc5\x01\n\x0cModuleBanner\x12\r\n\x05title\x18\x01 \x01(\t\x12\x37\n\x04type\x18\x02 \x01(\x0e\x32).bilibili.app.dynamic.v2.ModuleBannerType\x12\x39\n\x04user\x18\x03 \x01(\x0b\x32).bilibili.app.dynamic.v2.ModuleBannerUserH\x00\x12\x14\n\x0c\x64islike_text\x18\x04 \x01(\t\x12\x14\n\x0c\x64islike_icon\x18\x05 \x01(\tB\x06\n\x04item\"O\n\x10ModuleBannerUser\x12;\n\x04list\x18\x01 \x03(\x0b\x32-.bilibili.app.dynamic.v2.ModuleBannerUserItem\"\xed\x02\n\x14ModuleBannerUserItem\x12\x0c\n\x04\x66\x61\x63\x65\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x36\n\nlive_state\x18\x04 \x01(\x0e\x32\".bilibili.app.dynamic.v2.LiveState\x12\x39\n\x08official\x18\x05 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.OfficialVerify\x12-\n\x03vip\x18\x06 \x01(\x0b\x32 .bilibili.app.dynamic.v2.VipInfo\x12\r\n\x05label\x18\x07 \x01(\t\x12\x39\n\x06\x62utton\x18\x08 \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionalButton\x12\x0b\n\x03uri\x18\t \x01(\t\x12\x33\n\x08relation\x18\n \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\"\x82\x04\n\rModuleBlocked\x12/\n\x04icon\x18\x01 \x01(\x0b\x32!.bilibili.app.dynamic.v2.ImageSet\x12\x31\n\x06\x62g_img\x18\x02 \x01(\x0b\x32!.bilibili.app.dynamic.v2.ImageSet\x12\x14\n\x0chint_message\x18\x03 \x01(\t\x12\x34\n\x07\x61\x63t_btn\x18\x04 \x01(\x0b\x32#.bilibili.app.dynamic.v2.IconButton\x12=\n\x0b\x62lock_style\x18\x05 \x01(\x0e\x32(.bilibili.app.dynamic.v2.MdlBlockedStyle\x12\x18\n\x10sub_hint_message\x18\x06 \x01(\t\x12\x45\n\x17video_bottom_text_upper\x18\x07 \x01(\x0b\x32$.bilibili.app.dynamic.v2.OneLineText\x12\x45\n\x17video_bottom_text_lower\x18\x08 \x01(\x0b\x32$.bilibili.app.dynamic.v2.OneLineText\x12\x15\n\rarchive_title\x18\t \x01(\t\x12\x43\n\x15hint_message_one_line\x18\n \x01(\x0b\x32$.bilibili.app.dynamic.v2.OneLineText\"\xec\x02\n\x0cModuleButtom\x12\x38\n\x0bmodule_stat\x18\x01 \x01(\x0b\x32#.bilibili.app.dynamic.v2.ModuleStat\x12\x13\n\x0b\x63omment_box\x18\x02 \x01(\x08\x12\x17\n\x0f\x63omment_box_msg\x18\x03 \x01(\t\x12P\n\x11interaction_icons\x18\x04 \x03(\x0e\x32\x35.bilibili.app.dynamic.v2.ModuleButtom.InteractionIcon\x12\x37\n\x05\x66\x61\x63\x65s\x18\x05 \x03(\x0b\x32(.bilibili.app.dynamic.v2.InteractionFace\"i\n\x0fInteractionIcon\x12\x10\n\x0cICON_INVALID\x10\x00\x12\x10\n\x0cICON_FORWARD\x10\x01\x12\x10\n\x0cICON_COMMENT\x10\x02\x12\x11\n\rICON_FAVORITE\x10\x03\x12\r\n\tICON_LIKE\x10\x04\"@\n\x0cModuleButton\x12\x30\n\x03\x62tn\x18\x01 \x01(\x0b\x32#.bilibili.app.dynamic.v2.IconButton\"J\n\rModuleComment\x12\x39\n\x0b\x63mtShowItem\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.CmtShowItem\"8\n\x0fModuleCopyright\x12\x11\n\tleft_text\x18\x01 \x01(\t\x12\x12\n\nright_text\x18\x02 \x01(\t\"`\n\nModuleDesc\x12\x32\n\x04\x64\x65sc\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.Description\x12\x10\n\x08jump_uri\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\"\xde\x01\n\x0fModuleDescGoods\x12\x13\n\x0bsource_type\x18\x01 \x01(\x05\x12\x10\n\x08jump_url\x18\x02 \x01(\t\x12\x12\n\nschema_url\x18\x03 \x01(\t\x12\x0f\n\x07item_id\x18\x04 \x01(\x03\x12\x17\n\x0fopen_white_list\x18\x05 \x03(\t\x12\x13\n\x0buser_web_v2\x18\x06 \x01(\x08\x12\x0f\n\x07\x61\x64_mark\x18\x07 \x01(\t\x12\x1b\n\x13schema_package_name\x18\x08 \x01(\t\x12\x11\n\tjump_type\x18\t \x01(\x05\x12\x10\n\x08\x61pp_name\x18\n \x01(\t\"9\n\rModuleDispute\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\xec\t\n\rModuleDynamic\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32*.bilibili.app.dynamic.v2.ModuleDynamicType\x12=\n\x0b\x64yn_archive\x18\x02 \x01(\x0b\x32&.bilibili.app.dynamic.v2.MdlDynArchiveH\x00\x12\x35\n\x07\x64yn_pgc\x18\x03 \x01(\x0b\x32\".bilibili.app.dynamic.v2.MdlDynPGCH\x00\x12\x44\n\x0f\x64yn_cour_season\x18\x04 \x01(\x0b\x32).bilibili.app.dynamic.v2.MdlDynCourSeasonH\x00\x12\x42\n\x0e\x64yn_cour_batch\x18\x05 \x01(\x0b\x32(.bilibili.app.dynamic.v2.MdlDynCourBatchH\x00\x12=\n\x0b\x64yn_forward\x18\x06 \x01(\x0b\x32&.bilibili.app.dynamic.v2.MdlDynForwardH\x00\x12\x37\n\x08\x64yn_draw\x18\x07 \x01(\x0b\x32#.bilibili.app.dynamic.v2.MdlDynDrawH\x00\x12=\n\x0b\x64yn_article\x18\x08 \x01(\x0b\x32&.bilibili.app.dynamic.v2.MdlDynArticleH\x00\x12\x39\n\tdyn_music\x18\t \x01(\x0b\x32$.bilibili.app.dynamic.v2.MdlDynMusicH\x00\x12;\n\ndyn_common\x18\n \x01(\x0b\x32%.bilibili.app.dynamic.v2.MdlDynCommonH\x00\x12>\n\x0f\x64yn_common_live\x18\x0b \x01(\x0b\x32#.bilibili.app.dynamic.v2.MdlDynLiveH\x00\x12\x41\n\rdyn_medialist\x18\x0c \x01(\x0b\x32(.bilibili.app.dynamic.v2.MdlDynMedialistH\x00\x12;\n\ndyn_applet\x18\r \x01(\x0b\x32%.bilibili.app.dynamic.v2.MdlDynAppletH\x00\x12G\n\x10\x64yn_subscription\x18\x0e \x01(\x0b\x32+.bilibili.app.dynamic.v2.MdlDynSubscriptionH\x00\x12@\n\rdyn_live_rcmd\x18\x0f \x01(\x0b\x32\'.bilibili.app.dynamic.v2.MdlDynLiveRcmdH\x00\x12\x42\n\x0e\x64yn_ugc_season\x18\x10 \x01(\x0b\x32(.bilibili.app.dynamic.v2.MdlDynUGCSeasonH\x00\x12N\n\x14\x64yn_subscription_new\x18\x11 \x01(\x0b\x32..bilibili.app.dynamic.v2.MdlDynSubscriptionNewH\x00\x12\x42\n\x11\x64yn_cour_batch_up\x18\x12 \x01(\x0b\x32%.bilibili.app.dynamic.v2.MdlDynCourUpH\x00\x12@\n\rdyn_topic_set\x18\x13 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.MdlDynTopicSetH\x00\x42\r\n\x0bmodule_item\"V\n\x0cModuleExtend\x12\x39\n\x06\x65xtend\x18\x01 \x03(\x0b\x32).bilibili.app.dynamic.v2.ModuleExtendItem\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xcc\x03\n\x10ModuleExtendItem\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.bilibili.app.dynamic.v2.DynExtendType\x12?\n\x0e\x65xt_info_topic\x18\x02 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ExtInfoTopicH\x00\x12;\n\x0c\x65xt_info_lbs\x18\x03 \x01(\x0b\x32#.bilibili.app.dynamic.v2.ExtInfoLBSH\x00\x12;\n\x0c\x65xt_info_hot\x18\x04 \x01(\x0b\x32#.bilibili.app.dynamic.v2.ExtInfoHotH\x00\x12=\n\rext_info_game\x18\x05 \x01(\x0b\x32$.bilibili.app.dynamic.v2.ExtInfoGameH\x00\x12\x41\n\x0f\x65xt_info_common\x18\x06 \x01(\x0b\x32&.bilibili.app.dynamic.v2.ExtInfoCommonH\x00\x12;\n\x0c\x65xt_info_ogv\x18\x07 \x01(\x0b\x32#.bilibili.app.dynamic.v2.ExtInfoOGVH\x00\x42\x08\n\x06\x65xtend\"\xe6\x01\n\nModuleFold\x12\x34\n\tfold_type\x18\x01 \x01(\x0e\x32!.bilibili.app.dynamic.v2.FoldType\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x10\n\x08\x66old_ids\x18\x03 \x01(\t\x12\x35\n\nfold_users\x18\x04 \x03(\x0b\x32!.bilibili.app.dynamic.v2.UserInfo\x12K\n\x15topic_merged_resource\x18\x05 \x01(\x0b\x32,.bilibili.app.dynamic.v2.TopicMergedResource\"W\n\x11ModuleInteraction\x12\x42\n\x10interaction_item\x18\x01 \x03(\x0b\x32(.bilibili.app.dynamic.v2.InteractionItem\",\n\x0eModuleItemNull\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"]\n\x0eModuleLikeUser\x12\x35\n\nlike_users\x18\x01 \x03(\x0b\x32!.bilibili.app.dynamic.v2.LikeUser\x12\x14\n\x0c\x64isplay_text\x18\x02 \x01(\t\"_\n\x0cModuleNotice\x12\x10\n\x08identity\x18\x01 \x01(\t\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x13\n\x0bnotice_type\x18\x05 \x01(\x05\"\xab\x01\n\x14ModuleOpusCollection\x12@\n\x0f\x63ollection_info\x18\x01 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.OpusCollection\x12\x13\n\x0btitle_upper\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x19\n\x11title_prefix_icon\x18\x04 \x01(\t\x12\x12\n\ntotal_text\x18\x05 \x01(\t\"\xd3\x01\n\x11ModuleOpusSummary\x12\x31\n\x05title\x18\x01 \x01(\x0b\x32\".bilibili.app.dynamic.v2.Paragraph\x12\x33\n\x07summary\x18\x02 \x01(\x0b\x32\".bilibili.app.dynamic.v2.Paragraph\x12\x1d\n\x15summary_jump_btn_text\x18\x03 \x01(\t\x12\x37\n\x06\x63overs\x18\x04 \x03(\x0b\x32\'.bilibili.app.dynamic.v2.MdlDynDrawItem\"\x9e\x01\n\x0fModuleParagraph\x12\x35\n\tparagraph\x18\x01 \x01(\x0b\x32\".bilibili.app.dynamic.v2.Paragraph\x12\x18\n\x10is_article_title\x18\x02 \x01(\x08\x12:\n\x0cpara_spacing\x18\x03 \x01(\x0b\x32$.bilibili.app.dynamic.v2.ParaSpacing\"\x88\x01\n\nModuleRcmd\x12\x33\n\x06\x61uthor\x18\x01 \x01(\x0b\x32#.bilibili.app.dynamic.v2.RcmdAuthor\x12\x30\n\x05items\x18\x02 \x03(\x0b\x32!.bilibili.app.dynamic.v2.RcmdItem\x12\x13\n\x0bserver_info\x18\x03 \x01(\t\"\x86\x01\n\x0fModuleRecommend\x12\x14\n\x0cmodule_title\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x10\n\x08jump_url\x18\x05 \x01(\t\x12 \n\x02\x61\x64\x18\x06 \x03(\x0b\x32\x14.google.protobuf.Any\"\x8f\x01\n\x0fModuleShareInfo\x12\r\n\x05title\x18\x01 \x01(\t\x12=\n\x0eshare_channels\x18\x02 \x03(\x0b\x32%.bilibili.app.dynamic.v2.ShareChannel\x12\x14\n\x0cshare_origin\x18\x03 \x01(\t\x12\x0b\n\x03oid\x18\x04 \x01(\t\x12\x0b\n\x03sid\x18\x05 \x01(\t\"\xdc\x01\n\nModuleStat\x12\x0e\n\x06repost\x18\x01 \x01(\x03\x12\x0c\n\x04like\x18\x02 \x01(\x03\x12\r\n\x05reply\x18\x03 \x01(\x03\x12\x34\n\tlike_info\x18\x04 \x01(\x0b\x32!.bilibili.app.dynamic.v2.LikeInfo\x12\x12\n\nno_comment\x18\x05 \x01(\x08\x12\x12\n\nno_forward\x18\x06 \x01(\x08\x12\x11\n\treply_url\x18\x07 \x01(\t\x12\x17\n\x0fno_comment_text\x18\x08 \x01(\t\x12\x17\n\x0fno_forward_text\x18\t \x01(\t\"\xb4\x01\n\x0bModuleStory\x12\r\n\x05title\x18\x01 \x01(\t\x12\x31\n\x05items\x18\x02 \x03(\x0b\x32\".bilibili.app.dynamic.v2.StoryItem\x12\x1d\n\x15show_publish_entrance\x18\x03 \x01(\x08\x12\x12\n\nfold_state\x18\x04 \x01(\x03\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\r\n\x05\x63over\x18\x06 \x01(\t\x12\x14\n\x0cpublish_text\x18\x07 \x01(\t\"H\n\x10ModuleTextNotice\x12\x34\n\x06notice\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.OneLineText\"i\n\x0bModuleTitle\x12\r\n\x05title\x18\x01 \x01(\t\x12\x36\n\tright_btn\x18\x02 \x01(\x0b\x32#.bilibili.app.dynamic.v2.IconButton\x12\x13\n\x0btitle_style\x18\x03 \x01(\x05\"\xcd\x01\n\tModuleTop\x12\x38\n\x07tp_list\x18\x01 \x03(\x0b\x32\'.bilibili.app.dynamic.v2.ThreePointItem\x12\x37\n\x07\x61rchive\x18\x02 \x01(\x0b\x32&.bilibili.app.dynamic.v2.MdlDynArchive\x12\x35\n\x06\x61uthor\x18\x03 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ModuleAuthor\x12\x16\n\x0ehidden_nav_bar\x18\x04 \x01(\x08\"4\n\x0bModuleTopic\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\"E\n\x10ModuleTopicBrief\x12\x31\n\x05topic\x18\x01 \x01(\x0b\x32\".bilibili.app.dynamic.v2.TopicItem\".\n\x15ModuleTopicDetailsExt\x12\x15\n\rcomment_guide\x18\x01 \x01(\t\" \n\x0cModuleTopTag\x12\x10\n\x08tag_name\x18\x01 \x01(\t\"l\n\tNameplate\x12\x0b\n\x03nid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x13\n\x0bimage_small\x18\x04 \x01(\t\x12\r\n\x05level\x18\x05 \x01(\t\x12\x11\n\tcondition\x18\x06 \x01(\t\"6\n\x05NewEP\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nindex_show\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\"\x9f\x01\n\x07NFTInfo\x12;\n\x0bregion_type\x18\x01 \x01(\x0e\x32&.bilibili.app.dynamic.v2.NFTRegionType\x12\x13\n\x0bregion_icon\x18\x02 \x01(\t\x12\x42\n\x12region_show_status\x18\x03 \x01(\x0e\x32&.bilibili.app.dynamic.v2.NFTShowStatus\"\t\n\x07NoReply\"\x07\n\x05NoReq\"\xa7\x01\n\x0bNoteVideoTS\x12\x0b\n\x03\x63id\x18\x01 \x01(\x03\x12\x10\n\x08oid_type\x18\x02 \x01(\x03\x12\x0e\n\x06status\x18\x03 \x01(\x03\x12\r\n\x05index\x18\x04 \x01(\x03\x12\x0f\n\x07seconds\x18\x05 \x01(\x03\x12\x11\n\tcid_count\x18\x06 \x01(\x03\x12\x0b\n\x03key\x18\x07 \x01(\t\x12\x0c\n\x04\x65pid\x18\t \x01(\x03\x12\r\n\x05title\x18\x08 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\n \x01(\t\"\xbf\x01\n\x13OfficialAccountInfo\x12\x31\n\x06\x61uthor\x18\x01 \x01(\x0b\x32!.bilibili.app.dynamic.v2.UserInfo\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x33\n\x08relation\x18\x04 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\x12\x12\n\ndesc_text1\x18\x05 \x01(\t\x12\x12\n\ndesc_text2\x18\x06 \x01(\t\"v\n\x15OfficialAccountsReply\x12;\n\x05items\x18\x01 \x03(\x0b\x32,.bilibili.app.dynamic.v2.OfficialAccountInfo\x12\x10\n\x08has_more\x18\x02 \x01(\x08\x12\x0e\n\x06offset\x18\x03 \x01(\x03\"M\n\x13OfficialAccountsReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x03\"\xb4\x01\n\x15OfficialDynamicsReply\x12\x34\n\x05items\x18\x01 \x03(\x0b\x32%.bilibili.app.dynamic.v2.OfficialItem\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"M\n\x13OfficialDynamicsReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x03\"\xb5\x01\n\x0cOfficialItem\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x44\n\x0crcmd_archive\x18\x02 \x01(\x0b\x32,.bilibili.app.dynamic.v2.OfficialRcmdArchiveH\x00\x12\x44\n\x0crcmd_dynamic\x18\x03 \x01(\x0b\x32,.bilibili.app.dynamic.v2.OfficialRcmdDynamicH\x00\x42\x0b\n\trcmd_item\"\x9d\x02\n\x13OfficialRcmdArchive\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x18\n\x10\x63over_right_text\x18\x03 \x01(\t\x12\x12\n\ndesc_icon1\x18\x04 \x01(\x05\x12\x12\n\ndesc_text1\x18\x05 \x01(\t\x12\x12\n\ndesc_icon2\x18\x06 \x01(\x05\x12\x12\n\ndesc_text2\x18\x07 \x01(\t\x12\x0e\n\x06reason\x18\x08 \x01(\t\x12\x18\n\x10show_three_point\x18\t \x01(\x08\x12\x0b\n\x03uri\x18\n \x01(\t\x12\x0b\n\x03\x61id\x18\x0b \x01(\x03\x12\x0b\n\x03mid\x18\x0c \x01(\x03\x12\x0c\n\x04name\x18\r \x01(\t\x12\x12\n\ndynamic_id\x18\x0e \x01(\x03\x12\x0b\n\x03\x63id\x18\x0f \x01(\x03\"\xff\x01\n\x13OfficialRcmdDynamic\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x1c\n\x14\x63over_right_top_text\x18\x03 \x01(\t\x12\x12\n\ndesc_icon1\x18\x04 \x01(\x05\x12\x12\n\ndesc_text1\x18\x05 \x01(\t\x12\x12\n\ndesc_icon2\x18\x06 \x01(\x05\x12\x12\n\ndesc_text2\x18\x07 \x01(\t\x12\x0e\n\x06reason\x18\x08 \x01(\t\x12\x0b\n\x03uri\x18\t \x01(\t\x12\x12\n\ndynamic_id\x18\n \x01(\x03\x12\x0b\n\x03mid\x18\x0b \x01(\x03\x12\x11\n\tuser_name\x18\x0c \x01(\t\x12\x0b\n\x03rid\x18\r \x01(\x03\">\n\x0eOfficialVerify\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x10\n\x08is_atten\x18\x03 \x01(\x05\"G\n\x0bOneLineText\x12\x38\n\x05texts\x18\x01 \x03(\x0b\x32).bilibili.app.dynamic.v2.TextWithPriority\"S\n\x08OnlyFans\x12\x14\n\x0cis_only_fans\x18\x01 \x01(\x08\x12\x31\n\x05\x62\x61\x64ge\x18\x02 \x01(\x0b\x32\".bilibili.app.dynamic.v2.IconBadge\"?\n\x10OnlyFansProperty\x12\x15\n\rhas_privilege\x18\x01 \x01(\x08\x12\x14\n\x0cis_only_fans\x18\x02 \x01(\x08\"\xbf\x01\n\x0eOpusCollection\x12\x15\n\rcollection_id\x18\x01 \x01(\x03\x12\x33\n\x05title\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.OneLineText\x12\x12\n\ndetail_uri\x18\x03 \x01(\t\x12\r\n\x05intro\x18\x04 \x01(\t\x12>\n\tall_items\x18\x05 \x03(\x0b\x32+.bilibili.app.dynamic.v2.OpusCollectionItem\"r\n\x12OpusCollectionItem\x12\x0f\n\x07opus_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x10\n\x08pub_time\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\x12\x1d\n\x15is_selected_highlight\x18\x05 \x01(\x08\"\x92\x06\n\tParagraph\x12\x43\n\tpara_type\x18\x01 \x01(\x0e\x32\x30.bilibili.app.dynamic.v2.Paragraph.ParagraphType\x12G\n\x0bpara_format\x18\x02 \x01(\x0b\x32\x32.bilibili.app.dynamic.v2.Paragraph.ParagraphFormat\x12\x36\n\x04text\x18\x03 \x01(\x0b\x32&.bilibili.app.dynamic.v2.TextParagraphH\x00\x12\x34\n\x03pic\x18\x04 \x01(\x0b\x32%.bilibili.app.dynamic.v2.PicParagraphH\x00\x12\x36\n\x04line\x18\x05 \x01(\x0b\x32&.bilibili.app.dynamic.v2.LineParagraphH\x00\x12;\n\tlink_card\x18\x06 \x01(\x0b\x32&.bilibili.app.dynamic.v2.CardParagraphH\x00\x1a\x39\n\nListFormat\x12\r\n\x05level\x18\x01 \x01(\x05\x12\r\n\x05order\x18\x02 \x01(\x05\x12\r\n\x05theme\x18\x03 \x01(\t\x1a\x97\x01\n\x0fParagraphFormat\x12@\n\x05\x61lign\x18\x01 \x01(\x0e\x32\x31.bilibili.app.dynamic.v2.Paragraph.ParagraphAlign\x12\x42\n\x0blist_format\x18\x02 \x01(\x0b\x32-.bilibili.app.dynamic.v2.Paragraph.ListFormat\"1\n\x0eParagraphAlign\x12\x08\n\x04LEFT\x10\x00\x12\n\n\x06MIDDLE\x10\x01\x12\t\n\x05RIGHT\x10\x02\"\x80\x01\n\rParagraphType\x12\x0b\n\x07INVALID\x10\x00\x12\x08\n\x04TEXT\x10\x01\x12\x0c\n\x08PICTURES\x10\x02\x12\x08\n\x04LINE\x10\x03\x12\r\n\tREFERENCE\x10\x04\x12\x0f\n\x0bSORTED_LIST\x10\x05\x12\x11\n\rUNSORTED_LIST\x10\x06\x12\r\n\tLINK_CARD\x10\x07\x42\t\n\x07\x63ontent\"\\\n\x0bParaSpacing\x12\x1b\n\x13spacing_before_para\x18\x01 \x01(\x01\x12\x1a\n\x12spacing_after_para\x18\x02 \x01(\x01\x12\x14\n\x0cline_spacing\x18\x03 \x01(\x01\";\n\tPGCSeason\x12\x11\n\tis_finish\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x05\"\xca\x01\n\x0cPicParagraph\x12\x31\n\x04pics\x18\x01 \x01(\x0b\x32#.bilibili.app.dynamic.v2.MdlDynDraw\x12\x46\n\x05style\x18\x02 \x01(\x0e\x32\x37.bilibili.app.dynamic.v2.PicParagraph.PicParagraphStyle\"?\n\x11PicParagraphStyle\x12\x0b\n\x07INVALID\x10\x00\x12\r\n\tNINE_CELL\x10\x01\x12\x0e\n\nBIG_SCROLL\x10\x02\"[\n\x0cPlayurlParam\x12\n\n\x02qn\x18\x01 \x01(\x05\x12\r\n\x05\x66nver\x18\x02 \x01(\x05\x12\r\n\x05\x66nval\x18\x03 \x01(\x05\x12\x12\n\nforce_host\x18\x04 \x01(\x05\x12\r\n\x05\x66ourk\x18\x05 \x01(\x05\"1\n\x05Popup\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\xca\x02\n\x0bRcmdArchive\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12=\n\x11\x63over_left_icon_1\x18\x03 \x01(\x0e\x32\".bilibili.app.dynamic.v2.CoverIcon\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x0e\n\x06is_pgc\x18\x06 \x01(\x08\x12\x0b\n\x03\x61id\x18\x07 \x01(\x03\x12\x31\n\x05\x62\x61\x64ge\x18\x08 \x01(\x0b\x32\".bilibili.app.dynamic.v2.IconBadge\x12\x18\n\x10\x63over_left_icon2\x18\t \x01(\x05\x12\x18\n\x10\x63over_left_text2\x18\n \x01(\t\x12\x18\n\x10\x63over_left_icon3\x18\x0b \x01(\x05\x12\x18\n\x10\x63over_left_text3\x18\x0c \x01(\t\"\x82\x01\n\nRcmdAuthor\x12\x31\n\x06\x61uthor\x18\x01 \x01(\x0b\x32!.bilibili.app.dynamic.v2.UserInfo\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x33\n\x08relation\x18\x03 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\"\\\n\x0fRcmdCampusBrief\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12\x14\n\x0c\x63\x61mpus_badge\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\"\x86\x01\n\x08RcmdItem\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.bilibili.app.dynamic.v2.RcmdType\x12<\n\x0crcmd_archive\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.RcmdArchiveH\x00\x42\x0b\n\trcmd_item\" \n\nRcmdOption\x12\x12\n\nshow_title\x18\x01 \x01(\x08\"\x80\x01\n\nRcmdReason\x12\x13\n\x0b\x63\x61mpus_name\x18\x01 \x01(\t\x12\x37\n\x05style\x18\x02 \x01(\x0e\x32(.bilibili.app.dynamic.v2.RcmdReasonStyle\x12\x13\n\x0brcmd_reason\x18\x03 \x01(\t\x12\x0f\n\x07up_name\x18\x04 \x01(\t\"*\n\rRcmdTopButton\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"\"\n\x0cRcmdUPsParam\x12\x12\n\ndislike_ts\x18\x01 \x01(\x03\"\x9f\x01\n\x10ReactionListItem\x12/\n\x04user\x18\x01 \x01(\x0b\x32!.bilibili.app.dynamic.v2.UserInfo\x12\x33\n\x08relation\x18\x02 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\x12\x10\n\x08\x61\x63t_text\x18\x03 \x01(\t\x12\x13\n\x0brcmd_reason\x18\x04 \x01(\t\"}\n\x11ReactionListReply\x12\r\n\x05title\x18\x01 \x01(\t\x12\x37\n\x04list\x18\x02 \x03(\x0b\x32).bilibili.app.dynamic.v2.ReactionListItem\x12\x0e\n\x06offset\x18\x03 \x01(\t\x12\x10\n\x08has_more\x18\x04 \x01(\x08\"T\n\x0fReactionListReq\x12\x12\n\ndynamic_id\x18\x01 \x01(\x03\x12\x10\n\x08\x64yn_type\x18\x02 \x01(\x03\x12\x0b\n\x03rid\x18\x03 \x01(\x03\x12\x0e\n\x06offset\x18\x04 \x01(\t\"z\n\x08Relation\x12\x37\n\x06status\x18\x01 \x01(\x0e\x32\'.bilibili.app.dynamic.v2.RelationStatus\x12\x11\n\tis_follow\x18\x02 \x01(\x05\x12\x13\n\x0bis_followed\x18\x03 \x01(\x05\x12\r\n\x05title\x18\x04 \x01(\t\"\x9a\x01\n\rRepostListReq\x12\x12\n\ndynamic_id\x18\x01 \x01(\t\x12\x10\n\x08\x64yn_type\x18\x02 \x01(\x03\x12\x0b\n\x03rid\x18\x03 \x01(\x03\x12\x0e\n\x06offset\x18\x04 \x01(\t\x12\x0c\n\x04\x66rom\x18\x05 \x01(\t\x12\x38\n\x0brepost_type\x18\x06 \x01(\x0e\x32#.bilibili.app.dynamic.v2.RepostType\"\xb4\x01\n\rRepostListRsp\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x13\n\x0btotal_count\x18\x04 \x01(\x03\x12\x38\n\x0brepost_type\x18\x05 \x01(\x0e\x32#.bilibili.app.dynamic.v2.RepostType\"J\n\x14SchoolRecommendReply\x12\x32\n\x05items\x18\x01 \x03(\x0b\x32#.bilibili.app.dynamic.v2.CampusInfo\"m\n\x12SchoolRecommendReq\x12\x0b\n\x03lat\x18\x01 \x01(\x02\x12\x0b\n\x03lng\x18\x02 \x01(\x02\x12=\n\tfrom_type\x18\x03 \x01(\x0e\x32*.bilibili.app.dynamic.v2.CampusReqFromType\"|\n\x11SchoolSearchReply\x12\x32\n\x05items\x18\x01 \x03(\x0b\x32#.bilibili.app.dynamic.v2.CampusInfo\x12\x33\n\x05toast\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.SearchToast\"a\n\x0fSchoolSearchReq\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12=\n\tfrom_type\x18\x02 \x01(\x0e\x32*.bilibili.app.dynamic.v2.CampusReqFromType\"\x97\x01\n\rSearchChannel\x12\r\n\x05title\x18\x01 \x01(\t\x12?\n\x0bmore_button\x18\x02 \x01(\x0b\x32*.bilibili.app.dynamic.v2.SearchTopicButton\x12\x36\n\x08\x63hannels\x18\x03 \x03(\x0b\x32$.bilibili.app.dynamic.v2.ChannelInfo\"\x93\x01\n\nSearchInfo\x12\r\n\x05title\x18\x01 \x01(\t\x12\x32\n\x04list\x18\x02 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x10\n\x08track_id\x18\x03 \x01(\t\x12\r\n\x05total\x18\x04 \x01(\x03\x12\x10\n\x08has_more\x18\x05 \x01(\x08\x12\x0f\n\x07version\x18\x06 \x01(\t\"5\n\x0bSearchToast\x12\x12\n\ndesc_text1\x18\x01 \x01(\t\x12\x12\n\ndesc_text2\x18\x02 \x01(\t\"\x96\x01\n\x0bSearchTopic\x12\r\n\x05title\x18\x01 \x01(\t\x12?\n\x0bmore_button\x18\x02 \x01(\x0b\x32*.bilibili.app.dynamic.v2.SearchTopicButton\x12\x37\n\x05items\x18\x03 \x03(\x0b\x32(.bilibili.app.dynamic.v2.SearchTopicItem\"4\n\x11SearchTopicButton\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08jump_uri\x18\x02 \x01(\t\"g\n\x0fSearchTopicItem\x12\x10\n\x08topic_id\x18\x01 \x01(\x03\x12\x12\n\ntopic_name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x13\n\x0bis_activity\x18\x05 \x01(\x08\"_\n\x0eSetDecisionReq\x12\x0e\n\x06result\x18\x01 \x01(\x05\x12=\n\tfrom_type\x18\x02 \x01(\x0e\x32*.bilibili.app.dynamic.v2.CampusReqFromType\"{\n\x12SetRecentCampusReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12=\n\tfrom_type\x18\x03 \x01(\x0e\x32*.bilibili.app.dynamic.v2.CampusReqFromType\"t\n\x0cShareChannel\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x0f\n\x07\x63hannel\x18\x03 \x01(\t\x12\x36\n\x07reserve\x18\x04 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ShareReserve\"\xaa\x01\n\x0cShareReserve\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x14\n\x0cqr_code_icon\x18\x03 \x01(\t\x12\x14\n\x0cqr_code_text\x18\x04 \x01(\t\x12\x13\n\x0bqr_code_url\x18\x05 \x01(\t\x12<\n\tuser_info\x18\x06 \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionUserInfo\"5\n\x08SortType\x12\x11\n\tsort_type\x18\x01 \x01(\x05\x12\x16\n\x0esort_type_name\x18\x02 \x01(\t\"n\n\x0cStoryArchive\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x0b\n\x03\x61id\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x35\n\tdimension\x18\x04 \x01(\x0b\x32\".bilibili.app.dynamic.v2.Dimension\"\xb7\x01\n\tStoryItem\x12\x31\n\x06\x61uthor\x18\x01 \x01(\x0b\x32!.bilibili.app.dynamic.v2.UserInfo\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\x03\x12\x0c\n\x04type\x18\x04 \x01(\x05\x12>\n\rstory_archive\x18\x05 \x01(\x0b\x32%.bilibili.app.dynamic.v2.StoryArchiveH\x00\x42\x0b\n\trcmd_item\"{\n\x12SubscribeCampusReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12=\n\tfrom_type\x18\x03 \x01(\x0e\x32*.bilibili.app.dynamic.v2.CampusReqFromType\"\xcb\x02\n\x08TextNode\x12\x41\n\tnode_type\x18\x01 \x01(\x0e\x32..bilibili.app.dynamic.v2.TextNode.TextNodeType\x12\x10\n\x08raw_text\x18\x02 \x01(\t\x12\x31\n\x04word\x18\x03 \x01(\x0b\x32!.bilibili.app.dynamic.v2.WordNodeH\x00\x12\x33\n\x05\x65mote\x18\x04 \x01(\x0b\x32\".bilibili.app.dynamic.v2.EmoteNodeH\x00\x12\x31\n\x04link\x18\x05 \x01(\x0b\x32!.bilibili.app.dynamic.v2.LinkNodeH\x00\"G\n\x0cTextNodeType\x12\x0b\n\x07INVALID\x10\x00\x12\t\n\x05WORDS\x10\x01\x12\t\n\x05\x45MOTE\x10\x02\x12\x06\n\x02\x41T\x10\x03\x12\x0c\n\x08\x42IZ_LINK\x10\x04\x42\x06\n\x04text\"A\n\rTextParagraph\x12\x30\n\x05nodes\x18\x01 \x03(\x0b\x32!.bilibili.app.dynamic.v2.TextNode\"2\n\x10TextWithPriority\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x10\n\x08priority\x18\x02 \x01(\x03\"\xc1\x01\n\x13ThreePointAttention\x12\x16\n\x0e\x61ttention_icon\x18\x01 \x01(\t\x12\x16\n\x0e\x61ttention_text\x18\x02 \x01(\t\x12\x1a\n\x12not_attention_icon\x18\x03 \x01(\t\x12\x1a\n\x12not_attention_text\x18\x04 \x01(\t\x12\x42\n\x06status\x18\x05 \x01(\x0e\x32\x32.bilibili.app.dynamic.v2.ThreePointAttentionStatus\"\xe2\x01\n\x12ThreePointAutoPlay\x12\x11\n\topen_icon\x18\x01 \x01(\t\x12\x11\n\topen_text\x18\x02 \x01(\t\x12\x12\n\nclose_icon\x18\x03 \x01(\t\x12\x12\n\nclose_text\x18\x04 \x01(\t\x12\x14\n\x0copen_text_v2\x18\x05 \x01(\t\x12\x15\n\rclose_text_v2\x18\x06 \x01(\t\x12\x11\n\tonly_icon\x18\x07 \x01(\t\x12\x11\n\tonly_text\x18\x08 \x01(\t\x12\x14\n\x0copen_icon_v2\x18\t \x01(\t\x12\x15\n\rclose_icon_v2\x18\n \x01(\t\"\xa8\x01\n\x11ThreePointComment\x12<\n\x0cup_selection\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v2.CommentDetail\x12\x38\n\x08up_close\x18\x02 \x01(\x0b\x32&.bilibili.app.dynamic.v2.CommentDetail\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\"\x89\x01\n\x11ThreePointDefault\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12>\n\x05toast\x18\x05 \x01(\x0b\x32/.bilibili.app.dynamic.v2.ThreePointDefaultToast\"5\n\x16ThreePointDefaultToast\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\"0\n\x11ThreePointDislike\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"~\n\x12ThreePointFavorite\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\x03\x12\x14\n\x0cis_favourite\x18\x04 \x01(\x08\x12\x13\n\x0b\x63\x61ncel_icon\x18\x05 \x01(\t\x12\x14\n\x0c\x63\x61ncel_title\x18\x06 \x01(\t\"\x9d\x01\n\x0eThreePointHide\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12G\n\x0binteractive\x18\x03 \x01(\x0b\x32\x32.bilibili.app.dynamic.v2.ThreePointHideInteractive\x12\x11\n\tblook_fid\x18\x04 \x01(\x03\x12\x12\n\nblook_type\x18\x05 \x01(\t\"Z\n\x19ThreePointHideInteractive\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63onfirm\x18\x02 \x01(\t\x12\x0e\n\x06\x63\x61ncel\x18\x03 \x01(\t\x12\r\n\x05toast\x18\x04 \x01(\t\"\x88\x06\n\x0eThreePointItem\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.bilibili.app.dynamic.v2.ThreePointType\x12=\n\x07\x64\x65\x66\x61ult\x18\x02 \x01(\x0b\x32*.bilibili.app.dynamic.v2.ThreePointDefaultH\x00\x12\x42\n\x0b\x61uto_player\x18\x03 \x01(\x0b\x32+.bilibili.app.dynamic.v2.ThreePointAutoPlayH\x00\x12\x39\n\x05share\x18\x04 \x01(\x0b\x32(.bilibili.app.dynamic.v2.ThreePointShareH\x00\x12\x41\n\tattention\x18\x05 \x01(\x0b\x32,.bilibili.app.dynamic.v2.ThreePointAttentionH\x00\x12\x37\n\x04wait\x18\x06 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.ThreePointWaitH\x00\x12=\n\x07\x64islike\x18\x07 \x01(\x0b\x32*.bilibili.app.dynamic.v2.ThreePointDislikeH\x00\x12?\n\x08\x66\x61vorite\x18\x08 \x01(\x0b\x32+.bilibili.app.dynamic.v2.ThreePointFavoriteH\x00\x12\x35\n\x03top\x18\t \x01(\x0b\x32&.bilibili.app.dynamic.v2.ThreePointTopH\x00\x12=\n\x07\x63omment\x18\n \x01(\x0b\x32*.bilibili.app.dynamic.v2.ThreePointCommentH\x00\x12\x37\n\x04hide\x18\x0b \x01(\x0b\x32\'.bilibili.app.dynamic.v2.ThreePointHideH\x00\x12N\n\x10topic_irrelevant\x18\x0c \x01(\x0b\x32\x32.bilibili.app.dynamic.v2.ThreePointTopicIrrelevantH\x00\x42\x06\n\x04item\"\xbe\x01\n\x0fThreePointShare\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12@\n\x07\x63hannel\x18\x03 \x03(\x0b\x32/.bilibili.app.dynamic.v2.ThreePointShareChannel\x12\x14\n\x0c\x63hannel_name\x18\x04 \x01(\t\x12\x36\n\x07reserve\x18\x05 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ShareReserve\"5\n\x16ThreePointShareChannel\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"\\\n\rThreePointTop\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12.\n\x04type\x18\x03 \x01(\x0e\x32 .bilibili.app.dynamic.v2.TopType\"\x8b\x01\n\x19ThreePointTopicIrrelevant\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05toast\x18\x03 \x01(\t\x12\x10\n\x08topic_id\x18\x04 \x01(\x03\x12\x0e\n\x06res_id\x18\x05 \x01(\x03\x12\x10\n\x08res_type\x18\x06 \x01(\x03\x12\x0e\n\x06reason\x18\x07 \x01(\t\"~\n\x0eThreePointWait\x12\x15\n\raddition_icon\x18\x01 \x01(\t\x12\x15\n\raddition_text\x18\x02 \x01(\t\x12\x18\n\x10no_addition_icon\x18\x03 \x01(\t\x12\x18\n\x10no_addition_text\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\x03\"R\n\rTopAdditionUP\x12/\n\x02up\x18\x01 \x03(\x0b\x32#.bilibili.app.dynamic.v2.AdditionUP\x12\x10\n\x08has_fold\x18\x02 \x01(\x05\"M\n\x0bTopicButton\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x10\n\x08jump_uri\x18\x03 \x01(\t\x12\x0f\n\x07red_dot\x18\x04 \x01(\x08\"n\n\tTopicItem\x12\x10\n\x08topic_id\x18\x01 \x01(\x03\x12\x12\n\ntopic_name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\r\n\x05\x64\x65sc2\x18\x05 \x01(\t\x12\x11\n\trcmd_desc\x18\x06 \x01(\t\"\xe5\x01\n\tTopicList\x12\r\n\x05title\x18\x01 \x01(\t\x12?\n\x0ftopic_list_item\x18\x02 \x03(\x0b\x32&.bilibili.app.dynamic.v2.TopicListItem\x12\x38\n\nact_button\x18\x03 \x01(\x0b\x32$.bilibili.app.dynamic.v2.TopicButton\x12\x39\n\x0bmore_button\x18\x04 \x01(\x0b\x32$.bilibili.app.dynamic.v2.TopicButton\x12\x13\n\x0bserver_info\x18\x05 \x01(\t\"\xd7\x01\n\rTopicListItem\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x12\n\nicon_title\x18\x02 \x01(\t\x12\x10\n\x08topic_id\x18\x03 \x01(\x03\x12\x12\n\ntopic_name\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x0b\n\x03pos\x18\x06 \x01(\x03\x12\x13\n\x0bserver_info\x18\x07 \x01(\t\x12\x15\n\rhead_icon_url\x18\x08 \x01(\t\x12\x0e\n\x06up_mid\x18\t \x01(\x03\x12\x15\n\rtail_icon_url\x18\n \x01(\t\x12\x11\n\textension\x18\x0b \x01(\t\"e\n\x0eTopicListReply\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\".bilibili.app.dynamic.v2.TopicItem\x12\x10\n\x08has_more\x18\x02 \x01(\x08\x12\x0e\n\x06offset\x18\x03 \x01(\t\"1\n\x0cTopicListReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\t\"A\n\x13TopicMergedResource\x12\x12\n\nmerge_type\x18\x01 \x01(\x05\x12\x16\n\x0emerged_res_cnt\x18\x02 \x01(\x05\"\xab\x01\n\rTopicRcmdCard\x12\x10\n\x08topic_id\x18\x01 \x01(\x03\x12\x12\n\ntopic_name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x34\n\x06\x62utton\x18\x04 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12\r\n\x05\x64\x65sc1\x18\x05 \x01(\t\x12\r\n\x05\x64\x65sc2\x18\x06 \x01(\t\x12\x13\n\x0bupdate_desc\x18\x07 \x01(\t\"\x8c\x01\n\x0fTopicSquareInfo\x12\r\n\x05title\x18\x01 \x01(\t\x12\x34\n\x06\x62utton\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12\x34\n\x04rcmd\x18\x03 \x01(\x0b\x32&.bilibili.app.dynamic.v2.TopicRcmdCard\"J\n\x10TopicSquareReply\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.bilibili.app.dynamic.v2.TopicSquareInfo\"#\n\x0eTopicSquareReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\"c\n\x08Unfollow\x12\r\n\x05title\x18\x01 \x01(\t\x12\x37\n\x04list\x18\x02 \x03(\x0b\x32).bilibili.app.dynamic.v2.UnfollowUserItem\x12\x0f\n\x07TrackId\x18\x03 \x01(\t\"\x1f\n\x10UnfollowMatchReq\x12\x0b\n\x03\x63id\x18\x01 \x01(\x03\"\xe3\x02\n\x10UnfollowUserItem\x12\x12\n\nhas_update\x18\x01 \x01(\x08\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\x03\x12\x0b\n\x03pos\x18\x05 \x01(\x05\x12\x36\n\nlive_state\x18\x06 \x01(\x0e\x32\".bilibili.app.dynamic.v2.LiveState\x12\x39\n\x08official\x18\x07 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.OfficialVerify\x12-\n\x03vip\x18\x08 \x01(\x0b\x32 .bilibili.app.dynamic.v2.VipInfo\x12\x0c\n\x04sign\x18\t \x01(\t\x12\r\n\x05label\x18\n \x01(\t\x12\x39\n\x06\x62utton\x18\x0b \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionalButton\x12\x0b\n\x03uri\x18\x0c \x01(\t\"W\n\x13UpdateTabSettingReq\x12@\n\x06status\x18\x01 \x01(\x0e\x32\x30.bilibili.app.dynamic.v2.HomePageTabSttingStatus\"\x99\x04\n\nUpListItem\x12\x12\n\nhas_update\x18\x01 \x01(\x08\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\x03\x12\x0b\n\x03pos\x18\x05 \x01(\x03\x12=\n\x0euser_item_type\x18\x06 \x01(\x0e\x32%.bilibili.app.dynamic.v2.UserItemType\x12\x41\n\x11\x64isplay_style_day\x18\x07 \x01(\x0b\x32&.bilibili.app.dynamic.v2.UserItemStyle\x12\x43\n\x13\x64isplay_style_night\x18\x08 \x01(\x0b\x32&.bilibili.app.dynamic.v2.UserItemStyle\x12\x10\n\x08style_id\x18\t \x01(\x03\x12\x36\n\nlive_state\x18\n \x01(\x0e\x32\".bilibili.app.dynamic.v2.LiveState\x12\x11\n\tseparator\x18\x0b \x01(\x08\x12\x0b\n\x03uri\x18\x0c \x01(\t\x12\x11\n\tis_recall\x18\r \x01(\x08\x12\x37\n\x0bupdate_icon\x18\x0e \x01(\x0b\x32\".bilibili.app.dynamic.v2.IconBadge\x12\x18\n\x10live_rcmd_reason\x18\x0f \x01(\t\x12\x12\n\nlive_cover\x18\x10 \x01(\t\x12\x16\n\x0epersonal_extra\x18\x11 \x01(\t\"-\n\x0fUpListMoreLabel\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\x9b\x04\n\x08UserInfo\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x39\n\x08official\x18\x04 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.OfficialVerify\x12-\n\x03vip\x18\x05 \x01(\x0b\x32 .bilibili.app.dynamic.v2.VipInfo\x12/\n\x04live\x18\x06 \x01(\x0b\x32!.bilibili.app.dynamic.v2.LiveInfo\x12\x0b\n\x03uri\x18\x07 \x01(\t\x12\x35\n\x07pendant\x18\x08 \x01(\x0b\x32$.bilibili.app.dynamic.v2.UserPendant\x12\x35\n\tnameplate\x18\t \x01(\x0b\x32\".bilibili.app.dynamic.v2.Nameplate\x12\r\n\x05level\x18\n \x01(\x05\x12\x0c\n\x04sign\x18\x0b \x01(\t\x12\x10\n\x08\x66\x61\x63\x65_nft\x18\x0c \x01(\x05\x12\x14\n\x0c\x66\x61\x63\x65_nft_new\x18\r \x01(\x05\x12\x32\n\x08nft_info\x18\x0e \x01(\x0b\x32 .bilibili.app.dynamic.v2.NFTInfo\x12\x18\n\x10is_senior_member\x18\x0f \x01(\x05\x12=\n\x06\x61vatar\x18\x10 \x01(\x0b\x32-.bilibili.dagw.component.avatar.v1.AvatarItem\"~\n\rUserItemStyle\x12\x11\n\trect_text\x18\x01 \x01(\t\x12\x17\n\x0frect_text_color\x18\x02 \x01(\t\x12\x11\n\trect_icon\x18\x03 \x01(\t\x12\x15\n\rrect_bg_color\x18\x04 \x01(\t\x12\x17\n\x0fouter_animation\x18\x05 \x01(\t\"G\n\x0bUserPendant\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x0e\n\x06\x65xpire\x18\x04 \x01(\x03\"\xe0\x01\n\nVideoBadge\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x06 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x07 \x01(\t\x12\x10\n\x08\x62g_style\x18\x08 \x01(\x05\x12\x10\n\x08\x62g_alpha\x18\t \x01(\x05\x12\x16\n\x0e\x62g_alpha_night\x18\n \x01(\x05\"\xb1\x01\n\x07VipInfo\x12\x0c\n\x04Type\x18\x01 \x01(\x05\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x10\n\x08\x64ue_date\x18\x03 \x01(\x03\x12\x30\n\x05label\x18\x04 \x01(\x0b\x32!.bilibili.app.dynamic.v2.VipLabel\x12\x12\n\ntheme_type\x18\x05 \x01(\x05\x12\x18\n\x10\x61vatar_subscript\x18\x06 \x01(\x05\x12\x16\n\x0enickname_color\x18\x07 \x01(\t\";\n\x08VipLabel\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x13\n\x0blabel_theme\x18\x03 \x01(\t\"Y\n\x06Weight\x12\r\n\x05title\x18\x01 \x01(\t\x12\x32\n\x05items\x18\x02 \x03(\x0b\x32#.bilibili.app.dynamic.v2.WeightItem\x12\x0c\n\x04icon\x18\x03 \x01(\t\"/\n\x0cWeightButton\x12\x10\n\x08jump_url\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"6\n\rWeightDislike\x12\x16\n\x0e\x66\x65\x65\x64_back_type\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"\xbb\x01\n\nWeightItem\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32#.bilibili.app.dynamic.v2.WeightType\x12\x37\n\x06\x62utton\x18\x02 \x01(\x0b\x32%.bilibili.app.dynamic.v2.WeightButtonH\x00\x12\x39\n\x07\x64islike\x18\x03 \x01(\x0b\x32&.bilibili.app.dynamic.v2.WeightDislikeH\x00\x42\x06\n\x04item\"\xf5\x01\n\x08WordNode\x12\r\n\x05words\x18\x01 \x01(\t\x12\x11\n\tfont_size\x18\x02 \x01(\x01\x12.\n\x05\x63olor\x18\x03 \x01(\x0b\x32\x1f.bilibili.app.dynamic.v2.Colors\x12>\n\x05style\x18\x04 \x01(\x0b\x32/.bilibili.app.dynamic.v2.WordNode.WordNodeStyle\x1aW\n\rWordNodeStyle\x12\x0c\n\x04\x62old\x18\x01 \x01(\x08\x12\x0e\n\x06italic\x18\x02 \x01(\x08\x12\x15\n\rstrikethrough\x18\x03 \x01(\x08\x12\x11\n\tunderline\x18\x04 \x01(\x08*2\n\x10\x41\x64\x64\x42uttonBgStyle\x12\x08\n\x04\x66ill\x10\x00\x12\n\n\x06stroke\x10\x01\x12\x08\n\x04gray\x10\x02*8\n\rAddButtonType\x12\x0b\n\x07\x62t_none\x10\x00\x12\x0b\n\x07\x62t_jump\x10\x01\x12\r\n\tbt_button\x10\x02*9\n\x19\x41\x64\x64itionalButtonClickType\x12\x0e\n\nclick_none\x10\x00\x12\x0c\n\x08\x63lick_up\x10\x01*:\n\x16\x41\x64\x64itionalButtonStatus\x12\x08\n\x04none\x10\x00\x12\x0b\n\x07uncheck\x10\x01\x12\t\n\x05\x63heck\x10\x02*3\n\x17\x41\x64\x64itionalShareShowType\x12\x0b\n\x07st_none\x10\x00\x12\x0b\n\x07st_show\x10\x01*\x85\x02\n\x0e\x41\x64\x64itionalType\x12\x13\n\x0f\x61\x64\x64itional_none\x10\x00\x12\x17\n\x13\x61\x64\x64itional_type_pgc\x10\x01\x12\x19\n\x15\x61\x64\x64itional_type_goods\x10\x02\x12\x18\n\x14\x61\x64\x64itional_type_vote\x10\x03\x12\x1a\n\x16\x61\x64\x64itional_type_common\x10\x04\x12\x1a\n\x16\x61\x64\x64itional_type_esport\x10\x05\x12\x1b\n\x17\x61\x64\x64itional_type_up_rcmd\x10\x06\x12\x17\n\x13\x61\x64\x64itional_type_ugc\x10\x07\x12\"\n\x1e\x61\x64\x64itional_type_up_reservation\x10\x08*n\n\x11\x41\x64\x64itionVoteState\x12\x1c\n\x18\x61\x64\x64ition_vote_state_none\x10\x00\x12\x1c\n\x18\x61\x64\x64ition_vote_state_open\x10\x01\x12\x1d\n\x19\x61\x64\x64ition_vote_state_close\x10\x02*\x88\x01\n\x10\x41\x64\x64itionVoteType\x12\x1b\n\x17\x61\x64\x64ition_vote_type_none\x10\x00\x12\x1b\n\x17\x61\x64\x64ition_vote_type_word\x10\x01\x12\x1a\n\x16\x61\x64\x64ition_vote_type_pic\x10\x02\x12\x1e\n\x1a\x61\x64\x64ition_vote_type_default\x10\x03*>\n\x0f\x43\x61mpusEntryType\x12\x08\n\x04NONE\x10\x00\x12\x11\n\rENTRY_DYNAMIC\x10\x01\x12\x0e\n\nENTRY_HOME\x10\x02*\xe7\x01\n\x11\x43\x61mpusRcmdReqFrom\x12\x1c\n\x18\x43\x41MPUS_RCMD_FROM_UNKNOWN\x10\x00\x12!\n\x1d\x43\x41MPUS_RCMD_FROM_HOME_UN_OPEN\x10\x01\x12 \n\x1c\x43\x41MPUS_RCMD_FROM_VISIT_OTHER\x10\x02\x12 \n\x1c\x43\x41MPUS_RCMD_FROM_HOME_MOMENT\x10\x03\x12\x1f\n\x1b\x43\x41MPUS_RCMD_FROM_DYN_MOMENT\x10\x04\x12,\n(CAMPUS_RCMD_FROM_PAGE_SUBORDINATE_MOMENT\x10\x05*Q\n\x12\x43\x61mpusHomePageType\x12\x0e\n\nPAGE_MAJOR\x10\x00\x12\x14\n\x10PAGE_SUBORDINATE\x10\x01\x12\x15\n\x11PAGE_MAJOR_DETAIL\x10\x02*o\n\x14\x43\x61mpusMngAuditStatus\x12\x19\n\x15\x63\x61mpus_mng_audit_none\x10\x00\x12\x1f\n\x1b\x63\x61mpus_mng_audit_in_process\x10\x01\x12\x1b\n\x17\x63\x61mpus_mng_audit_failed\x10\x02*\x85\x01\n\x11\x43\x61mpusMngItemType\x12\x13\n\x0f\x63\x61mpus_mng_none\x10\x00\x12\x19\n\x15\x63\x61mpus_mng_basic_info\x10\x01\x12\x14\n\x10\x63\x61mpus_mng_badge\x10\x02\x12\x15\n\x11\x63\x61mpus_mng_slogan\x10\x03\x12\x13\n\x0f\x63\x61mpus_mng_quiz\x10\x04*m\n\x13\x43\x61mpusMngQuizAction\x12\x1c\n\x18\x63\x61mpus_mng_quiz_act_list\x10\x00\x12\x1b\n\x17\x63\x61mpus_mng_quiz_act_add\x10\x01\x12\x1b\n\x17\x63\x61mpus_mng_quiz_act_del\x10\x02*I\n\x12\x43\x61mpusOnlineStatus\x12\x19\n\x15\x63\x61mpus_online_offline\x10\x00\x12\x18\n\x14\x63\x61mpus_online_online\x10\x01**\n\x11\x43\x61mpusReqFromType\x12\x0b\n\x07\x44YNAMIC\x10\x00\x12\x08\n\x04HOME\x10\x01*\x96\x01\n\rCampusTabType\x12\x0f\n\x0b\x63\x61mpus_none\x10\x00\x12\x11\n\rcampus_school\x10\x01\x12\x12\n\x0e\x63\x61mpus_dynamic\x10\x02\x12\x12\n\x0e\x63\x61mpus_account\x10\x03\x12\x14\n\x10\x63\x61mpus_billboard\x10\x04\x12\x10\n\x0c\x63\x61mpus_topic\x10\x05\x12\x11\n\rcampues_other\x10\x06*s\n\tCoverIcon\x12\x13\n\x0f\x63over_icon_none\x10\x00\x12\x13\n\x0f\x63over_icon_play\x10\x01\x12\x16\n\x12\x63over_icon_danmaku\x10\x02\x12\x11\n\rcover_icon_up\x10\x03\x12\x11\n\rcover_icon_vt\x10\x04*\x94\x03\n\x08\x44\x65scType\x12\x12\n\x0e\x64\x65sc_type_none\x10\x00\x12\x12\n\x0e\x64\x65sc_type_text\x10\x01\x12\x12\n\x0e\x64\x65sc_type_aite\x10\x02\x12\x15\n\x11\x64\x65sc_type_lottery\x10\x03\x12\x12\n\x0e\x64\x65sc_type_vote\x10\x04\x12\x13\n\x0f\x64\x65sc_type_topic\x10\x05\x12\x13\n\x0f\x64\x65sc_type_goods\x10\x06\x12\x10\n\x0c\x64\x65sc_type_bv\x10\x07\x12\x10\n\x0c\x64\x65sc_type_av\x10\x08\x12\x13\n\x0f\x64\x65sc_type_emoji\x10\t\x12\x12\n\x0e\x64\x65sc_type_user\x10\n\x12\x10\n\x0c\x64\x65sc_type_cv\x10\x0b\x12\x10\n\x0c\x64\x65sc_type_vc\x10\x0c\x12\x11\n\rdesc_type_web\x10\r\x12\x14\n\x10\x64\x65sc_type_taobao\x10\x0e\x12\x12\n\x0e\x64\x65sc_type_mail\x10\x0f\x12\x18\n\x14\x64\x65sc_type_ogv_season\x10\x10\x12\x14\n\x10\x64\x65sc_type_ogv_ep\x10\x11\x12\x19\n\x15\x64\x65sc_type_search_word\x10\x12*\'\n\x0c\x44isableState\x12\r\n\thighlight\x10\x00\x12\x08\n\x04gary\x10\x01*\x8c\x03\n\x0b\x44ynamicType\x12\x0c\n\x08\x64yn_none\x10\x00\x12\x0b\n\x07\x66orward\x10\x01\x12\x06\n\x02\x61v\x10\x02\x12\x07\n\x03pgc\x10\x03\x12\x0b\n\x07\x63ourses\x10\x04\x12\x08\n\x04\x66old\x10\x05\x12\x08\n\x04word\x10\x06\x12\x08\n\x04\x64raw\x10\x07\x12\x0b\n\x07\x61rticle\x10\x08\x12\t\n\x05music\x10\t\x12\x11\n\rcommon_square\x10\n\x12\x13\n\x0f\x63ommon_vertical\x10\x0b\x12\x08\n\x04live\x10\x0c\x12\r\n\tmedialist\x10\r\x12\x12\n\x0e\x63ourses_season\x10\x0e\x12\x06\n\x02\x61\x64\x10\x0f\x12\n\n\x06\x61pplet\x10\x10\x12\x10\n\x0csubscription\x10\x11\x12\r\n\tlive_rcmd\x10\x12\x12\n\n\x06\x62\x61nner\x10\x13\x12\x0e\n\nugc_season\x10\x14\x12\x14\n\x10subscription_new\x10\x15\x12\t\n\x05story\x10\x16\x12\x0e\n\ntopic_rcmd\x10\x17\x12\x0b\n\x07\x63our_up\x10\x18\x12\r\n\ttopic_set\x10\x19\x12\n\n\x06notice\x10\x1a\x12\x0f\n\x0btext_notice\x10\x1b*\xe5\x01\n\rDynExtendType\x12\x15\n\x11\x64yn_ext_type_none\x10\x00\x12\x16\n\x12\x64yn_ext_type_topic\x10\x01\x12\x14\n\x10\x64yn_ext_type_lbs\x10\x02\x12\x14\n\x10\x64yn_ext_type_hot\x10\x03\x12\x15\n\x11\x64yn_ext_type_game\x10\x04\x12\x17\n\x13\x64yn_ext_type_common\x10\x05\x12\x18\n\x14\x64yn_ext_type_biliCut\x10\x06\x12\x14\n\x10\x64yn_ext_type_ogv\x10\x07\x12\x19\n\x15\x64yn_ext_type_auto_ogv\x10\x08*\xfc\x05\n\rDynModuleType\x12\x0f\n\x0bmodule_none\x10\x00\x12\x11\n\rmodule_author\x10\x01\x12\x12\n\x0emodule_dispute\x10\x02\x12\x0f\n\x0bmodule_desc\x10\x03\x12\x12\n\x0emodule_dynamic\x10\x04\x12\x12\n\x0emodule_forward\x10\x05\x12\x13\n\x0fmodule_likeUser\x10\x06\x12\x11\n\rmodule_extend\x10\x07\x12\x15\n\x11module_additional\x10\x08\x12\x0f\n\x0bmodule_stat\x10\t\x12\x0f\n\x0bmodule_fold\x10\n\x12\x12\n\x0emodule_comment\x10\x0b\x12\x16\n\x12module_interaction\x10\x0c\x12\x19\n\x15module_author_forward\x10\r\x12\r\n\tmodule_ad\x10\x0e\x12\x11\n\rmodule_banner\x10\x0f\x12\x14\n\x10module_item_null\x10\x10\x12\x15\n\x11module_share_info\x10\x11\x12\x14\n\x10module_recommend\x10\x12\x12\x17\n\x13module_stat_forward\x10\x13\x12\x0e\n\nmodule_top\x10\x14\x12\x11\n\rmodule_bottom\x10\x15\x12\x10\n\x0cmodule_story\x10\x16\x12\x10\n\x0cmodule_topic\x10\x17\x12\x1c\n\x18module_topic_details_ext\x10\x18\x12\x12\n\x0emodule_top_tag\x10\x19\x12\x16\n\x12module_topic_brief\x10\x1a\x12\x10\n\x0cmodule_title\x10\x1b\x12\x11\n\rmodule_button\x10\x1c\x12\x11\n\rmodule_notice\x10\x1d\x12\x17\n\x13module_opus_summary\x10\x1e\x12\x14\n\x10module_copyright\x10\x1f\x12\x14\n\x10module_paragraph\x10 \x12\x12\n\x0emodule_blocked\x10!\x12\x16\n\x12module_text_notice\x10\"\x12\x1a\n\x16module_opus_collection\x10#*B\n\tEmojiType\x12\x0e\n\nemoji_none\x10\x00\x12\r\n\temoji_old\x10\x01\x12\r\n\temoji_new\x10\x02\x12\x07\n\x03vip\x10\x03*\x17\n\x0b\x45spaceStyle\x12\x08\n\x04moba\x10\x00*\x86\x01\n\x08\x46oldType\x12\x10\n\x0c\x46oldTypeZore\x10\x00\x12\x13\n\x0f\x46oldTypePublish\x10\x01\x12\x14\n\x10\x46oldTypeFrequent\x10\x02\x12\x11\n\rFoldTypeUnite\x10\x03\x12\x11\n\rFoldTypeLimit\x10\x04\x12\x17\n\x13\x46oldTypeTopicMerged\x10\x05*.\n\nFollowType\x12\x11\n\rft_not_follow\x10\x00\x12\r\n\tft_follow\x10\x01*@\n\rGoodsJumpType\x12\x0e\n\ngoods_none\x10\x00\x12\x10\n\x0cgoods_schema\x10\x01\x12\r\n\tgoods_url\x10\x02*9\n\x12HighlightTextStyle\x12\x0e\n\nstyle_none\x10\x00\x12\x13\n\x0fstyle_highlight\x10\x01*S\n\x17HomePageTabSttingStatus\x12\x13\n\x0fSETTING_INVALID\x10\x00\x12\x10\n\x0cSETTING_OPEN\x10\x01\x12\x11\n\rSETTING_CLOSE\x10\x02*@\n\x0cIconResLocal\x12\x17\n\x13ICON_RES_LOCAL_NONE\x10\x00\x12\x17\n\x13ICON_RES_LOCAL_LIVE\x10\x01*:\n\nImageStyle\x12\x16\n\x12\x61\x64\x64_style_vertical\x10\x00\x12\x14\n\x10\x61\x64\x64_style_square\x10\x01*1\n\rLightFromType\x12\x0e\n\nfrom_login\x10\x00\x12\x10\n\x0c\x66rom_unlogin\x10\x01*\x93\x03\n\x0cLinkNodeType\x12\x0b\n\x07INVALID\x10\x00\x12\t\n\x05VIDEO\x10\x01\x12\x0b\n\x07RESERVE\x10\x02\x12\x08\n\x04VOTE\x10\x03\x12\x08\n\x04LIVE\x10\x04\x12\x0b\n\x07LOTTERY\x10\x05\x12\t\n\x05MATCH\x10\x06\x12\t\n\x05GOODS\x10\x07\x12\n\n\x06OGV_SS\x10\x08\x12\n\n\x06OGV_EP\x10\t\x12\t\n\x05MANGA\x10\n\x12\n\n\x06\x43HEESE\x10\x0b\x12\x0c\n\x08VIDEO_TS\x10\x0c\x12\x06\n\x02\x41T\x10\r\x12\x0c\n\x08HASH_TAG\x10\x0e\x12\x0b\n\x07\x41RTICLE\x10\x0f\x12\x07\n\x03URL\x10\x10\x12\x08\n\x04MAIL\x10\x11\x12\x07\n\x03LBS\x10\x12\x12\x0c\n\x08\x41\x43TIVITY\x10\x13\x12!\n\x1d\x41TTACH_CARD_OFFICIAL_ACTIVITY\x10\x14\x12\x08\n\x04GAME\x10\x15\x12\x0e\n\nDECORATION\x10\x16\x12\x0c\n\x08UP_TOPIC\x10\x17\x12\x0f\n\x0bUP_ACTIVITY\x10\x18\x12\x0c\n\x08UP_MAOER\x10\x19\x12\x10\n\x0cMEMBER_GOODS\x10\x1a\x12\x15\n\x11OPENMALL_UP_ITEMS\x10\x1b\x12\n\n\x06SEARCH\x10\x1c*<\n\tLiveState\x12\r\n\tlive_none\x10\x00\x12\r\n\tlive_live\x10\x01\x12\x11\n\rlive_rotation\x10\x02*\x8a\x01\n\rLocalIconType\x12\x16\n\x12local_icon_comment\x10\x00\x12\x13\n\x0flocal_icon_like\x10\x01\x12\x15\n\x11local_icon_avatar\x10\x02\x12\x14\n\x10local_icon_cover\x10\x03\x12\x1f\n\x1blocal_icon_like_and_forward\x10\x04*\x8d\x01\n\x0fMdlBlockedStyle\x12\x19\n\x15\x42LOCKED_STYLE_DEFAULT\x10\x00\x12\x1a\n\x16\x42LOCKED_STYLE_IN_AUDIT\x10\x01\x12 \n\x1c\x42LOCKED_STYLE_ONLY_FANS_LIST\x10\x02\x12!\n\x1d\x42LOCKED_STYLE_ONLY_FANS_VIDEO\x10\x03*b\n\x10MdlDynCommonType\x12\x17\n\x13mdl_dyn_common_none\x10\x00\x12\x19\n\x15mdl_dyn_common_square\x10\x01\x12\x1a\n\x16mdl_dyn_common_vertica\x10\x02*\xa0\x01\n\x11MdlDynDrawTagType\x12\x15\n\x11mdl_draw_tag_none\x10\x00\x12\x17\n\x13mdl_draw_tag_common\x10\x01\x12\x16\n\x12mdl_draw_tag_goods\x10\x02\x12\x15\n\x11mdl_draw_tag_user\x10\x03\x12\x16\n\x12mdl_draw_tag_topic\x10\x04\x12\x14\n\x10mdl_draw_tag_lbs\x10\x05*\x97\x01\n\x1aMdlDynSubscriptionNewStyle\x12\'\n#mdl_dyn_subscription_new_style_nont\x10\x00\x12\'\n#mdl_dyn_subscription_new_style_live\x10\x01\x12\'\n#mdl_dyn_subscription_new_style_draw\x10\x02*g\n\tMediaType\x12\x11\n\rMediaTypeNone\x10\x00\x12\x10\n\x0cMediaTypeUGC\x10\x01\x12\x10\n\x0cMediaTypePGC\x10\x02\x12\x11\n\rMediaTypeLive\x10\x03\x12\x10\n\x0cMediaTypeVCS\x10\x04*\xad\x01\n\x15ModuleAuthorBadgeType\x12!\n\x1dmodule_author_badge_type_none\x10\x00\x12\'\n#module_author_badge_type_threePoint\x10\x01\x12#\n\x1fmodule_author_badge_type_button\x10\x02\x12#\n\x1fmodule_author_badge_type_weight\x10\x03*L\n\x10ModuleBannerType\x12\x1b\n\x17module_banner_type_none\x10\x00\x12\x1b\n\x17module_banner_type_user\x10\x01*\xa3\x03\n\x11ModuleDynamicType\x12\x13\n\x0fmdl_dyn_archive\x10\x00\x12\x0f\n\x0bmdl_dyn_pgc\x10\x01\x12\x17\n\x13mdl_dyn_cour_season\x10\x02\x12\x16\n\x12mdl_dyn_cour_batch\x10\x03\x12\x13\n\x0fmdl_dyn_forward\x10\x04\x12\x10\n\x0cmdl_dyn_draw\x10\x05\x12\x13\n\x0fmdl_dyn_article\x10\x06\x12\x11\n\rmdl_dyn_music\x10\x07\x12\x12\n\x0emdl_dyn_common\x10\x08\x12\x10\n\x0cmdl_dyn_live\x10\t\x12\x15\n\x11mdl_dyn_medialist\x10\n\x12\x12\n\x0emdl_dyn_applet\x10\x0b\x12\x18\n\x14mdl_dyn_subscription\x10\x0c\x12\x15\n\x11mdl_dyn_live_rcmd\x10\r\x12\x16\n\x12mdl_dyn_ugc_season\x10\x0e\x12\x1c\n\x18mdl_dyn_subscription_new\x10\x0f\x12\x19\n\x15mdl_dyn_cour_batch_up\x10\x10\x12\x15\n\x11mdl_dyn_topic_set\x10\x11*^\n\x0bNetworkType\x12\x0e\n\nNT_UNKNOWN\x10\x00\x12\x08\n\x04WIFI\x10\x01\x12\x0c\n\x08\x43\x45LLULAR\x10\x02\x12\x0b\n\x07OFFLINE\x10\x03\x12\x0c\n\x08OTHERNET\x10\x04\x12\x0c\n\x08\x45THERNET\x10\x05*T\n\rNFTRegionType\x12\x16\n\x12nft_region_default\x10\x00\x12\x17\n\x13nft_region_mainlang\x10\x01\x12\x12\n\x0enft_region_gat\x10\x02*T\n\rNFTShowStatus\x12\x14\n\x10nft_show_default\x10\x00\x12\x1b\n\x17nft_show_zoominmainlang\x10\x01\x12\x10\n\x0cnft_show_raw\x10\x02*\x9d\x01\n\x0fRcmdReasonStyle\x12\x1a\n\x16rcmd_reason_style_none\x10\x00\x12#\n\x1frcmd_reason_style_campus_nearby\x10\x01\x12\x1f\n\x1brcmd_reason_style_campus_up\x10\x02\x12(\n$rcmd_reason_style_campus_near_up_mix\x10\x03*.\n\x08RcmdType\x12\x10\n\x0crcmd_archive\x10\x00\x12\x10\n\x0crcmd_dynamic\x10\x01*/\n\x07Refresh\x12\x0f\n\x0brefresh_new\x10\x00\x12\x13\n\x0frefresh_history\x10\x01*\xc3\x01\n\x0eRelationStatus\x12\x18\n\x14relation_status_none\x10\x00\x12\x1c\n\x18relation_status_nofollow\x10\x01\x12\x1a\n\x16relation_status_follow\x10\x02\x12\x1c\n\x18relation_status_followed\x10\x03\x12\"\n\x1erelation_status_mutual_concern\x10\x04\x12\x1b\n\x17relation_status_special\x10\x05*0\n\nRepostType\x12\x0e\n\nrepost_hot\x10\x00\x12\x12\n\x0erepost_general\x10\x01*o\n\x1aReserveRelationLotteryType\x12)\n%reserve_relation_lottery_type_default\x10\x00\x12&\n\"reserve_relation_lottery_type_cron\x10\x01*3\n\x0bReserveType\x12\x10\n\x0creserve_none\x10\x00\x12\x12\n\x0ereserve_recall\x10\x01*#\n\x0cRouterAction\x12\x08\n\x04OPEN\x10\x00\x12\t\n\x05\x45MBED\x10\x01*4\n\x08ShowType\x12\x12\n\x0eshow_type_none\x10\x00\x12\x14\n\x10show_type_backup\x10\x01*L\n\tStyleType\x12\x13\n\x0fSTYLE_TYPE_NONE\x10\x00\x12\x13\n\x0fSTYLE_TYPE_LIVE\x10\x01\x12\x15\n\x11STYLE_TYPE_DYN_UP\x10\x02*]\n\x06TFType\x12\x0e\n\nTF_UNKNOWN\x10\x00\x12\n\n\x06U_CARD\x10\x01\x12\t\n\x05U_PKG\x10\x02\x12\n\n\x06\x43_CARD\x10\x03\x12\t\n\x05\x43_PKG\x10\x04\x12\n\n\x06T_CARD\x10\x05\x12\t\n\x05T_PKG\x10\x06*C\n\x19ThreePointAttentionStatus\x12\x14\n\x10tp_not_attention\x10\x00\x12\x10\n\x0ctp_attention\x10\x01*\xdc\x01\n\x0eThreePointType\x12\x0b\n\x07tp_none\x10\x00\x12\x0e\n\nbackground\x10\x01\x12\r\n\tauto_play\x10\x02\x12\t\n\x05share\x10\x03\x12\x08\n\x04wait\x10\x04\x12\r\n\tattention\x10\x05\x12\n\n\x06report\x10\x06\x12\n\n\x06\x64\x65lete\x10\x07\x12\x0b\n\x07\x64islike\x10\x08\x12\x0c\n\x08\x66\x61vorite\x10\t\x12\x07\n\x03top\x10\n\x12\x0b\n\x07\x63omment\x10\x0b\x12\x08\n\x04hide\x10\x0c\x12\x11\n\rcampus_delete\x10\r\x12\x14\n\x10topic_irrelevant\x10\x0e*\"\n\tThumbType\x12\n\n\x06\x63\x61ncel\x10\x00\x12\t\n\x05thumb\x10\x01*\'\n\x07TopType\x12\x0c\n\x08top_none\x10\x00\x12\x0e\n\ntop_cancel\x10\x01*\xb4\x02\n\x0cUserItemType\x12\x17\n\x13user_item_type_none\x10\x00\x12\x17\n\x13user_item_type_live\x10\x01\x12\x1e\n\x1auser_item_type_live_custom\x10\x02\x12\x19\n\x15user_item_type_normal\x10\x03\x12\x19\n\x15user_item_type_extend\x10\x04\x12#\n\x1fuser_item_type_premiere_reserve\x10\x05\x12\x1b\n\x17user_item_type_premiere\x10\x06\x12\x1c\n\x18user_item_type_live_card\x10\x07\x12\x1d\n\x19user_item_type_ogv_season\x10\x08\x12\x1d\n\x19user_item_type_ugc_season\x10\t*\xa5\x01\n\x0cVideoSubType\x12\x14\n\x10VideoSubTypeNone\x10\x00\x12\x17\n\x13VideoSubTypeBangumi\x10\x01\x12\x15\n\x11VideoSubTypeMovie\x10\x02\x12\x1b\n\x17VideoSubTypeDocumentary\x10\x03\x12\x18\n\x14VideoSubTypeDomestic\x10\x04\x12\x18\n\x14VideoSubTypeTeleplay\x10\x05*j\n\tVideoType\x12\x16\n\x12video_type_general\x10\x00\x12\x16\n\x12video_type_dynamic\x10\x01\x12\x17\n\x13video_type_playback\x10\x02\x12\x14\n\x10video_type_story\x10\x03*\'\n\nVoteStatus\x12\n\n\x06normal\x10\x00\x12\r\n\tanonymous\x10\x01*B\n\nWeightType\x12\x0f\n\x0bweight_none\x10\x00\x12\x12\n\x0eweight_dislike\x10\x01\x12\x0f\n\x0bweight_jump\x10\x02*`\n\nWFItemType\x12\x18\n\x14WATER_FLOW_TYPE_NONE\x10\x00\x12\x1b\n\x17WATER_FLOW_TYPE_ARCHIVE\x10\x01\x12\x1b\n\x17WATER_FLOW_TYPE_DYNAMIC\x10\x02\x32\x90-\n\x07\x44ynamic\x12j\n\x0e\x41lumniDynamics\x12*.bilibili.app.dynamic.v2.AlumniDynamicsReq\x1a,.bilibili.app.dynamic.v2.AlumniDynamicsReply\x12m\n\x0f\x43\x61mpusBillBoard\x12+.bilibili.app.dynamic.v2.CampusBillBoardReq\x1a-.bilibili.app.dynamic.v2.CampusBillBoardReply\x12i\n\x0e\x43\x61mpusEntryTab\x12*.bilibili.app.dynamic.v2.CampusEntryTabReq\x1a+.bilibili.app.dynamic.v2.CampusEntryTabResp\x12j\n\x0e\x43\x61mpusFeedback\x12*.bilibili.app.dynamic.v2.CampusFeedbackReq\x1a,.bilibili.app.dynamic.v2.CampusFeedbackReply\x12m\n\x0f\x43\x61mpusHomePages\x12+.bilibili.app.dynamic.v2.CampusHomePagesReq\x1a-.bilibili.app.dynamic.v2.CampusHomePagesReply\x12v\n\x12\x43\x61mpusMateLikeList\x12..bilibili.app.dynamic.v2.CampusMateLikeListReq\x1a\x30.bilibili.app.dynamic.v2.CampusMateLikeListReply\x12m\n\x0f\x43\x61mpusMngDetail\x12+.bilibili.app.dynamic.v2.CampusMngDetailReq\x1a-.bilibili.app.dynamic.v2.CampusMngDetailReply\x12|\n\x14\x43\x61mpusMngQuizOperate\x12\x30.bilibili.app.dynamic.v2.CampusMngQuizOperateReq\x1a\x32.bilibili.app.dynamic.v2.CampusMngQuizOperateReply\x12m\n\x0f\x43\x61mpusMngSubmit\x12+.bilibili.app.dynamic.v2.CampusMngSubmitReq\x1a-.bilibili.app.dynamic.v2.CampusMngSubmitReply\x12^\n\nCampusRcmd\x12&.bilibili.app.dynamic.v2.CampusRcmdReq\x1a(.bilibili.app.dynamic.v2.CampusRcmdReply\x12j\n\x0e\x43\x61mpusRcmdFeed\x12*.bilibili.app.dynamic.v2.CampusRcmdFeedReq\x1a,.bilibili.app.dynamic.v2.CampusRcmdFeedReply\x12m\n\x0f\x43\x61mpusRecommend\x12+.bilibili.app.dynamic.v2.CampusRecommendReq\x1a-.bilibili.app.dynamic.v2.CampusRecommendReply\x12\x64\n\x0c\x43\x61mpusRedDot\x12(.bilibili.app.dynamic.v2.CampusRedDotReq\x1a*.bilibili.app.dynamic.v2.CampusRedDotReply\x12\x64\n\x0c\x43\x61mpusSquare\x12(.bilibili.app.dynamic.v2.CampusSquareReq\x1a*.bilibili.app.dynamic.v2.CampusSquareReply\x12y\n\x13\x43\x61mpusTopicRcmdFeed\x12/.bilibili.app.dynamic.v2.CampusTopicRcmdFeedReq\x1a\x31.bilibili.app.dynamic.v2.CampusTopicRcmdFeedReply\x12\x85\x01\n\x17\x44ynAdditionCommonFollow\x12\x33.bilibili.app.dynamic.v2.DynAdditionCommonFollowReq\x1a\x35.bilibili.app.dynamic.v2.DynAdditionCommonFollowReply\x12R\n\x06\x44ynAll\x12\".bilibili.app.dynamic.v2.DynAllReq\x1a$.bilibili.app.dynamic.v2.DynAllReply\x12j\n\x0e\x44ynAllPersonal\x12*.bilibili.app.dynamic.v2.DynAllPersonalReq\x1a,.bilibili.app.dynamic.v2.DynAllPersonalReply\x12`\n\x0f\x44ynAllUpdOffset\x12+.bilibili.app.dynamic.v2.DynAllUpdOffsetReq\x1a .bilibili.app.dynamic.v2.NoReply\x12[\n\tDynDetail\x12%.bilibili.app.dynamic.v2.DynDetailReq\x1a\'.bilibili.app.dynamic.v2.DynDetailReply\x12^\n\nDynDetails\x12&.bilibili.app.dynamic.v2.DynDetailsReq\x1a(.bilibili.app.dynamic.v2.DynDetailsReply\x12\x61\n\x0b\x44ynFakeCard\x12\'.bilibili.app.dynamic.v2.DynFakeCardReq\x1a).bilibili.app.dynamic.v2.DynFakeCardReply\x12[\n\tDynFriend\x12%.bilibili.app.dynamic.v2.DynFriendReq\x1a\'.bilibili.app.dynamic.v2.DynFriendReply\x12X\n\x08\x44ynLight\x12$.bilibili.app.dynamic.v2.DynLightReq\x1a&.bilibili.app.dynamic.v2.DynLightReply\x12|\n\x14\x44ynMixUpListViewMore\x12\x30.bilibili.app.dynamic.v2.DynMixUpListViewMoreReq\x1a\x32.bilibili.app.dynamic.v2.DynMixUpListViewMoreReply\x12s\n\x11\x44ynRcmdUpExchange\x12-.bilibili.app.dynamic.v2.DynRcmdUpExchangeReq\x1a/.bilibili.app.dynamic.v2.DynRcmdUpExchangeReply\x12[\n\tDynSearch\x12%.bilibili.app.dynamic.v2.DynSearchReq\x1a\'.bilibili.app.dynamic.v2.DynSearchReply\x12p\n\x10\x44ynServerDetails\x12,.bilibili.app.dynamic.v2.DynServerDetailsReq\x1a..bilibili.app.dynamic.v2.DynServerDetailsReply\x12V\n\x08\x44ynSpace\x12$.bilibili.app.dynamic.v2.DynSpaceReq\x1a$.bilibili.app.dynamic.v2.DynSpaceRsp\x12\x7f\n\x15\x44ynSpaceSearchDetails\x12\x31.bilibili.app.dynamic.v2.DynSpaceSearchDetailsReq\x1a\x33.bilibili.app.dynamic.v2.DynSpaceSearchDetailsReply\x12R\n\x06\x44ynTab\x12\".bilibili.app.dynamic.v2.DynTabReq\x1a$.bilibili.app.dynamic.v2.DynTabReply\x12R\n\x08\x44ynThumb\x12$.bilibili.app.dynamic.v2.DynThumbReq\x1a .bilibili.app.dynamic.v2.NoReply\x12\\\n\x0e\x44ynUnLoginRcmd\x12#.bilibili.app.dynamic.v2.DynRcmdReq\x1a%.bilibili.app.dynamic.v2.DynRcmdReply\x12X\n\x08\x44ynVideo\x12$.bilibili.app.dynamic.v2.DynVideoReq\x1a&.bilibili.app.dynamic.v2.DynVideoReply\x12p\n\x10\x44ynVideoPersonal\x12,.bilibili.app.dynamic.v2.DynVideoPersonalReq\x1a..bilibili.app.dynamic.v2.DynVideoPersonalReply\x12\x64\n\x11\x44ynVideoUpdOffset\x12-.bilibili.app.dynamic.v2.DynVideoUpdOffsetReq\x1a .bilibili.app.dynamic.v2.NoReply\x12U\n\x07\x44ynVote\x12#.bilibili.app.dynamic.v2.DynVoteReq\x1a%.bilibili.app.dynamic.v2.DynVoteReply\x12^\n\nFeedFilter\x12&.bilibili.app.dynamic.v2.FeedFilterReq\x1a(.bilibili.app.dynamic.v2.FeedFilterReply\x12`\n\x0f\x46\x65tchTabSetting\x12\x1e.bilibili.app.dynamic.v2.NoReq\x1a-.bilibili.app.dynamic.v2.FetchTabSettingReply\x12g\n\rHomeSubscribe\x12).bilibili.app.dynamic.v2.HomeSubscribeReq\x1a+.bilibili.app.dynamic.v2.HomeSubscribeReply\x12R\n\x06LbsPoi\x12\".bilibili.app.dynamic.v2.LbsPoiReq\x1a$.bilibili.app.dynamic.v2.LbsPoiReply\x12m\n\x0fLegacyTopicFeed\x12+.bilibili.app.dynamic.v2.LegacyTopicFeedReq\x1a-.bilibili.app.dynamic.v2.LegacyTopicFeedReply\x12X\n\x08LikeList\x12$.bilibili.app.dynamic.v2.LikeListReq\x1a&.bilibili.app.dynamic.v2.LikeListReply\x12p\n\x10OfficialAccounts\x12,.bilibili.app.dynamic.v2.OfficialAccountsReq\x1a..bilibili.app.dynamic.v2.OfficialAccountsReply\x12p\n\x10OfficialDynamics\x12,.bilibili.app.dynamic.v2.OfficialDynamicsReq\x1a..bilibili.app.dynamic.v2.OfficialDynamicsReply\x12\x64\n\x0cReactionList\x12(.bilibili.app.dynamic.v2.ReactionListReq\x1a*.bilibili.app.dynamic.v2.ReactionListReply\x12\\\n\nRepostList\x12&.bilibili.app.dynamic.v2.RepostListReq\x1a&.bilibili.app.dynamic.v2.RepostListRsp\x12m\n\x0fSchoolRecommend\x12+.bilibili.app.dynamic.v2.SchoolRecommendReq\x1a-.bilibili.app.dynamic.v2.SchoolRecommendReply\x12\x64\n\x0cSchoolSearch\x12(.bilibili.app.dynamic.v2.SchoolSearchReq\x1a*.bilibili.app.dynamic.v2.SchoolSearchReply\x12X\n\x0bSetDecision\x12\'.bilibili.app.dynamic.v2.SetDecisionReq\x1a .bilibili.app.dynamic.v2.NoReply\x12`\n\x0fSetRecentCampus\x12+.bilibili.app.dynamic.v2.SetRecentCampusReq\x1a .bilibili.app.dynamic.v2.NoReply\x12`\n\x0fSubscribeCampus\x12+.bilibili.app.dynamic.v2.SubscribeCampusReq\x1a .bilibili.app.dynamic.v2.NoReply\x12[\n\tTopicList\x12%.bilibili.app.dynamic.v2.TopicListReq\x1a\'.bilibili.app.dynamic.v2.TopicListReply\x12\x61\n\x0bTopicSquare\x12\'.bilibili.app.dynamic.v2.TopicSquareReq\x1a).bilibili.app.dynamic.v2.TopicSquareReply\x12\\\n\rUnfollowMatch\x12).bilibili.app.dynamic.v2.UnfollowMatchReq\x1a .bilibili.app.dynamic.v2.NoReply\x12\x62\n\x10UpdateTabSetting\x12,.bilibili.app.dynamic.v2.UpdateTabSettingReq\x1a .bilibili.app.dynamic.v2.NoReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.dynamic.v2.dynamic_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DYNSERVERDETAILSREPLY_ITEMSENTRY._options = None
  _DYNSERVERDETAILSREPLY_ITEMSENTRY._serialized_options = b'8\001'
  _DYNSPACESEARCHDETAILSREPLY_ITEMSENTRY._options = None
  _DYNSPACESEARCHDETAILSREPLY_ITEMSENTRY._serialized_options = b'8\001'
  _EXTEND_HISTORYREPORTENTRY._options = None
  _EXTEND_HISTORYREPORTENTRY._serialized_options = b'8\001'
  _globals['_ADDBUTTONBGSTYLE']._serialized_start=60358
  _globals['_ADDBUTTONBGSTYLE']._serialized_end=60408
  _globals['_ADDBUTTONTYPE']._serialized_start=60410
  _globals['_ADDBUTTONTYPE']._serialized_end=60466
  _globals['_ADDITIONALBUTTONCLICKTYPE']._serialized_start=60468
  _globals['_ADDITIONALBUTTONCLICKTYPE']._serialized_end=60525
  _globals['_ADDITIONALBUTTONSTATUS']._serialized_start=60527
  _globals['_ADDITIONALBUTTONSTATUS']._serialized_end=60585
  _globals['_ADDITIONALSHARESHOWTYPE']._serialized_start=60587
  _globals['_ADDITIONALSHARESHOWTYPE']._serialized_end=60638
  _globals['_ADDITIONALTYPE']._serialized_start=60641
  _globals['_ADDITIONALTYPE']._serialized_end=60902
  _globals['_ADDITIONVOTESTATE']._serialized_start=60904
  _globals['_ADDITIONVOTESTATE']._serialized_end=61014
  _globals['_ADDITIONVOTETYPE']._serialized_start=61017
  _globals['_ADDITIONVOTETYPE']._serialized_end=61153
  _globals['_CAMPUSENTRYTYPE']._serialized_start=61155
  _globals['_CAMPUSENTRYTYPE']._serialized_end=61217
  _globals['_CAMPUSRCMDREQFROM']._serialized_start=61220
  _globals['_CAMPUSRCMDREQFROM']._serialized_end=61451
  _globals['_CAMPUSHOMEPAGETYPE']._serialized_start=61453
  _globals['_CAMPUSHOMEPAGETYPE']._serialized_end=61534
  _globals['_CAMPUSMNGAUDITSTATUS']._serialized_start=61536
  _globals['_CAMPUSMNGAUDITSTATUS']._serialized_end=61647
  _globals['_CAMPUSMNGITEMTYPE']._serialized_start=61650
  _globals['_CAMPUSMNGITEMTYPE']._serialized_end=61783
  _globals['_CAMPUSMNGQUIZACTION']._serialized_start=61785
  _globals['_CAMPUSMNGQUIZACTION']._serialized_end=61894
  _globals['_CAMPUSONLINESTATUS']._serialized_start=61896
  _globals['_CAMPUSONLINESTATUS']._serialized_end=61969
  _globals['_CAMPUSREQFROMTYPE']._serialized_start=61971
  _globals['_CAMPUSREQFROMTYPE']._serialized_end=62013
  _globals['_CAMPUSTABTYPE']._serialized_start=62016
  _globals['_CAMPUSTABTYPE']._serialized_end=62166
  _globals['_COVERICON']._serialized_start=62168
  _globals['_COVERICON']._serialized_end=62283
  _globals['_DESCTYPE']._serialized_start=62286
  _globals['_DESCTYPE']._serialized_end=62690
  _globals['_DISABLESTATE']._serialized_start=62692
  _globals['_DISABLESTATE']._serialized_end=62731
  _globals['_DYNAMICTYPE']._serialized_start=62734
  _globals['_DYNAMICTYPE']._serialized_end=63130
  _globals['_DYNEXTENDTYPE']._serialized_start=63133
  _globals['_DYNEXTENDTYPE']._serialized_end=63362
  _globals['_DYNMODULETYPE']._serialized_start=63365
  _globals['_DYNMODULETYPE']._serialized_end=64129
  _globals['_EMOJITYPE']._serialized_start=64131
  _globals['_EMOJITYPE']._serialized_end=64197
  _globals['_ESPACESTYLE']._serialized_start=64199
  _globals['_ESPACESTYLE']._serialized_end=64222
  _globals['_FOLDTYPE']._serialized_start=64225
  _globals['_FOLDTYPE']._serialized_end=64359
  _globals['_FOLLOWTYPE']._serialized_start=64361
  _globals['_FOLLOWTYPE']._serialized_end=64407
  _globals['_GOODSJUMPTYPE']._serialized_start=64409
  _globals['_GOODSJUMPTYPE']._serialized_end=64473
  _globals['_HIGHLIGHTTEXTSTYLE']._serialized_start=64475
  _globals['_HIGHLIGHTTEXTSTYLE']._serialized_end=64532
  _globals['_HOMEPAGETABSTTINGSTATUS']._serialized_start=64534
  _globals['_HOMEPAGETABSTTINGSTATUS']._serialized_end=64617
  _globals['_ICONRESLOCAL']._serialized_start=64619
  _globals['_ICONRESLOCAL']._serialized_end=64683
  _globals['_IMAGESTYLE']._serialized_start=64685
  _globals['_IMAGESTYLE']._serialized_end=64743
  _globals['_LIGHTFROMTYPE']._serialized_start=64745
  _globals['_LIGHTFROMTYPE']._serialized_end=64794
  _globals['_LINKNODETYPE']._serialized_start=64797
  _globals['_LINKNODETYPE']._serialized_end=65200
  _globals['_LIVESTATE']._serialized_start=65202
  _globals['_LIVESTATE']._serialized_end=65262
  _globals['_LOCALICONTYPE']._serialized_start=65265
  _globals['_LOCALICONTYPE']._serialized_end=65403
  _globals['_MDLBLOCKEDSTYLE']._serialized_start=65406
  _globals['_MDLBLOCKEDSTYLE']._serialized_end=65547
  _globals['_MDLDYNCOMMONTYPE']._serialized_start=65549
  _globals['_MDLDYNCOMMONTYPE']._serialized_end=65647
  _globals['_MDLDYNDRAWTAGTYPE']._serialized_start=65650
  _globals['_MDLDYNDRAWTAGTYPE']._serialized_end=65810
  _globals['_MDLDYNSUBSCRIPTIONNEWSTYLE']._serialized_start=65813
  _globals['_MDLDYNSUBSCRIPTIONNEWSTYLE']._serialized_end=65964
  _globals['_MEDIATYPE']._serialized_start=65966
  _globals['_MEDIATYPE']._serialized_end=66069
  _globals['_MODULEAUTHORBADGETYPE']._serialized_start=66072
  _globals['_MODULEAUTHORBADGETYPE']._serialized_end=66245
  _globals['_MODULEBANNERTYPE']._serialized_start=66247
  _globals['_MODULEBANNERTYPE']._serialized_end=66323
  _globals['_MODULEDYNAMICTYPE']._serialized_start=66326
  _globals['_MODULEDYNAMICTYPE']._serialized_end=66745
  _globals['_NETWORKTYPE']._serialized_start=66747
  _globals['_NETWORKTYPE']._serialized_end=66841
  _globals['_NFTREGIONTYPE']._serialized_start=66843
  _globals['_NFTREGIONTYPE']._serialized_end=66927
  _globals['_NFTSHOWSTATUS']._serialized_start=66929
  _globals['_NFTSHOWSTATUS']._serialized_end=67013
  _globals['_RCMDREASONSTYLE']._serialized_start=67016
  _globals['_RCMDREASONSTYLE']._serialized_end=67173
  _globals['_RCMDTYPE']._serialized_start=67175
  _globals['_RCMDTYPE']._serialized_end=67221
  _globals['_REFRESH']._serialized_start=67223
  _globals['_REFRESH']._serialized_end=67270
  _globals['_RELATIONSTATUS']._serialized_start=67273
  _globals['_RELATIONSTATUS']._serialized_end=67468
  _globals['_REPOSTTYPE']._serialized_start=67470
  _globals['_REPOSTTYPE']._serialized_end=67518
  _globals['_RESERVERELATIONLOTTERYTYPE']._serialized_start=67520
  _globals['_RESERVERELATIONLOTTERYTYPE']._serialized_end=67631
  _globals['_RESERVETYPE']._serialized_start=67633
  _globals['_RESERVETYPE']._serialized_end=67684
  _globals['_ROUTERACTION']._serialized_start=67686
  _globals['_ROUTERACTION']._serialized_end=67721
  _globals['_SHOWTYPE']._serialized_start=67723
  _globals['_SHOWTYPE']._serialized_end=67775
  _globals['_STYLETYPE']._serialized_start=67777
  _globals['_STYLETYPE']._serialized_end=67853
  _globals['_TFTYPE']._serialized_start=67855
  _globals['_TFTYPE']._serialized_end=67948
  _globals['_THREEPOINTATTENTIONSTATUS']._serialized_start=67950
  _globals['_THREEPOINTATTENTIONSTATUS']._serialized_end=68017
  _globals['_THREEPOINTTYPE']._serialized_start=68020
  _globals['_THREEPOINTTYPE']._serialized_end=68240
  _globals['_THUMBTYPE']._serialized_start=68242
  _globals['_THUMBTYPE']._serialized_end=68276
  _globals['_TOPTYPE']._serialized_start=68278
  _globals['_TOPTYPE']._serialized_end=68317
  _globals['_USERITEMTYPE']._serialized_start=68320
  _globals['_USERITEMTYPE']._serialized_end=68628
  _globals['_VIDEOSUBTYPE']._serialized_start=68631
  _globals['_VIDEOSUBTYPE']._serialized_end=68796
  _globals['_VIDEOTYPE']._serialized_start=68798
  _globals['_VIDEOTYPE']._serialized_end=68904
  _globals['_VOTESTATUS']._serialized_start=68906
  _globals['_VOTESTATUS']._serialized_end=68945
  _globals['_WEIGHTTYPE']._serialized_start=68947
  _globals['_WEIGHTTYPE']._serialized_end=69013
  _globals['_WFITEMTYPE']._serialized_start=69015
  _globals['_WFITEMTYPE']._serialized_end=69111
  _globals['_ADDITIONALACTSKIN']._serialized_start=191
  _globals['_ADDITIONALACTSKIN']._serialized_end=264
  _globals['_ADDITIONALBUTTON']._serialized_start=267
  _globals['_ADDITIONALBUTTON']._serialized_end=690
  _globals['_ADDITIONALBUTTONINTERACTIVE']._serialized_start=692
  _globals['_ADDITIONALBUTTONINTERACTIVE']._serialized_end=784
  _globals['_ADDITIONALBUTTONSHARE']._serialized_start=786
  _globals['_ADDITIONALBUTTONSHARE']._serialized_end=851
  _globals['_ADDITIONALBUTTONSTYLE']._serialized_start=854
  _globals['_ADDITIONALBUTTONSTYLE']._serialized_end=1175
  _globals['_ADDITIONALPGC']._serialized_start=1178
  _globals['_ADDITIONALPGC']._serialized_end=1445
  _globals['_ADDITIONARTICLE']._serialized_start=1448
  _globals['_ADDITIONARTICLE']._serialized_end=1617
  _globals['_ADDITIONCOMMON']._serialized_start=1620
  _globals['_ADDITIONCOMMON']._serialized_end=1907
  _globals['_ADDITIONESPORT']._serialized_start=1910
  _globals['_ADDITIONESPORT']._serialized_end=2097
  _globals['_ADDITIONESPORTMOBA']._serialized_start=2100
  _globals['_ADDITIONESPORTMOBA']._serialized_end=2441
  _globals['_ADDITIONESPORTMOBASTATUS']._serialized_start=2444
  _globals['_ADDITIONESPORTMOBASTATUS']._serialized_end=2634
  _globals['_ADDITIONESPORTMOBASTATUSDESC']._serialized_start=2636
  _globals['_ADDITIONESPORTMOBASTATUSDESC']._serialized_end=2717
  _globals['_ADDITIONGOODS']._serialized_start=2720
  _globals['_ADDITIONGOODS']._serialized_end=2937
  _globals['_ADDITIONLIVEROOM']._serialized_start=2940
  _globals['_ADDITIONLIVEROOM']._serialized_end=3166
  _globals['_ADDITIONUGC']._serialized_start=3169
  _globals['_ADDITIONUGC']._serialized_end=3342
  _globals['_ADDITIONUP']._serialized_start=3345
  _globals['_ADDITIONUP']._serialized_end=3923
  _globals['_ADDITIONUSERINFO']._serialized_start=3925
  _globals['_ADDITIONUSERINFO']._serialized_end=3971
  _globals['_ADDITIONVOTE']._serialized_start=3973
  _globals['_ADDITIONVOTE']._serialized_end=4071
  _globals['_ADDITIONVOTE2']._serialized_start=4074
  _globals['_ADDITIONVOTE2']._serialized_end=4721
  _globals['_ADDITIONVOTEDEFAULE']._serialized_start=4723
  _globals['_ADDITIONVOTEDEFAULE']._serialized_end=4759
  _globals['_ADDITIONVOTEPIC']._serialized_start=4761
  _globals['_ADDITIONVOTEPIC']._serialized_end=4838
  _globals['_ADDITIONVOTEPICITEM']._serialized_start=4841
  _globals['_ADDITIONVOTEPICITEM']._serialized_end=4981
  _globals['_ADDITIONVOTEWORD']._serialized_start=4983
  _globals['_ADDITIONVOTEWORD']._serialized_end=5062
  _globals['_ADDITIONVOTEWORDITEM']._serialized_start=5064
  _globals['_ADDITIONVOTEWORDITEM']._serialized_end=5190
  _globals['_ADPARAM']._serialized_start=5192
  _globals['_ADPARAM']._serialized_end=5239
  _globals['_ALUMNIDYNAMICSREPLY']._serialized_start=5241
  _globals['_ALUMNIDYNAMICSREPLY']._serialized_end=5329
  _globals['_ALUMNIDYNAMICSREQ']._serialized_start=5332
  _globals['_ALUMNIDYNAMICSREQ']._serialized_end=5512
  _globals['_CAMPUSBANNERINFO']._serialized_start=5514
  _globals['_CAMPUSBANNERINFO']._serialized_end=5565
  _globals['_CAMPUSBILLBOARDINTERNALREQ']._serialized_start=5567
  _globals['_CAMPUSBILLBOARDINTERNALREQ']._serialized_end=5649
  _globals['_CAMPUSBILLBOARDREPLY']._serialized_start=5652
  _globals['_CAMPUSBILLBOARDREPLY']._serialized_end=5975
  _globals['_CAMPUSBILLBOARDREQ']._serialized_start=5978
  _globals['_CAMPUSBILLBOARDREQ']._serialized_end=6171
  _globals['_CAMPUSENTRYTABREQ']._serialized_start=6173
  _globals['_CAMPUSENTRYTABREQ']._serialized_end=6211
  _globals['_CAMPUSENTRYTABRESP']._serialized_start=6213
  _globals['_CAMPUSENTRYTABRESP']._serialized_end=6295
  _globals['_CAMPUSFEATUREPROGRESS']._serialized_start=6298
  _globals['_CAMPUSFEATUREPROGRESS']._serialized_end=6458
  _globals['_CAMPUSFEEDBACKINFO']._serialized_start=6460
  _globals['_CAMPUSFEEDBACKINFO']._serialized_end=6549
  _globals['_CAMPUSFEEDBACKREPLY']._serialized_start=6551
  _globals['_CAMPUSFEEDBACKREPLY']._serialized_end=6589
  _globals['_CAMPUSFEEDBACKREQ']._serialized_start=6591
  _globals['_CAMPUSFEEDBACKREQ']._serialized_end=6684
  _globals['_CAMPUSHOMEPAGESREPLY']._serialized_start=6687
  _globals['_CAMPUSHOMEPAGESREPLY']._serialized_end=6837
  _globals['_CAMPUSHOMEPAGESREQ']._serialized_start=6840
  _globals['_CAMPUSHOMEPAGESREQ']._serialized_end=7014
  _globals['_CAMPUSHOMERCMDTOPIC']._serialized_start=7016
  _globals['_CAMPUSHOMERCMDTOPIC']._serialized_end=7141
  _globals['_CAMPUSINFO']._serialized_start=7143
  _globals['_CAMPUSINFO']._serialized_end=7238
  _globals['_CAMPUSLABEL']._serialized_start=7240
  _globals['_CAMPUSLABEL']._serialized_end=7294
  _globals['_CAMPUSMATELIKELISTREPLY']._serialized_start=7296
  _globals['_CAMPUSMATELIKELISTREPLY']._serialized_end=7374
  _globals['_CAMPUSMATELIKELISTREQ']._serialized_start=7376
  _globals['_CAMPUSMATELIKELISTREQ']._serialized_end=7482
  _globals['_CAMPUSMNGBADGE']._serialized_start=7484
  _globals['_CAMPUSMNGBADGE']._serialized_end=7559
  _globals['_CAMPUSMNGBASICINFO']._serialized_start=7561
  _globals['_CAMPUSMNGBASICINFO']._serialized_end=7639
  _globals['_CAMPUSMNGDETAILREPLY']._serialized_start=7642
  _globals['_CAMPUSMNGDETAILREPLY']._serialized_end=7817
  _globals['_CAMPUSMNGDETAILREQ']._serialized_start=7819
  _globals['_CAMPUSMNGDETAILREQ']._serialized_end=7858
  _globals['_CAMPUSMNGITEM']._serialized_start=7861
  _globals['_CAMPUSMNGITEM']._serialized_end=8184
  _globals['_CAMPUSMNGQUIZ']._serialized_start=8187
  _globals['_CAMPUSMNGQUIZ']._serialized_end=8336
  _globals['_CAMPUSMNGQUIZDETAIL']._serialized_start=8339
  _globals['_CAMPUSMNGQUIZDETAIL']._serialized_end=8491
  _globals['_CAMPUSMNGQUIZOPERATEREPLY']._serialized_start=8493
  _globals['_CAMPUSMNGQUIZOPERATEREPLY']._serialized_end=8615
  _globals['_CAMPUSMNGQUIZOPERATEREQ']._serialized_start=8617
  _globals['_CAMPUSMNGQUIZOPERATEREQ']._serialized_end=8737
  _globals['_CAMPUSMNGSLOGAN']._serialized_start=8739
  _globals['_CAMPUSMNGSLOGAN']._serialized_end=8811
  _globals['_CAMPUSMNGSUBMITREPLY']._serialized_start=8813
  _globals['_CAMPUSMNGSUBMITREPLY']._serialized_end=8850
  _globals['_CAMPUSMNGSUBMITREQ']._serialized_start=8852
  _globals['_CAMPUSMNGSUBMITREQ']._serialized_end=8955
  _globals['_CAMPUSNOTICEINFO']._serialized_start=8957
  _globals['_CAMPUSNOTICEINFO']._serialized_end=9058
  _globals['_CAMPUSRCMDFEEDREPLY']._serialized_start=9061
  _globals['_CAMPUSRCMDFEEDREPLY']._serialized_end=9241
  _globals['_CAMPUSRCMDFEEDREQ']._serialized_start=9244
  _globals['_CAMPUSRCMDFEEDREQ']._serialized_end=9505
  _globals['_CAMPUSRCMDINFO']._serialized_start=9507
  _globals['_CAMPUSRCMDINFO']._serialized_end=9594
  _globals['_CAMPUSRCMDITEM']._serialized_start=9597
  _globals['_CAMPUSRCMDITEM']._serialized_end=9756
  _globals['_CAMPUSRCMDREPLY']._serialized_start=9759
  _globals['_CAMPUSRCMDREPLY']._serialized_end=9982
  _globals['_CAMPUSRCMDREQ']._serialized_start=9985
  _globals['_CAMPUSRCMDREQ']._serialized_end=10262
  _globals['_CAMPUSRCMDTOP']._serialized_start=10265
  _globals['_CAMPUSRCMDTOP']._serialized_end=10968
  _globals['_CAMPUSRECOMMENDREPLY']._serialized_start=10970
  _globals['_CAMPUSRECOMMENDREPLY']._serialized_end=11060
  _globals['_CAMPUSRECOMMENDREQ']._serialized_start=11063
  _globals['_CAMPUSRECOMMENDREQ']._serialized_end=11246
  _globals['_CAMPUSREDDOTREPLY']._serialized_start=11248
  _globals['_CAMPUSREDDOTREPLY']._serialized_end=11284
  _globals['_CAMPUSREDDOTREQ']._serialized_start=11286
  _globals['_CAMPUSREDDOTREQ']._serialized_end=11385
  _globals['_CAMPUSSHOWTABINFO']._serialized_start=11387
  _globals['_CAMPUSSHOWTABINFO']._serialized_end=11482
  _globals['_CAMPUSSQUAREREPLY']._serialized_start=11485
  _globals['_CAMPUSSQUAREREPLY']._serialized_end=11629
  _globals['_CAMPUSSQUAREREQ']._serialized_start=11631
  _globals['_CAMPUSSQUAREREQ']._serialized_end=11693
  _globals['_CAMPUSTOP']._serialized_start=11696
  _globals['_CAMPUSTOP']._serialized_end=12324
  _globals['_CAMPUSTOPICRCMDFEEDREPLY']._serialized_start=12327
  _globals['_CAMPUSTOPICRCMDFEEDREPLY']._serialized_end=12513
  _globals['_CAMPUSTOPICRCMDFEEDREQ']._serialized_start=12516
  _globals['_CAMPUSTOPICRCMDFEEDREQ']._serialized_end=12727
  _globals['_CARDPARAGRAPH']._serialized_start=12730
  _globals['_CARDPARAGRAPH']._serialized_end=12886
  _globals['_CARDVIDEODYNLIST']._serialized_start=12889
  _globals['_CARDVIDEODYNLIST']._serialized_end=13046
  _globals['_CARDVIDEOFOLLOWLIST']._serialized_start=13048
  _globals['_CARDVIDEOFOLLOWLIST']._serialized_end=13147
  _globals['_CARDVIDEOUPLIST']._serialized_start=13150
  _globals['_CARDVIDEOUPLIST']._serialized_end=13494
  _globals['_CHANNELINFO']._serialized_start=13497
  _globals['_CHANNELINFO']._serialized_end=13685
  _globals['_CMTSHOWITEM']._serialized_start=13687
  _globals['_CMTSHOWITEM']._serialized_end=13758
  _globals['_COLORS']._serialized_start=13760
  _globals['_COLORS']._serialized_end=13808
  _globals['_COMMENTDETAIL']._serialized_start=13810
  _globals['_COMMENTDETAIL']._serialized_end=13861
  _globals['_CONFIG']._serialized_start=13863
  _globals['_CONFIG']._serialized_end=13925
  _globals['_COVERICONWITHTEXT']._serialized_start=13927
  _globals['_COVERICONWITHTEXT']._serialized_end=13974
  _globals['_DECOCARDFAN']._serialized_start=13976
  _globals['_DECOCARDFAN']._serialized_end=14056
  _globals['_DECORATECARD']._serialized_start=14058
  _globals['_DECORATECARD']._serialized_end=14171
  _globals['_DESCRIPTION']._serialized_start=14174
  _globals['_DESCRIPTION']._serialized_end=14550
  _globals['_DIMENSION']._serialized_start=14552
  _globals['_DIMENSION']._serialized_end=14610
  _globals['_DYNADDITIONCOMMONFOLLOWREPLY']._serialized_start=14612
  _globals['_DYNADDITIONCOMMONFOLLOWREPLY']._serialized_end=14707
  _globals['_DYNADDITIONCOMMONFOLLOWREQ']._serialized_start=14710
  _globals['_DYNADDITIONCOMMONFOLLOWREQ']._serialized_end=14838
  _globals['_DYNALLPERSONALREPLY']._serialized_start=14841
  _globals['_DYNALLPERSONALREPLY']._serialized_end=15117
  _globals['_DYNALLPERSONALREQ']._serialized_start=15120
  _globals['_DYNALLPERSONALREQ']._serialized_end=15415
  _globals['_DYNALLREPLY']._serialized_start=15418
  _globals['_DYNALLREPLY']._serialized_end=15769
  _globals['_DYNALLREQ']._serialized_start=15772
  _globals['_DYNALLREQ']._serialized_end=16268
  _globals['_DYNALLUPDOFFSETREQ']._serialized_start=16270
  _globals['_DYNALLUPDOFFSETREQ']._serialized_end=16372
  _globals['_DYNAMICITEM']._serialized_start=16375
  _globals['_DYNAMICITEM']._serialized_end=16640
  _globals['_DYNAMICLIST']._serialized_start=16643
  _globals['_DYNAMICLIST']._serialized_end=16795
  _globals['_DYNDETAILREPLY']._serialized_start=16797
  _globals['_DYNDETAILREPLY']._serialized_end=16865
  _globals['_DYNDETAILREQ']._serialized_start=16868
  _globals['_DYNDETAILREQ']._serialized_end=17205
  _globals['_DYNDETAILSREPLY']._serialized_start=17207
  _globals['_DYNDETAILSREPLY']._serialized_end=17276
  _globals['_DYNDETAILSREQ']._serialized_start=17279
  _globals['_DYNDETAILSREQ']._serialized_end=17515
  _globals['_DYNFAKECARDREPLY']._serialized_start=17517
  _globals['_DYNFAKECARDREPLY']._serialized_end=17587
  _globals['_DYNFAKECARDREQ']._serialized_start=17589
  _globals['_DYNFAKECARDREQ']._serialized_end=17622
  _globals['_DYNFEATUREGATE']._serialized_start=17624
  _globals['_DYNFEATUREGATE']._serialized_end=17670
  _globals['_DYNFRIENDREPLY']._serialized_start=17672
  _globals['_DYNFRIENDREPLY']._serialized_end=17778
  _globals['_DYNFRIENDREQ']._serialized_start=17780
  _globals['_DYNFRIENDREQ']._serialized_end=17899
  _globals['_DYNLIGHTREPLY']._serialized_start=17901
  _globals['_DYNLIGHTREPLY']._serialized_end=17976
  _globals['_DYNLIGHTREQ']._serialized_start=17979
  _globals['_DYNLIGHTREQ']._serialized_end=18170
  _globals['_DYNMIXUPLISTVIEWMOREREPLY']._serialized_start=18173
  _globals['_DYNMIXUPLISTVIEWMOREREPLY']._serialized_end=18396
  _globals['_DYNMIXUPLISTVIEWMOREREQ']._serialized_start=18398
  _globals['_DYNMIXUPLISTVIEWMOREREQ']._serialized_end=18442
  _globals['_DYNRCMDREPLY']._serialized_start=18445
  _globals['_DYNRCMDREPLY']._serialized_end=18580
  _globals['_DYNRCMDREQ']._serialized_start=18583
  _globals['_DYNRCMDREQ']._serialized_end=18722
  _globals['_DYNRCMDUPEXCHANGEREPLY']._serialized_start=18724
  _globals['_DYNRCMDUPEXCHANGEREPLY']._serialized_end=18801
  _globals['_DYNRCMDUPEXCHANGEREQ']._serialized_start=18803
  _globals['_DYNRCMDUPEXCHANGEREQ']._serialized_end=18871
  _globals['_DYNREGIONRCMD']._serialized_start=18873
  _globals['_DYNREGIONRCMD']._serialized_end=18998
  _globals['_DYNREGIONRCMDITEM']._serialized_start=19000
  _globals['_DYNREGIONRCMDITEM']._serialized_end=19099
  _globals['_DYNSCREENTAB']._serialized_start=19102
  _globals['_DYNSCREENTAB']._serialized_end=19269
  _globals['_DYNSEARCHREPLY']._serialized_start=19272
  _globals['_DYNSEARCHREPLY']._serialized_end=19468
  _globals['_DYNSEARCHREQ']._serialized_start=19471
  _globals['_DYNSEARCHREQ']._serialized_end=19605
  _globals['_DYNSERVERDETAILSREPLY']._serialized_start=19608
  _globals['_DYNSERVERDETAILSREPLY']._serialized_end=19789
  _globals['_DYNSERVERDETAILSREPLY_ITEMSENTRY']._serialized_start=19707
  _globals['_DYNSERVERDETAILSREPLY_ITEMSENTRY']._serialized_end=19789
  _globals['_DYNSERVERDETAILSREQ']._serialized_start=19792
  _globals['_DYNSERVERDETAILSREQ']._serialized_end=20041
  _globals['_DYNSPACEREQ']._serialized_start=20044
  _globals['_DYNSPACEREQ']._serialized_end=20216
  _globals['_DYNSPACERSP']._serialized_start=20218
  _globals['_DYNSPACERSP']._serialized_end=20325
  _globals['_DYNSPACESEARCHDETAILSREPLY']._serialized_start=20328
  _globals['_DYNSPACESEARCHDETAILSREPLY']._serialized_end=20519
  _globals['_DYNSPACESEARCHDETAILSREPLY_ITEMSENTRY']._serialized_start=19707
  _globals['_DYNSPACESEARCHDETAILSREPLY_ITEMSENTRY']._serialized_end=19789
  _globals['_DYNSPACESEARCHDETAILSREQ']._serialized_start=20522
  _globals['_DYNSPACESEARCHDETAILSREQ']._serialized_end=20801
  _globals['_DYNTAB']._serialized_start=20804
  _globals['_DYNTAB']._serialized_end=21100
  _globals['_DYNTABREPLY']._serialized_start=21102
  _globals['_DYNTABREPLY']._serialized_end=21224
  _globals['_DYNTABREQ']._serialized_start=21226
  _globals['_DYNTABREQ']._serialized_end=21324
  _globals['_DYNTHUMBREQ']._serialized_start=21326
  _globals['_DYNTHUMBREQ']._serialized_end=21449
  _globals['_DYNVIDEOPERSONALREPLY']._serialized_start=21452
  _globals['_DYNVIDEOPERSONALREPLY']._serialized_end=21730
  _globals['_DYNVIDEOPERSONALREQ']._serialized_start=21733
  _globals['_DYNVIDEOPERSONALREQ']._serialized_end=22052
  _globals['_DYNVIDEOREPLY']._serialized_start=22055
  _globals['_DYNVIDEOREPLY']._serialized_end=22273
  _globals['_DYNVIDEOREQ']._serialized_start=22276
  _globals['_DYNVIDEOREQ']._serialized_end=22590
  _globals['_DYNVIDEOUPDOFFSETREQ']._serialized_start=22592
  _globals['_DYNVIDEOUPDOFFSETREQ']._serialized_end=22696
  _globals['_DYNVOTEREPLY']._serialized_start=22698
  _globals['_DYNVOTEREPLY']._serialized_end=22781
  _globals['_DYNVOTEREQ']._serialized_start=22784
  _globals['_DYNVOTEREQ']._serialized_end=22916
  _globals['_EMOJISIZESPEC']._serialized_start=22918
  _globals['_EMOJISIZESPEC']._serialized_end=22948
  _globals['_EMOTENODE']._serialized_start=22951
  _globals['_EMOTENODE']._serialized_end=23177
  _globals['_EMOTESIZE']._serialized_start=23179
  _globals['_EMOTESIZE']._serialized_end=23225
  _globals['_EXTEND']._serialized_start=23228
  _globals['_EXTEND']._serialized_end=24129
  _globals['_EXTEND_HISTORYREPORTENTRY']._serialized_start=24077
  _globals['_EXTEND_HISTORYREPORTENTRY']._serialized_end=24129
  _globals['_EXTENDREPLY']._serialized_start=24131
  _globals['_EXTENDREPLY']._serialized_end=24216
  _globals['_EXTENDREPLYPARAM']._serialized_start=24218
  _globals['_EXTENDREPLYPARAM']._serialized_end=24264
  _globals['_EXTINFOCOMMON']._serialized_start=24267
  _globals['_EXTINFOCOMMON']._serialized_end=24493
  _globals['_EXTINFOGAME']._serialized_start=24495
  _globals['_EXTINFOGAME']._serialized_end=24550
  _globals['_EXTINFOHOT']._serialized_start=24552
  _globals['_EXTINFOHOT']._serialized_end=24606
  _globals['_EXTINFOLBS']._serialized_start=24608
  _globals['_EXTINFOLBS']._serialized_end=24680
  _globals['_EXTINFOOGV']._serialized_start=24682
  _globals['_EXTINFOOGV']._serialized_end=24746
  _globals['_EXTINFOTOPIC']._serialized_start=24748
  _globals['_EXTINFOTOPIC']._serialized_end=24804
  _globals['_FEEDFILTERREPLY']._serialized_start=24806
  _globals['_FEEDFILTERREPLY']._serialized_end=24909
  _globals['_FEEDFILTERREQ']._serialized_start=24912
  _globals['_FEEDFILTERREQ']._serialized_end=25131
  _globals['_FETCHTABSETTINGREPLY']._serialized_start=25133
  _globals['_FETCHTABSETTINGREPLY']._serialized_end=25171
  _globals['_FOLLOWLISTITEM']._serialized_start=25174
  _globals['_FOLLOWLISTITEM']._serialized_end=25332
  _globals['_GOODSITEM']._serialized_start=25335
  _globals['_GOODSITEM']._serialized_end=25670
  _globals['_GUIDEBARINFO']._serialized_start=25672
  _globals['_GUIDEBARINFO']._serialized_end=25788
  _globals['_HIGHLIGHTTEXT']._serialized_start=25790
  _globals['_HIGHLIGHTTEXT']._serialized_end=25916
  _globals['_HOMESUBSCRIBEREPLY']._serialized_start=25918
  _globals['_HOMESUBSCRIBEREPLY']._serialized_end=25954
  _globals['_HOMESUBSCRIBEREQ']._serialized_start=25956
  _globals['_HOMESUBSCRIBEREQ']._serialized_end=26014
  _globals['_ICONBADGE']._serialized_start=26016
  _globals['_ICONBADGE']._serialized_end=26062
  _globals['_ICONBUTTON']._serialized_start=26064
  _globals['_ICONBUTTON']._serialized_end=26146
  _globals['_IMAGESET']._serialized_start=26148
  _globals['_IMAGESET']._serialized_end=26193
  _globals['_IMGINLINECFG']._serialized_start=26195
  _globals['_IMGINLINECFG']._serialized_end=26288
  _globals['_INFOOGV']._serialized_start=26290
  _globals['_INFOOGV']._serialized_end=26361
  _globals['_INTERACTIONFACE']._serialized_start=26363
  _globals['_INTERACTIONFACE']._serialized_end=26407
  _globals['_INTERACTIONITEM']._serialized_start=26410
  _globals['_INTERACTIONITEM']._serialized_end=26719
  _globals['_INTERACTIONSTAT']._serialized_start=26721
  _globals['_INTERACTIONSTAT']._serialized_end=26752
  _globals['_LBSPOIDETAIL']._serialized_start=26754
  _globals['_LBSPOIDETAIL']._serialized_end=26860
  _globals['_LBSPOIREPLY']._serialized_start=26863
  _globals['_LBSPOIREPLY']._serialized_end=27017
  _globals['_LBSPOIREQ']._serialized_start=27020
  _globals['_LBSPOIREQ']._serialized_end=27185
  _globals['_LEGACYTOPICFEEDREPLY']._serialized_start=27188
  _globals['_LEGACYTOPICFEEDREPLY']._serialized_end=27423
  _globals['_LEGACYTOPICFEEDREQ']._serialized_start=27426
  _globals['_LEGACYTOPICFEEDREQ']._serialized_end=27610
  _globals['_LIKEANIMATION']._serialized_start=27612
  _globals['_LIKEANIMATION']._serialized_end=27691
  _globals['_LIKEINFO']._serialized_start=27693
  _globals['_LIKEINFO']._serialized_end=27779
  _globals['_LIKELISTREPLY']._serialized_start=27781
  _globals['_LIKELISTREPLY']._serialized_end=27888
  _globals['_LIKELISTREQ']._serialized_start=27890
  _globals['_LIKELISTREQ']._serialized_end=27988
  _globals['_LIKEUSER']._serialized_start=27990
  _globals['_LIKEUSER']._serialized_end=28041
  _globals['_LINEPARAGRAPH']._serialized_start=28043
  _globals['_LINEPARAGRAPH']._serialized_end=28112
  _globals['_LINKNODE']._serialized_start=28115
  _globals['_LINKNODE']._serialized_end=28427
  _globals['_LIVEINFO']._serialized_start=28429
  _globals['_LIVEINFO']._serialized_end=28527
  _globals['_LIVEPENDANT']._serialized_start=28529
  _globals['_LIVEPENDANT']._serialized_end=28590
  _globals['_MATCHTEAM']._serialized_start=28592
  _globals['_MATCHTEAM']._serialized_end=28680
  _globals['_MDLDYNAPPLET']._serialized_start=28683
  _globals['_MDLDYNAPPLET']._serialized_end=28822
  _globals['_MDLDYNARCHIVE']._serialized_start=28825
  _globals['_MDLDYNARCHIVE']._serialized_end=29679
  _globals['_MDLDYNARTICLE']._serialized_start=29681
  _globals['_MDLDYNARTICLE']._serialized_end=29801
  _globals['_MDLDYNCOMMON']._serialized_start=29804
  _globals['_MDLDYNCOMMON']._serialized_end=30107
  _globals['_MDLDYNCOURBATCH']._serialized_start=30110
  _globals['_MDLDYNCOURBATCH']._serialized_end=30470
  _globals['_MDLDYNCOURSEASON']._serialized_start=30473
  _globals['_MDLDYNCOURSEASON']._serialized_end=30751
  _globals['_MDLDYNCOURUP']._serialized_start=30754
  _globals['_MDLDYNCOURUP']._serialized_end=31028
  _globals['_MDLDYNDRAW']._serialized_start=31031
  _globals['_MDLDYNDRAW']._serialized_end=31195
  _globals['_MDLDYNDRAWITEM']._serialized_start=31198
  _globals['_MDLDYNDRAWITEM']._serialized_end=31326
  _globals['_MDLDYNDRAWTAG']._serialized_start=31329
  _globals['_MDLDYNDRAWTAG']._serialized_end=31460
  _globals['_MDLDYNDRAWTAGITEM']._serialized_start=31463
  _globals['_MDLDYNDRAWTAGITEM']._serialized_end=31644
  _globals['_MDLDYNFORWARD']._serialized_start=31646
  _globals['_MDLDYNFORWARD']._serialized_end=31728
  _globals['_MDLDYNLIVE']._serialized_start=31731
  _globals['_MDLDYNLIVE']._serialized_end=32009
  _globals['_MDLDYNLIVERCMD']._serialized_start=32012
  _globals['_MDLDYNLIVERCMD']._serialized_end=32160
  _globals['_MDLDYNMEDIALIST']._serialized_start=32163
  _globals['_MDLDYNMEDIALIST']._serialized_end=32326
  _globals['_MDLDYNMUSIC']._serialized_start=32328
  _globals['_MDLDYNMUSIC']._serialized_end=32442
  _globals['_MDLDYNPGC']._serialized_start=32445
  _globals['_MDLDYNPGC']._serialized_end=33085
  _globals['_MDLDYNSUBSCRIPTION']._serialized_start=33088
  _globals['_MDLDYNSUBSCRIPTION']._serialized_end=33262
  _globals['_MDLDYNSUBSCRIPTIONNEW']._serialized_start=33265
  _globals['_MDLDYNSUBSCRIPTIONNEW']._serialized_end=33503
  _globals['_MDLDYNTOPICSET']._serialized_start=33506
  _globals['_MDLDYNTOPICSET']._serialized_end=33668
  _globals['_MDLDYNUGCSEASON']._serialized_start=33671
  _globals['_MDLDYNUGCSEASON']._serialized_end=33998
  _globals['_MIXUPLISTITEM']._serialized_start=34001
  _globals['_MIXUPLISTITEM']._serialized_end=34364
  _globals['_MIXUPLISTLIVEITEM']._serialized_start=34366
  _globals['_MIXUPLISTLIVEITEM']._serialized_end=34431
  _globals['_MODULE']._serialized_start=34434
  _globals['_MODULE']._serialized_end=36808
  _globals['_MODULEAD']._serialized_start=36811
  _globals['_MODULEAD']._serialized_end=37032
  _globals['_MODULEADDITIONAL']._serialized_start=37035
  _globals['_MODULEADDITIONAL']._serialized_end=37724
  _globals['_MODULEAUTHOR']._serialized_start=37727
  _globals['_MODULEAUTHOR']._serialized_end=38362
  _globals['_MODULEAUTHORBADGEBUTTON']._serialized_start=38364
  _globals['_MODULEAUTHORBADGEBUTTON']._serialized_end=38445
  _globals['_MODULEAUTHORFORWARD']._serialized_start=38448
  _globals['_MODULEAUTHORFORWARD']._serialized_end=38737
  _globals['_MODULEAUTHORFORWARDTITLE']._serialized_start=38739
  _globals['_MODULEAUTHORFORWARDTITLE']._serialized_end=38792
  _globals['_MODULEBANNER']._serialized_start=38795
  _globals['_MODULEBANNER']._serialized_end=38992
  _globals['_MODULEBANNERUSER']._serialized_start=38994
  _globals['_MODULEBANNERUSER']._serialized_end=39073
  _globals['_MODULEBANNERUSERITEM']._serialized_start=39076
  _globals['_MODULEBANNERUSERITEM']._serialized_end=39441
  _globals['_MODULEBLOCKED']._serialized_start=39444
  _globals['_MODULEBLOCKED']._serialized_end=39958
  _globals['_MODULEBUTTOM']._serialized_start=39961
  _globals['_MODULEBUTTOM']._serialized_end=40325
  _globals['_MODULEBUTTOM_INTERACTIONICON']._serialized_start=40220
  _globals['_MODULEBUTTOM_INTERACTIONICON']._serialized_end=40325
  _globals['_MODULEBUTTON']._serialized_start=40327
  _globals['_MODULEBUTTON']._serialized_end=40391
  _globals['_MODULECOMMENT']._serialized_start=40393
  _globals['_MODULECOMMENT']._serialized_end=40467
  _globals['_MODULECOPYRIGHT']._serialized_start=40469
  _globals['_MODULECOPYRIGHT']._serialized_end=40525
  _globals['_MODULEDESC']._serialized_start=40527
  _globals['_MODULEDESC']._serialized_end=40623
  _globals['_MODULEDESCGOODS']._serialized_start=40626
  _globals['_MODULEDESCGOODS']._serialized_end=40848
  _globals['_MODULEDISPUTE']._serialized_start=40850
  _globals['_MODULEDISPUTE']._serialized_end=40907
  _globals['_MODULEDYNAMIC']._serialized_start=40910
  _globals['_MODULEDYNAMIC']._serialized_end=42170
  _globals['_MODULEEXTEND']._serialized_start=42172
  _globals['_MODULEEXTEND']._serialized_end=42258
  _globals['_MODULEEXTENDITEM']._serialized_start=42261
  _globals['_MODULEEXTENDITEM']._serialized_end=42721
  _globals['_MODULEFOLD']._serialized_start=42724
  _globals['_MODULEFOLD']._serialized_end=42954
  _globals['_MODULEINTERACTION']._serialized_start=42956
  _globals['_MODULEINTERACTION']._serialized_end=43043
  _globals['_MODULEITEMNULL']._serialized_start=43045
  _globals['_MODULEITEMNULL']._serialized_end=43089
  _globals['_MODULELIKEUSER']._serialized_start=43091
  _globals['_MODULELIKEUSER']._serialized_end=43184
  _globals['_MODULENOTICE']._serialized_start=43186
  _globals['_MODULENOTICE']._serialized_end=43281
  _globals['_MODULEOPUSCOLLECTION']._serialized_start=43284
  _globals['_MODULEOPUSCOLLECTION']._serialized_end=43455
  _globals['_MODULEOPUSSUMMARY']._serialized_start=43458
  _globals['_MODULEOPUSSUMMARY']._serialized_end=43669
  _globals['_MODULEPARAGRAPH']._serialized_start=43672
  _globals['_MODULEPARAGRAPH']._serialized_end=43830
  _globals['_MODULERCMD']._serialized_start=43833
  _globals['_MODULERCMD']._serialized_end=43969
  _globals['_MODULERECOMMEND']._serialized_start=43972
  _globals['_MODULERECOMMEND']._serialized_end=44106
  _globals['_MODULESHAREINFO']._serialized_start=44109
  _globals['_MODULESHAREINFO']._serialized_end=44252
  _globals['_MODULESTAT']._serialized_start=44255
  _globals['_MODULESTAT']._serialized_end=44475
  _globals['_MODULESTORY']._serialized_start=44478
  _globals['_MODULESTORY']._serialized_end=44658
  _globals['_MODULETEXTNOTICE']._serialized_start=44660
  _globals['_MODULETEXTNOTICE']._serialized_end=44732
  _globals['_MODULETITLE']._serialized_start=44734
  _globals['_MODULETITLE']._serialized_end=44839
  _globals['_MODULETOP']._serialized_start=44842
  _globals['_MODULETOP']._serialized_end=45047
  _globals['_MODULETOPIC']._serialized_start=45049
  _globals['_MODULETOPIC']._serialized_end=45101
  _globals['_MODULETOPICBRIEF']._serialized_start=45103
  _globals['_MODULETOPICBRIEF']._serialized_end=45172
  _globals['_MODULETOPICDETAILSEXT']._serialized_start=45174
  _globals['_MODULETOPICDETAILSEXT']._serialized_end=45220
  _globals['_MODULETOPTAG']._serialized_start=45222
  _globals['_MODULETOPTAG']._serialized_end=45254
  _globals['_NAMEPLATE']._serialized_start=45256
  _globals['_NAMEPLATE']._serialized_end=45364
  _globals['_NEWEP']._serialized_start=45366
  _globals['_NEWEP']._serialized_end=45420
  _globals['_NFTINFO']._serialized_start=45423
  _globals['_NFTINFO']._serialized_end=45582
  _globals['_NOREPLY']._serialized_start=45584
  _globals['_NOREPLY']._serialized_end=45593
  _globals['_NOREQ']._serialized_start=45595
  _globals['_NOREQ']._serialized_end=45602
  _globals['_NOTEVIDEOTS']._serialized_start=45605
  _globals['_NOTEVIDEOTS']._serialized_end=45772
  _globals['_OFFICIALACCOUNTINFO']._serialized_start=45775
  _globals['_OFFICIALACCOUNTINFO']._serialized_end=45966
  _globals['_OFFICIALACCOUNTSREPLY']._serialized_start=45968
  _globals['_OFFICIALACCOUNTSREPLY']._serialized_end=46086
  _globals['_OFFICIALACCOUNTSREQ']._serialized_start=46088
  _globals['_OFFICIALACCOUNTSREQ']._serialized_end=46165
  _globals['_OFFICIALDYNAMICSREPLY']._serialized_start=46168
  _globals['_OFFICIALDYNAMICSREPLY']._serialized_end=46348
  _globals['_OFFICIALDYNAMICSREQ']._serialized_start=46350
  _globals['_OFFICIALDYNAMICSREQ']._serialized_end=46427
  _globals['_OFFICIALITEM']._serialized_start=46430
  _globals['_OFFICIALITEM']._serialized_end=46611
  _globals['_OFFICIALRCMDARCHIVE']._serialized_start=46614
  _globals['_OFFICIALRCMDARCHIVE']._serialized_end=46899
  _globals['_OFFICIALRCMDDYNAMIC']._serialized_start=46902
  _globals['_OFFICIALRCMDDYNAMIC']._serialized_end=47157
  _globals['_OFFICIALVERIFY']._serialized_start=47159
  _globals['_OFFICIALVERIFY']._serialized_end=47221
  _globals['_ONELINETEXT']._serialized_start=47223
  _globals['_ONELINETEXT']._serialized_end=47294
  _globals['_ONLYFANS']._serialized_start=47296
  _globals['_ONLYFANS']._serialized_end=47379
  _globals['_ONLYFANSPROPERTY']._serialized_start=47381
  _globals['_ONLYFANSPROPERTY']._serialized_end=47444
  _globals['_OPUSCOLLECTION']._serialized_start=47447
  _globals['_OPUSCOLLECTION']._serialized_end=47638
  _globals['_OPUSCOLLECTIONITEM']._serialized_start=47640
  _globals['_OPUSCOLLECTIONITEM']._serialized_end=47754
  _globals['_PARAGRAPH']._serialized_start=47757
  _globals['_PARAGRAPH']._serialized_end=48543
  _globals['_PARAGRAPH_LISTFORMAT']._serialized_start=48139
  _globals['_PARAGRAPH_LISTFORMAT']._serialized_end=48196
  _globals['_PARAGRAPH_PARAGRAPHFORMAT']._serialized_start=48199
  _globals['_PARAGRAPH_PARAGRAPHFORMAT']._serialized_end=48350
  _globals['_PARAGRAPH_PARAGRAPHALIGN']._serialized_start=48352
  _globals['_PARAGRAPH_PARAGRAPHALIGN']._serialized_end=48401
  _globals['_PARAGRAPH_PARAGRAPHTYPE']._serialized_start=48404
  _globals['_PARAGRAPH_PARAGRAPHTYPE']._serialized_end=48532
  _globals['_PARASPACING']._serialized_start=48545
  _globals['_PARASPACING']._serialized_end=48637
  _globals['_PGCSEASON']._serialized_start=48639
  _globals['_PGCSEASON']._serialized_end=48698
  _globals['_PICPARAGRAPH']._serialized_start=48701
  _globals['_PICPARAGRAPH']._serialized_end=48903
  _globals['_PICPARAGRAPH_PICPARAGRAPHSTYLE']._serialized_start=48840
  _globals['_PICPARAGRAPH_PICPARAGRAPHSTYLE']._serialized_end=48903
  _globals['_PLAYURLPARAM']._serialized_start=48905
  _globals['_PLAYURLPARAM']._serialized_end=48996
  _globals['_POPUP']._serialized_start=48998
  _globals['_POPUP']._serialized_end=49047
  _globals['_RCMDARCHIVE']._serialized_start=49050
  _globals['_RCMDARCHIVE']._serialized_end=49380
  _globals['_RCMDAUTHOR']._serialized_start=49383
  _globals['_RCMDAUTHOR']._serialized_end=49513
  _globals['_RCMDCAMPUSBRIEF']._serialized_start=49515
  _globals['_RCMDCAMPUSBRIEF']._serialized_end=49607
  _globals['_RCMDITEM']._serialized_start=49610
  _globals['_RCMDITEM']._serialized_end=49744
  _globals['_RCMDOPTION']._serialized_start=49746
  _globals['_RCMDOPTION']._serialized_end=49778
  _globals['_RCMDREASON']._serialized_start=49781
  _globals['_RCMDREASON']._serialized_end=49909
  _globals['_RCMDTOPBUTTON']._serialized_start=49911
  _globals['_RCMDTOPBUTTON']._serialized_end=49953
  _globals['_RCMDUPSPARAM']._serialized_start=49955
  _globals['_RCMDUPSPARAM']._serialized_end=49989
  _globals['_REACTIONLISTITEM']._serialized_start=49992
  _globals['_REACTIONLISTITEM']._serialized_end=50151
  _globals['_REACTIONLISTREPLY']._serialized_start=50153
  _globals['_REACTIONLISTREPLY']._serialized_end=50278
  _globals['_REACTIONLISTREQ']._serialized_start=50280
  _globals['_REACTIONLISTREQ']._serialized_end=50364
  _globals['_RELATION']._serialized_start=50366
  _globals['_RELATION']._serialized_end=50488
  _globals['_REPOSTLISTREQ']._serialized_start=50491
  _globals['_REPOSTLISTREQ']._serialized_end=50645
  _globals['_REPOSTLISTRSP']._serialized_start=50648
  _globals['_REPOSTLISTRSP']._serialized_end=50828
  _globals['_SCHOOLRECOMMENDREPLY']._serialized_start=50830
  _globals['_SCHOOLRECOMMENDREPLY']._serialized_end=50904
  _globals['_SCHOOLRECOMMENDREQ']._serialized_start=50906
  _globals['_SCHOOLRECOMMENDREQ']._serialized_end=51015
  _globals['_SCHOOLSEARCHREPLY']._serialized_start=51017
  _globals['_SCHOOLSEARCHREPLY']._serialized_end=51141
  _globals['_SCHOOLSEARCHREQ']._serialized_start=51143
  _globals['_SCHOOLSEARCHREQ']._serialized_end=51240
  _globals['_SEARCHCHANNEL']._serialized_start=51243
  _globals['_SEARCHCHANNEL']._serialized_end=51394
  _globals['_SEARCHINFO']._serialized_start=51397
  _globals['_SEARCHINFO']._serialized_end=51544
  _globals['_SEARCHTOAST']._serialized_start=51546
  _globals['_SEARCHTOAST']._serialized_end=51599
  _globals['_SEARCHTOPIC']._serialized_start=51602
  _globals['_SEARCHTOPIC']._serialized_end=51752
  _globals['_SEARCHTOPICBUTTON']._serialized_start=51754
  _globals['_SEARCHTOPICBUTTON']._serialized_end=51806
  _globals['_SEARCHTOPICITEM']._serialized_start=51808
  _globals['_SEARCHTOPICITEM']._serialized_end=51911
  _globals['_SETDECISIONREQ']._serialized_start=51913
  _globals['_SETDECISIONREQ']._serialized_end=52008
  _globals['_SETRECENTCAMPUSREQ']._serialized_start=52010
  _globals['_SETRECENTCAMPUSREQ']._serialized_end=52133
  _globals['_SHARECHANNEL']._serialized_start=52135
  _globals['_SHARECHANNEL']._serialized_end=52251
  _globals['_SHARERESERVE']._serialized_start=52254
  _globals['_SHARERESERVE']._serialized_end=52424
  _globals['_SORTTYPE']._serialized_start=52426
  _globals['_SORTTYPE']._serialized_end=52479
  _globals['_STORYARCHIVE']._serialized_start=52481
  _globals['_STORYARCHIVE']._serialized_end=52591
  _globals['_STORYITEM']._serialized_start=52594
  _globals['_STORYITEM']._serialized_end=52777
  _globals['_SUBSCRIBECAMPUSREQ']._serialized_start=52779
  _globals['_SUBSCRIBECAMPUSREQ']._serialized_end=52902
  _globals['_TEXTNODE']._serialized_start=52905
  _globals['_TEXTNODE']._serialized_end=53236
  _globals['_TEXTNODE_TEXTNODETYPE']._serialized_start=53157
  _globals['_TEXTNODE_TEXTNODETYPE']._serialized_end=53228
  _globals['_TEXTPARAGRAPH']._serialized_start=53238
  _globals['_TEXTPARAGRAPH']._serialized_end=53303
  _globals['_TEXTWITHPRIORITY']._serialized_start=53305
  _globals['_TEXTWITHPRIORITY']._serialized_end=53355
  _globals['_THREEPOINTATTENTION']._serialized_start=53358
  _globals['_THREEPOINTATTENTION']._serialized_end=53551
  _globals['_THREEPOINTAUTOPLAY']._serialized_start=53554
  _globals['_THREEPOINTAUTOPLAY']._serialized_end=53780
  _globals['_THREEPOINTCOMMENT']._serialized_start=53783
  _globals['_THREEPOINTCOMMENT']._serialized_end=53951
  _globals['_THREEPOINTDEFAULT']._serialized_start=53954
  _globals['_THREEPOINTDEFAULT']._serialized_end=54091
  _globals['_THREEPOINTDEFAULTTOAST']._serialized_start=54093
  _globals['_THREEPOINTDEFAULTTOAST']._serialized_end=54146
  _globals['_THREEPOINTDISLIKE']._serialized_start=54148
  _globals['_THREEPOINTDISLIKE']._serialized_end=54196
  _globals['_THREEPOINTFAVORITE']._serialized_start=54198
  _globals['_THREEPOINTFAVORITE']._serialized_end=54324
  _globals['_THREEPOINTHIDE']._serialized_start=54327
  _globals['_THREEPOINTHIDE']._serialized_end=54484
  _globals['_THREEPOINTHIDEINTERACTIVE']._serialized_start=54486
  _globals['_THREEPOINTHIDEINTERACTIVE']._serialized_end=54576
  _globals['_THREEPOINTITEM']._serialized_start=54579
  _globals['_THREEPOINTITEM']._serialized_end=55355
  _globals['_THREEPOINTSHARE']._serialized_start=55358
  _globals['_THREEPOINTSHARE']._serialized_end=55548
  _globals['_THREEPOINTSHARECHANNEL']._serialized_start=55550
  _globals['_THREEPOINTSHARECHANNEL']._serialized_end=55603
  _globals['_THREEPOINTTOP']._serialized_start=55605
  _globals['_THREEPOINTTOP']._serialized_end=55697
  _globals['_THREEPOINTTOPICIRRELEVANT']._serialized_start=55700
  _globals['_THREEPOINTTOPICIRRELEVANT']._serialized_end=55839
  _globals['_THREEPOINTWAIT']._serialized_start=55841
  _globals['_THREEPOINTWAIT']._serialized_end=55967
  _globals['_TOPADDITIONUP']._serialized_start=55969
  _globals['_TOPADDITIONUP']._serialized_end=56051
  _globals['_TOPICBUTTON']._serialized_start=56053
  _globals['_TOPICBUTTON']._serialized_end=56130
  _globals['_TOPICITEM']._serialized_start=56132
  _globals['_TOPICITEM']._serialized_end=56242
  _globals['_TOPICLIST']._serialized_start=56245
  _globals['_TOPICLIST']._serialized_end=56474
  _globals['_TOPICLISTITEM']._serialized_start=56477
  _globals['_TOPICLISTITEM']._serialized_end=56692
  _globals['_TOPICLISTREPLY']._serialized_start=56694
  _globals['_TOPICLISTREPLY']._serialized_end=56795
  _globals['_TOPICLISTREQ']._serialized_start=56797
  _globals['_TOPICLISTREQ']._serialized_end=56846
  _globals['_TOPICMERGEDRESOURCE']._serialized_start=56848
  _globals['_TOPICMERGEDRESOURCE']._serialized_end=56913
  _globals['_TOPICRCMDCARD']._serialized_start=56916
  _globals['_TOPICRCMDCARD']._serialized_end=57087
  _globals['_TOPICSQUAREINFO']._serialized_start=57090
  _globals['_TOPICSQUAREINFO']._serialized_end=57230
  _globals['_TOPICSQUAREREPLY']._serialized_start=57232
  _globals['_TOPICSQUAREREPLY']._serialized_end=57306
  _globals['_TOPICSQUAREREQ']._serialized_start=57308
  _globals['_TOPICSQUAREREQ']._serialized_end=57343
  _globals['_UNFOLLOW']._serialized_start=57345
  _globals['_UNFOLLOW']._serialized_end=57444
  _globals['_UNFOLLOWMATCHREQ']._serialized_start=57446
  _globals['_UNFOLLOWMATCHREQ']._serialized_end=57477
  _globals['_UNFOLLOWUSERITEM']._serialized_start=57480
  _globals['_UNFOLLOWUSERITEM']._serialized_end=57835
  _globals['_UPDATETABSETTINGREQ']._serialized_start=57837
  _globals['_UPDATETABSETTINGREQ']._serialized_end=57924
  _globals['_UPLISTITEM']._serialized_start=57927
  _globals['_UPLISTITEM']._serialized_end=58464
  _globals['_UPLISTMORELABEL']._serialized_start=58466
  _globals['_UPLISTMORELABEL']._serialized_end=58511
  _globals['_USERINFO']._serialized_start=58514
  _globals['_USERINFO']._serialized_end=59053
  _globals['_USERITEMSTYLE']._serialized_start=59055
  _globals['_USERITEMSTYLE']._serialized_end=59181
  _globals['_USERPENDANT']._serialized_start=59183
  _globals['_USERPENDANT']._serialized_end=59254
  _globals['_VIDEOBADGE']._serialized_start=59257
  _globals['_VIDEOBADGE']._serialized_end=59481
  _globals['_VIPINFO']._serialized_start=59484
  _globals['_VIPINFO']._serialized_end=59661
  _globals['_VIPLABEL']._serialized_start=59663
  _globals['_VIPLABEL']._serialized_end=59722
  _globals['_WEIGHT']._serialized_start=59724
  _globals['_WEIGHT']._serialized_end=59813
  _globals['_WEIGHTBUTTON']._serialized_start=59815
  _globals['_WEIGHTBUTTON']._serialized_end=59862
  _globals['_WEIGHTDISLIKE']._serialized_start=59864
  _globals['_WEIGHTDISLIKE']._serialized_end=59918
  _globals['_WEIGHTITEM']._serialized_start=59921
  _globals['_WEIGHTITEM']._serialized_end=60108
  _globals['_WORDNODE']._serialized_start=60111
  _globals['_WORDNODE']._serialized_end=60356
  _globals['_WORDNODE_WORDNODESTYLE']._serialized_start=60269
  _globals['_WORDNODE_WORDNODESTYLE']._serialized_end=60356
  _globals['_DYNAMIC']._serialized_start=69114
  _globals['_DYNAMIC']._serialized_end=74890
# @@protoc_insertion_point(module_scope)
